@@ -68,15 +68,5 @@
 #pragma link C++ function make_mask(bcount_t, bcount_t);
 #pragma link C++ function lowest_bit_set(bmask_t);
 
-#pragma link C++ function wfft(fComplex*, unsigned int, int);
-#pragma link C++ function wfft(const float*, fComplex*, unsigned int);
-#pragma link C++ function wfft(dComplex*, unsigned int, int);
-#pragma link C++ function wfft(const float*, dComplex*, unsigned int);
-
-#pragma link C++ function Rndm();
-#pragma link C++ function RndmSeed(unsigned long);
-#pragma link C++ function Rannor(double&, double&);
-#pragma link C++ function Rannor();
-
 #endif
 
