@@ -30,7 +30,7 @@ Time::ulong_t LeapS(const Time& t0) {
    const Time::ulong_t secpd = 24*60*60;
 
    // Offset in days from the GPS t=0
-   const int nLeaps=17;
+   const int nLeaps=18;
    const Time::ulong_t leapd[nLeaps] = {
       // 1980 + Std years + Leap years + Jan-Jul
       361                          +  181,  // Jul 1, 1981
@@ -49,7 +49,8 @@ Time::ulong_t LeapS(const Time& t0) {
       361 +   19*365  +   6*366,            // Jan 1, 2006
       361 +   21*365  +   7*366,            // Jan 1, 2009
       361 +   23*365  +   8*366    +  181,  // Jul 1, 2012
-      361 +   26*365  +   8*366    +  181   // Jul 1, 2015
+      361 +   26*365  +   8*366    +  181,  // Jul 1, 2015
+      361 +   27*365  +   9*366             // Jan 1, 2017
    };
 
    //----------------------------------  Count the leap seconds in effect
