@@ -83,6 +83,12 @@ DVector::Append(size_type N, const fComplex* data) {
      replace(getLength(), 0, DVecType<fComplex>(cv), 0, N);
 }
 
+void 
+DVector::Append(size_type N, const dComplex* data) {
+     const CWVec<dComplex>  cv(N, data, false);
+     replace(getLength(), 0, DVecType<dComplex>(cv), 0, N);
+}
+
 
 //======================================  Construct a converted vector
 DVector*
