@@ -1,7 +1,7 @@
 #include "DataDesc.hh"
 #include <time.h>
-#include <string.h>
-#include <math.h>
+#include <cstring>
+#include <cmath>
 #include <iostream>
 
    using namespace std;
