@@ -2,11 +2,10 @@
 #include "tconv.h"
 #include "calibration/calutil.h"
 #include <string>
-#include <string.h>
-#include <strings.h>
+#include <cstring>
 #include <time.h>
-#include <math.h>
-#include <stdlib.h>
+#include <cmath>
+#include <cstdlib>
 #include <iostream>
 
 
