@@ -1,4 +1,4 @@
-/* -*- mode: c++; c-basic-offset: 4; -*- */
+//* -*- mode: c++; c-basic-offset: 4; -*- */
 //
 //   TSeries class implementation
 //
@@ -15,15 +15,6 @@
 #include <iostream>
 #include <iomanip>
 
-// NOT CLEAR WHY THIS IS NEEDED BUT AVOIDS STRANGE LINK ERRORS ON CYGWIN/GCC
-#ifdef P__WIN32
-template class DVecType<short>;
-template class DVecType<int>;
-template class DVecType<float>;
-template class DVecType<double>;
-template class DVecType<fComplex>;
-#endif
-
 using namespace std;
 
 //======================================  Default Constructor
@@ -128,7 +119,7 @@ TSeries::TSeries(const Time& t0, const Interval& dt, size_type NData,
   : mT0(t0),
     mDt(dt),
     mF0(0.0),
-    mFNyquist(2/double(dt)),
+    mFNyquist(0.5/double(dt)),
     mStatus(0),
     mSigmaW(1.0)
 {
@@ -251,10 +242,10 @@ TSeries::getBin(const Time& t) const {
     return r;
 }
 
-fComplex
+TSeries::complex_type
 TSeries::getComplexAverage(void) const {
     size_type len = getNSample();
-    if (!len) return fComplex(0.0);
+    if (!len) return complex_type(0.0);
     return mData->CSum(0, len)/math_type(len);
 }
 
@@ -325,9 +316,15 @@ TSeries::getData(size_type len, fComplex* data) const {
     return mData->getData(0, len, data);
 }
 
-fComplex
+TSeries::size_type
+TSeries::getData(size_type len, dComplex* data) const {
+    if (empty()) return 0;
+    return mData->getData(0, len, data);
+}
+
+TSeries::complex_type
 TSeries::getComplex(size_type index) const {
-    if (empty()) return fComplex(0.0);
+    if (empty()) return complex_type(0.0);
     return mData->getCplx(index);
 }
 
@@ -337,10 +334,9 @@ TSeries::getDouble(size_type index) const {
     return mData->getDouble(index);
 }
 
-
 bool
 TSeries::isComplex(void) const {
-    return mData.get() && mData->C_data();
+    return mData.get() && (mData->C_data() || mData->W_data());
 }
 
 const void*
@@ -415,7 +411,7 @@ TSeries::setData(const Time& t0, const Interval& dt, DVector* data) {
     mT0       = t0;
     mDt       = dt;
     mF0       = 0.0;
-    mFNyquist = 2/double(dt);
+    mFNyquist = 0.5/double(dt);
     mStatus   = 0;
     mSigmaW   = 1.0;
     if (data != mData.get()) mData.reset(data);
@@ -574,6 +570,21 @@ TSeries::Append(const Time& t, const Interval& Step, const fComplex* data,
     return 0;
 }
 
+//======================================  Append Complex data
+int 
+TSeries::Append(const Time& t, const Interval& Step, const dComplex* data, 
+		size_type N) {
+    //----------------------------------  Check that data is continuous
+    int bad = Contig(t, Step);
+    if (bad) return bad;
+
+    //----------------------------------  Create or add to a DVector
+    if (!mData.get()) mData.reset(new DVectW(N, data));
+    else              mData->Append(N, data);
+
+    return 0;
+}
+
 //======================================  Check that data is continuous
 int 
 TSeries::Contig(const Time& t, const Interval& Step) {
@@ -644,6 +655,13 @@ TSeries::operator+=(math_type Bias) {
     return *this;
 }
 
+//======================================  Bias a TSeries
+TSeries&
+TSeries::operator+=(complex_type Bias) {
+    if (!empty()) *mData += Bias;
+    return *this;
+}
+
 //======================================  Scale a TSeries
 TSeries& 
 TSeries::operator*=(math_type Scale) {
@@ -651,9 +669,16 @@ TSeries::operator*=(math_type Scale) {
     return *this;
 }
 
+//======================================  Scale a complex TSeries
+TSeries& 
+TSeries::operator*=(complex_type Scale) {
+    if (!empty()) *mData *= Scale;
+    return *this;
+}
+
 //======================================  Add two TSeries
 TSeries&
-TSeries::operator+=(const TSeries& rhs) {
+TSeries::add_overlap(const TSeries& rhs) {
     if (empty() || rhs.empty()) return *this;
     if (mDt != rhs.mDt) throw runtime_error("TSeries sample mismatch");
     size_type inx1 = getBin(rhs.mT0);
@@ -665,9 +690,20 @@ TSeries::operator+=(const TSeries& rhs) {
     return *this;
 }
 
+TSeries&
+TSeries::operator+=(const TSeries& rhs) {
+    if (empty() || rhs.empty()) return *this;
+    if (mDt != rhs.mDt || mT0 != rhs.mT0 || getNSample() != rhs.getNSample()) {
+	throw runtime_error("TSeries::operator+= binning mismatch");
+    }
+    *mData += *rhs.mData;
+    combineStatus(rhs.getStatus());
+    return *this;
+}
+
 //======================================  Difference of two TSeries
 TSeries&
-TSeries::operator-=(const TSeries& rhs) {
+TSeries::subtract_overlap(const TSeries& rhs) {
     if (empty() || rhs.empty()) return *this;
     if (mDt != rhs.mDt) throw runtime_error("TSeries sample mismatch");
     size_type inx1 = getBin(rhs.mT0);
@@ -679,6 +715,17 @@ TSeries::operator-=(const TSeries& rhs) {
     return *this;
 }
 
+TSeries&
+TSeries::operator-=(const TSeries& rhs) {
+    if (empty() || rhs.empty()) return *this;
+    if (mDt != rhs.mDt || mT0 != rhs.mT0 || getNSample() != rhs.getNSample()) {
+	throw runtime_error("TSeries::operator-= binning mismatch");
+    }
+    *mData -= *rhs.mData;
+    combineStatus(rhs.getStatus());
+    return *this;
+}
+
 //======================================  Dot product of two series
 TSeries::math_type 
 TSeries::operator*(const TSeries& rhs) const {
@@ -686,35 +733,56 @@ TSeries::operator*(const TSeries& rhs) const {
     return (*mData) * (*rhs.mData);
 }
 
+TSeries&
+TSeries::operator*=(const TSeries& rhs) {
+    if (empty() || rhs.empty()) return *this;
+    if (mDt != rhs.mDt || mT0 != rhs.mT0 || getNSample() != rhs.getNSample()) {
+	throw runtime_error("TSeries::operator*= binning mismatch");
+    }
+    *mData *= *rhs.mData;
+    combineStatus(rhs.getStatus());
+    return *this;
+}
+
 //======================================  Ratio of two series
-TSeries
-TSeries::operator/(const TSeries& rhs) const {
+TSeries&
+TSeries::divide_overlap(const TSeries& rhs) {
     //----------------------------------  Get the overlapping fields
     size_type inx, inx1;
     size_type nw = overlap(rhs, inx, inx1);
-    if (!nw) return TSeries();
+    if (!nw) return *this;
 
     //----------------------------------  Get numerator substring
-    TSeries r(mT0, mDt, mData->Extract(inx, nw));
     switch(mData->getType()) {
     case DVector::t_short:
-        r.Convert(DVector::t_float);
+        Convert(DVector::t_float);
 	break;
     case DVector::t_int:
     case DVector::t_long:
-        r.Convert(DVector::t_double);
+        Convert(DVector::t_double);
 	break;
     default:
         break;
     }
 
     //-----------------------------------  Divide DVectors
-    r.mData->div(0, *rhs.mData, inx1, nw);
-    r.setStatus(getStatus());
-    r.combineStatus(rhs.getStatus());
-    r.mF0 = mF0 - rhs.mF0;
-    r.mSigmaW = mSigmaW / rhs.mSigmaW;
-    return r;
+    mData->div(0, *rhs.mData, inx1, nw);
+    combineStatus(rhs.getStatus());
+    mF0 -= rhs.mF0;
+    mSigmaW = mSigmaW / rhs.mSigmaW;
+    return *this;
+}
+
+
+TSeries&
+TSeries::operator/=(const TSeries& rhs) {
+    if (empty() || rhs.empty()) return *this;
+    if (mDt != rhs.mDt || mT0 != rhs.mT0 || getNSample() != rhs.getNSample()) {
+	throw runtime_error("TSeries::operator/= binning mismatch");
+    }
+    *mData /= *rhs.mData;
+    combineStatus(rhs.getStatus());
+    return *this;
 }
 
 //========================================  Find overlapping region
