@@ -1,12 +1,8 @@
-// $Id: WaveDWT.cc 2928 2004-10-15 15:10:58Z sergei.klimenko $
+// $Id: WaveDWT.cc 7582 2016-03-01 22:25:48Z john.zweizig@LIGO.ORG $
 
 #define WAVEDWT_CC
 #include "PConfig.h"
-#ifdef __GNU_STDC_OLD
-#include <gnusstream.h>
-#else
 #include <sstream>
-#endif
 #include <stdexcept>
 #include "WaveDWT.hh"
 
@@ -265,12 +261,12 @@ void WaveDWT<DataType_t>::forwardFWT(int level, int layer,
 
    if(pLPF==NULL || pHPF==NULL) return;
 
-   register int i,j,k;
-   register double sumA, sumD, data;
-   register const double *p = pLPF;           
-   register const double *q = pHPF;
-   register DataType_t *pD;
-   register int stride = 1<<level; // stride parameter
+   int i,j,k;
+   double sumA, sumD, data;
+   const double *p = pLPF;           
+   const double *q = pHPF;
+   DataType_t *pD;
+   int stride = 1<<level; // stride parameter
    
 // pointer to the first sample in the layer 
    DataType_t *pData = pWWS+getOffset(level,layer);
@@ -395,12 +391,12 @@ void WaveDWT<DataType_t>::inverseFWT(int level, int layer,
 //
 //                  
 
-   register long i,j,k;
-   register double sumA, sumD, data;           
-   register const double *p = pLPF;           
-   register const double *q = pHPF;
-   register DataType_t *pD;
-   register int stride = 1<<level; // stride parameter
+   long i,j,k;
+   double sumA, sumD, data;           
+   const double *p = pLPF;           
+   const double *q = pHPF;
+   DataType_t *pD;
+   int stride = 1<<level; // stride parameter
    
 // pointer to the first sample in the layer 
    DataType_t *pData = pWWS+getOffset(level,layer);
@@ -537,13 +533,13 @@ void WaveDWT<DataType_t>::predict(int level,
    double data;
    double hsum = 0.;             // filter sum
    
-   register int i,j,k;
-   register double sum = 0.;          
+   int i,j,k;
+   double sum = 0.;          
 
-   register const double *h;	         // pointer to filter coefficient
-   register const DataType_t *dataL;     // pointer to left data sample
-   register const DataType_t *dataR;     // pointer to right data sample
-   register const int stride = 1<<level; // stride parameter
+   const double *h;	         // pointer to filter coefficient
+   const DataType_t *dataL;     // pointer to left data sample
+   const DataType_t *dataR;     // pointer to right data sample
+   const int stride = 1<<level; // stride parameter
 
    double *pBorder=new double[2*(m_H-nL)]; // border array
    double *pB;
@@ -717,13 +713,13 @@ void WaveDWT<DataType_t>::update(int level,
    double data;
    double hsum = 0.;             // filter sum
    
-   register int i,j,k;
-   register double sum = 0.;
+   int i,j,k;
+   double sum = 0.;
 
-   register const double *h;	         // pointer to filter coefficient
-   register const DataType_t *dataL;     // pointer to left data sample
-   register const DataType_t *dataR;     // pointer to right data sample
-   register const int stride = 1<<level; // stride parameter
+   const double *h;	         // pointer to filter coefficient
+   const DataType_t *dataL;     // pointer to left data sample
+   const DataType_t *dataR;     // pointer to right data sample
+   const int stride = 1<<level; // stride parameter
    
    DataType_t *dataA, *dataD; 
 
