@@ -1137,8 +1137,8 @@ int wavearray<DataType_t>::getSampleRank(size_t n, size_t l, size_t r) const
    
    while(i<j)
    {
-      while(data[++i]<v && i<j);
-      while(data[--j]>v && i<j);
+      while(data[++i]<v) if (i >= j) break;
+      while(data[--j]>v) if (i >= j) break;
    }
    data[r]=data[n]; data[n]=v;     // put pivot back
    
