@@ -1,4 +1,4 @@
-// $Id: wseries.cc 6832 2013-06-18 23:20:26Z john.zweizig@LIGO.ORG $
+// $Id: wseries.cc 7524 2015-11-19 01:18:08Z ed.maros@LIGO.ORG $
 
 #define WSeries_CC
 #include <time.h>
@@ -362,12 +362,12 @@ template<class DataType_t>
 double WSeries<DataType_t>::coincidence(WSeries<DataType_t>& a, int t, int f, double threshold)
 {
 #if !defined (__SUNPRO_CC)
-   register int i;
-   register int j;
-   register int u;
-   register int v;
-   register float* q = NULL;
-   register float* p = NULL; 
+   int i;
+   int j;
+   int u;
+   int v;
+   float* q = NULL;
+   float* p = NULL; 
 
    int is, ie, js, je;
    
@@ -726,8 +726,8 @@ double WSeries<DataType_t>::fraction(double t, double f, int mode)
 {
    slice S;
    DataType_t*  p=NULL;
-   register DataType_t*  P=NULL;
-   register DataType_t** pp;
+   DataType_t*  P=NULL;
+   DataType_t** pp;
    DataType_t A, aL, aR;
    size_t i,j,k;
    size_t nS, kS, nL, nR, lS;
@@ -1131,8 +1131,8 @@ double WSeries<DataType_t>::percentile(double f, int mode, WSeries<DataType_t>*
 {
    slice S;
    DataType_t*  p=NULL;
-   register DataType_t*  P=NULL;
-   register DataType_t** pp;
+   DataType_t*  P=NULL;
+   DataType_t** pp;
    DataType_t A, aL, aR;
    double x;
    size_t i,j;
