@@ -220,7 +220,7 @@ extern "C" {
 /** This function reads calibration records from a file. The pointer
     to the calibration record array must either point to NULL or 
     point to an array which was previously allocated with calnew or
-    calresize. Upon successful return array pointer will conatain
+    calresize. Upon successful return array pointer will contain
     a valid address if at least one record was read; otherwise this
     argument will be unchanged. This function will call calresize
     if the number of records in the file is larger than the size of
@@ -573,7 +573,7 @@ extern "C" {
     can be called successively feeding in additional data. The function
     returns 0 if an end-of-file mark (empty LIGO_LW element) is 
     discovered; 1 if to continue; -1 on error. Whenever a complete 
-    calibration record or authorization record has been scaned in, 
+    calibration record or authorization record has been scanned in, 
     the corresponding callback function is called.
 
     @memo XML parser for calibration records
@@ -637,7 +637,7 @@ extern "C" {
 /** Finds related units. This function uses a table to find
     related units, e.g., Celsius and Kelvin. This function takes
     a signal information and up to two calibration records as 
-    arguments. If related units are found deduced unit strcutures 
+    arguments. If related units are found deduced unit structures 
     are written to the result array and their number is returned.
     The returned deduced unit structures contain references to
     the signal info and the calibration records. This structures
@@ -716,10 +716,10 @@ extern "C" {
     transfer function if supplied and the conversion factor otherwise.
     If a zero frequency data point is supplied, an offset correction
     will be done only if the specified bandwidth is non-zero. The
-    value is subtarcted is then offset/sqrt(bandwidth). If a PSD
+    value is subtracted is then offset/sqrt(bandwidth). If a PSD
     unit of unit^2 or unit^2/Hz is specifed the function will do
     the square. PSD arrays are assumed to be specified in units per 
-    root Hertz. If the desired units are either starigh units or
+    root Hertz. If the desired units are either straight units or
     unit^2, a valid bandwidth must specified.
 
     @memo Calibration correction for frequency domain data
