@@ -65,6 +65,7 @@ fSeries::extend(freq_type fmax) {
 	    mF0 -= double(nNew)*mDf;
 	}
     }
+    mDelta = 0;
 }
 
 //======================================  Extract a subseries.
@@ -102,6 +103,14 @@ fSeries::getFSType(void) const {
 fSeries
 fSeries::interpolate(freq_type fmin, freq_type fmax, freq_type df, 
 		     bool l) const {
+    if (l) return interpolate(fmin, fmax, df, kLog);
+    else   return interpolate(fmin, fmax, df, kLinear);
+}
+    
+//======================================  Resample series
+fSeries
+fSeries::interpolate(freq_type fmin, freq_type fmax, freq_type df, 
+		     FSinterp ityp) const {
 
     //----------------------------------  Set the return series.
     fSeries r(fmin, df, mT0, mDt);
@@ -129,83 +138,172 @@ fSeries::interpolate(freq_type fmin, freq_type fmax, freq_type df,
 	if (refDVect().C_data()) {
 	    DVecType<dComplex> dv(nBin);
 	    const fComplex* p = dynamic_cast<const DVectC&>(*mData).refTData();
-	    for (size_type i=0; i<nBin; ++i) {
-		freq_type f = fmin + df*double(i);
-		if (f < mF0 || f>fHi ) {
-		    dv[i] = dComplex(0);
-		} else {
-		    size_type inx = size_type((f - mF0)/mDf);
-		    freq_type f0  = getBinF(inx);
-		    if (inx == nF) {
-			inx--;
-			f0 -= mDf;
+
+	    switch (ityp) {
+	    case kLinear:
+		for (size_type i=0; i<nBin; ++i) {
+		    freq_type f = fmin + df*double(i);
+		    if (f < mF0 || f>fHi ) {
+			dv[i] = dComplex(0);
+		    } else {
+			size_type inx = size_type((f - mF0)/mDf);
+			freq_type f0  = getBinF(inx);
+			if (inx == nF) {
+			    inx--;
+			    f0 -= mDf;
+			}
+			double a   = (f - f0) / mDf;
+			dv[i] = p[inx]*(1.0-a) + p[inx+1]*a;
 		    }
-		    double a   = (f - f0) / mDf;
-		    if (l) dv[i] = exp(log(p[inx])*(1-a) + log(p[inx+1])*a);
-		    else   dv[i] = p[inx]*(1.0-a) + p[inx+1]*a;
 		}
+		break;
+	    case kLog:
+		for (size_type i=0; i<nBin; ++i) {
+		    freq_type f = fmin + df*double(i);
+		    if (f < mF0 || f>fHi ) {
+			dv[i] = dComplex(0);
+		    } else {
+			size_type inx = size_type((f - mF0)/mDf);
+			freq_type f0  = getBinF(inx);
+			if (inx == nF) {
+			    inx--;
+			    f0 -= mDf;
+			}
+			double a   = (f - f0) / mDf;
+			dv[i] = exp(log(p[inx])*(1-a) + log(p[inx+1])*a);
+		    }
+		}
+		break;
+	    default:
+		throw runtime_error("interpolation method not implemented");
 	    }
 	    r.setData(fmin, df, dv);
 	} else if (refDVect().W_data()) {
 	    DVecType<dComplex> dv(nBin);
 	    const dComplex* p = dynamic_cast<const DVectW&>(*mData).refTData();
-	    for (size_type i=0; i<nBin; ++i) {
-		freq_type f = fmin + df*double(i);
-		if (f < mF0 || f>fHi ) {
-		    dv[i] = dComplex(0);
-		} else {
-		    size_type inx = size_type((f - mF0)/mDf);
-		    freq_type f0  = getBinF(inx);
-		    if (inx == nF) {
-			inx--;
-			f0 -= mDf;
+	    switch (ityp) {
+	    case kLinear:
+		for (size_type i=0; i<nBin; ++i) {
+		    freq_type f = fmin + df*double(i);
+		    if (f < mF0 || f>fHi ) {
+			dv[i] = dComplex(0);
+		    } else {
+			size_type inx = size_type((f - mF0)/mDf);
+			freq_type f0  = getBinF(inx);
+			if (inx == nF) {
+			    inx--;
+			    f0 -= mDf;
+			}
+			double    a   = (f - f0) / mDf;
+			dv[i] = p[inx]*(1.0-a) + p[inx+1]*a;
 		    }
-		    double    a   = (f - f0) / mDf;
-		    if (l) dv[i] = exp(log(p[inx])*(1-a) + log(p[inx+1])*a);
-		    else   dv[i] = p[inx]*(1.0-a) + p[inx+1]*a;
 		}
+		break;
+	    case kLog:
+		for (size_type i=0; i<nBin; ++i) {
+		    freq_type f = fmin + df*double(i);
+		    if (f < mF0 || f>fHi ) {
+			dv[i] = dComplex(0);
+		    } else {
+			size_type inx = size_type((f - mF0)/mDf);
+			freq_type f0  = getBinF(inx);
+			if (inx == nF) {
+			    inx--;
+			    f0 -= mDf;
+			}
+			double    a   = (f - f0) / mDf;
+			dv[i] = exp(log(p[inx])*(1-a) + log(p[inx+1])*a);
+		    }
+		}
+		break;
+	    default:
+		throw runtime_error("interpolation method not implemented");
 	    }
 	    r.setData(fmin, df, dv);
 	} else if (refDVect().D_data()) {
 	    DVectD dv(nBin);
 	    double* dvp = dv.refTData();
 	    const double* p = dynamic_cast<const DVectD&>(*mData).refTData();
-	    for (size_type i=0; i<nBin; ++i) {
-		freq_type f = fmin + df*double(i);
-		if (f < mF0 || f>fHi ) {
-		    dvp[i] = 0.0;
-		} else {
-		    size_type inx = size_type((f - mF0)/mDf);
-		    freq_type f0  = getBinF(inx);
-		    if (inx == nF) {
-			inx--;
-			f0 -= mDf;
+	    switch (ityp) {
+	    case kLinear:
+		for (size_type i=0; i<nBin; ++i) {
+		    freq_type f = fmin + df*double(i);
+		    if (f < mF0 || f>fHi ) {
+			dvp[i] = 0.0;
+		    } else {
+			size_type inx = size_type((f - mF0)/mDf);
+			freq_type f0  = getBinF(inx);
+			if (inx == nF) {
+			    inx--;
+			    f0 -= mDf;
+			}
+			double    a   = (f - f0) / mDf;
+			dvp[i] = p[inx]*(1.0-a) + p[inx+1]*a;
 		    }
-		    double    a   = (f - f0) / mDf;
-		    if (l) dvp[i] = exp(log(p[inx])*(1-a) + log(p[inx+1])*a);
-		    else   dvp[i] = p[inx]*(1.0-a) + p[inx+1]*a;
 		}
+		break;
+	    case kLog:
+		for (size_type i=0; i<nBin; ++i) {
+		    freq_type f = fmin + df*double(i);
+		    if (f < mF0 || f>fHi ) {
+			dvp[i] = 0.0;
+		    } else {
+			size_type inx = size_type((f - mF0)/mDf);
+			freq_type f0  = getBinF(inx);
+			if (inx == nF) {
+			    inx--;
+			    f0 -= mDf;
+			}
+			double    a   = (f - f0) / mDf;
+			dvp[i] = exp(log(p[inx])*(1-a) + log(p[inx+1])*a);
+		    }
+		}
+		break;
+	    default:
+		throw runtime_error("interpolation method not implemented");
 	    }
 	    r.setData(fmin, df, dv);
 	} else {
 	    DVectD dv(nBin);
 	    lcl_array<double> p(nF);
 	    getData(nF, p.get());
-	    for (size_type i=0; i<nBin; ++i) {
-		freq_type f = fmin + df*double(i);
-		if (f < mF0 || f>fHi ) {
-		    dv[i] = 0.0;
-		} else {
-		    size_type inx = size_type((f - mF0)/mDf);
-		    freq_type f0  = getBinF(inx);
-		    if (inx == nF) {
-			inx--;
-			f0 -= mDf;
+	    switch (ityp) {
+	    case kLinear:
+		for (size_type i=0; i<nBin; ++i) {
+		    freq_type f = fmin + df*double(i);
+		    if (f < mF0 || f>fHi ) {
+			dv[i] = 0.0;
+		    } else {
+			size_type inx = size_type((f - mF0)/mDf);
+			freq_type f0  = getBinF(inx);
+			if (inx == nF) {
+			    inx--;
+			    f0 -= mDf;
+			}
+			double a   = (f - f0) / mDf;
+			dv[i] = p[inx]*(1.0-a) + p[inx+1]*a;
 		    }
-		    double a   = (f - f0) / mDf;
-		    if (l) dv[i] = exp(log(p[inx])*(1-a) + log(p[inx+1])*a);
-		    else   dv[i] = p[inx]*(1.0-a) + p[inx+1]*a;
 		}
+		break;
+	    case kLog:
+		for (size_type i=0; i<nBin; ++i) {
+		    freq_type f = fmin + df*double(i);
+		    if (f < mF0 || f>fHi ) {
+			dv[i] = 0.0;
+		    } else {
+			size_type inx = size_type((f - mF0)/mDf);
+			freq_type f0  = getBinF(inx);
+			if (inx == nF) {
+			    inx--;
+			    f0 -= mDf;
+			}
+			double a   = (f - f0) / mDf;
+			dv[i] = exp(log(p[inx])*(1-a) + log(p[inx+1])*a);
+		    }
+		}
+		break;
+	    default:
+		throw runtime_error("interpolation method not implemented");
 	    }
 	    r.setData(fmin, df, dv);
 	}
