@@ -21,27 +21,31 @@ using namespace std;
 
 PSD::PSD(const window_api *win_choice, int intervals)
 {
-        n = intervals;
-        if (win_choice) win = win_choice->clone();
-	else            win = 0;
+    n = intervals;
+    if (win_choice) win = win_choice->clone();
+    else            win = 0;
+    overlap = 0;
 }
 
 PSD::PSD(const char *square, int intervals)
 {
-        n = intervals;
-        win = 0;
+    n = intervals;
+    win = 0;
+    overlap = 0;
 }
 
 PSD::PSD(int intervals)
 {
-	n = intervals;
-	win = new Hamming;
+    n = intervals;
+    win = new Hamming;
+    overlap = 0;
 }
 
 PSD::PSD(void)
 {
-	n = 1;
-	win = new Hamming;
+    n = 1;
+    win = new Hamming;
+    overlap = 0;
 }
 
 PSD::~PSD(void)
@@ -54,7 +58,9 @@ PSD::generate(FSpectrum& total, const TSeries* ts)
 {
     // Divide TSeries interval into n sub-intervals of equal length
     Interval seg_length = ts->getInterval();
-    seg_length /= double(n);
+    // seg_length /= double(n);
+    seg_length /= n*(1 - overlap) + overlap;
+    Interval time_inc = seg_length * (1.0 - overlap);
     Time t_zero = ts->getStartTime();
 
     // Test to determine if seg_length is an integer.  If not, display
@@ -66,8 +72,11 @@ PSD::generate(FSpectrum& total, const TSeries* ts)
     }
 
     // Set window length
-    if(win) win->setWindow((int)((double)seg_length));
-
+    if (win) {
+	size_t win_size = size_t(seg_length / ts->getTStep() + 0.5);
+	win->setWindow(win_size);
+    }
+    
     // Extract data starting with t_zero and lasting for seg_length
     TSeries sub_series(ts->extract(t_zero, seg_length));
 
@@ -79,7 +88,7 @@ PSD::generate(FSpectrum& total, const TSeries* ts)
     total = FSpectrum(FSeries(sub_series));
 
     // Increment t_zero
-    t_zero += seg_length;
+    t_zero += time_inc;
 
     // Loop to divide TSeries into n sub-series
     for(int i = 1; i < n; i++) {
@@ -94,7 +103,7 @@ PSD::generate(FSpectrum& total, const TSeries* ts)
 	total += FSpectrum(FSeries(sub_series));
 
 	// Increment t_zero
-	t_zero += seg_length;
+	t_zero += time_inc;
     }
 
     // Normalize to mean power per data point
@@ -106,7 +115,10 @@ void
 PSD::generate(FSpectrum& total, const TSeries* ts, FDFilter& fd) {
     // Divide TSeries interval into n sub-intervals of equal length
     Interval seg_length = ts->getInterval();
-    seg_length /= double(n);
+    // seg_length /= double(n);
+    seg_length /= n*(1 - overlap) + overlap;
+    Interval time_inc = seg_length * (1.0 - overlap);
+
     Time t_zero = ts->getStartTime();
 
     // Test to determine if seg_length is an integer.  If not, display
@@ -118,20 +130,23 @@ PSD::generate(FSpectrum& total, const TSeries* ts, FDFilter& fd) {
     }
 
     // Set window length
-    if(win) win->setWindow((int)((double)seg_length));
+    if (win) {
+	size_t win_size = size_t(seg_length / ts->getTStep() + 0.5);
+	win->setWindow(win_size);
+    }
 
     // Extract data starting with t_zero and lasting for seg_length
     TSeries sub_series(ts->extract(t_zero, seg_length));
 
     // Detrend, window sub_series
     sub_series -= sub_series.getAverage();
-    if(win) sub_series = win->apply(sub_series);
+    if (win) sub_series = win->apply(sub_series);
 
     // Add to running total for power spectrum
     total = FSpectrum(fd.Apply(FSeries(sub_series)));
 
     // Increment t_zero
-    t_zero += seg_length;
+    t_zero += time_inc;
 
     // Loop to divide TSeries into n sub-series
     for(int i=1; i < n; i++) {
@@ -146,7 +161,7 @@ PSD::generate(FSpectrum& total, const TSeries* ts, FDFilter& fd) {
 	total += FSpectrum(fd.Apply(FSeries(sub_series)));
 
 	// Increment t_zero
-	t_zero += seg_length;
+	t_zero += time_inc;
     }
 
     // Normalize to mean power per data point
@@ -157,8 +172,10 @@ void
 PSD::generate(containers::PSD& total, const TSeries* ts) {
     // Divide TSeries interval into n sub-intervals of equal length
     Interval seg_length = ts->getInterval();
-    seg_length /= double(n);
+    // seg_length /= double(n);
+    seg_length /= n*(1 - overlap) + overlap;
     Time t_zero = ts->getStartTime();
+    Interval time_inc = seg_length * (1.0 - overlap);
 
     // Test to determine if seg_length is an integer.  If not, display
     // possible error message
@@ -169,7 +186,10 @@ PSD::generate(containers::PSD& total, const TSeries* ts) {
     }
 
     // Set window length
-    if(win) win->setWindow((int)((double)seg_length));
+    if (win) {
+	size_t win_size = size_t(seg_length / ts->getTStep() + 0.5);
+	win->setWindow(win_size);
+    }
 
     // Extract data starting with t_zero and lasting for seg_length
     TSeries sub_series(ts->extract(t_zero, seg_length));
@@ -182,7 +202,7 @@ PSD::generate(containers::PSD& total, const TSeries* ts) {
     total = containers::PSD(sub_series);
 
     // Increment t_zero
-    t_zero += seg_length;
+    t_zero += time_inc;
 
     // Loop to divide TSeries into n sub-series
     for(int i=1; i < n; i++) {
@@ -197,9 +217,15 @@ PSD::generate(containers::PSD& total, const TSeries* ts) {
 	total += containers::PSD(sub_series);
 
 	// Increment t_zero
-	t_zero += seg_length;
+	t_zero += time_inc;
     }
 
     // Normalize to mean power per data point
     if (n > 1) total *= 1.0 / double(n);
 }
+
+//======================================  Set overlap
+void
+PSD::set_overlap(double ovlp) {
+    overlap = ovlp;
+}
