@@ -28,8 +28,8 @@ int
 main(int argc, const char* argv[]) {
     DMTGen myPgm(argc, argv);
     if (!myPgm.configured()) return 1;
-    myPgm.generate();
-    return 0;
+    int rc = myPgm.generate();
+    return rc;
 }
 
 //======================================  Test file readable.
@@ -40,8 +40,9 @@ testRead(const std::string& file) {
 
 //======================================  Constructor
 DMTGen::DMTGen(int argc, const char* argv[]) 
-    : mConfigured(false), mWriteMode(kFile), mWriter("DMTGen", mRunID), 
-      mVerbStat(0), mDebug(0), mNFramesGen(0), mNFramesOut(0), mRealTime(false)
+    : mConfigured(false), mWriteMode(kFile), mRunID(-666),
+      mWriter("DMTGen", mRunID), mVerbStat(0), mDebug(0),
+      mNFramesGen(0), mNFramesOut(0), mRealTime(false)
 {
     //----------------------------------  Initialize 
     DataSource::init_dict(mSourceDict);
@@ -791,7 +792,7 @@ DMTGen::readConfig(const std::string& file) {
 }
 
 //======================================  Generate the data.
-void
+int
 DMTGen::generate(void) {
     //
 
@@ -808,7 +809,7 @@ DMTGen::generate(void) {
 	    cerr << "Exception: " << e.what() 
 		 << " caught while generating data for gps " << now.getS()
 		 << "-" << (now+dtGen).getS() << endl;
-	    return;
+	    return 2;
 	}
 	if (mDebug) cout << "Data generated to " << mGener.getLatest().getS()
 			 << endl;
@@ -844,6 +845,7 @@ DMTGen::generate(void) {
 	mGener.releaseSourceData(writeTime);
 	mGener.releaseChannelData(writeTime);
     }
+    return 0;
 }
 
 //======================================  Write generated data
