@@ -248,7 +248,7 @@ namespace generator {
 	  int len  = mSeries.getBin(mTrigEnd) - inx0;
 	  TSeries source_ts;
 	  getSourceTSeries(mSeries.getBinT(inx0), tStep, len, source_ts);
-	  mSeries += source_ts;
+	  mSeries.add_overlap(source_ts);
 
 	  //----------------------------  Save the source data.
 	  if (getSaveFlag()) {
