@@ -2,7 +2,6 @@ R__EXTERN Dacc In;
 
 Dacc In;
 
-
 void
 openDacc(void) {
    //----------------------------------  Create a data access object.
@@ -16,3 +15,8 @@ openDacc(void) {
 	   << endl;
    }
 }
+
+void
+closeDacc(void) {
+   In.close();
+}
