@@ -1,6 +1,6 @@
 // Yo, Emacs! This is -*- mode: C++; c-basic-offset: 4;  -*-
 //
-// $Id: OperStateCondList.cc 7524 2015-11-19 01:18:08Z ed.maros@LIGO.ORG $
+// $Id: OperStateCondList.cc 7941 2017-10-04 02:22:45Z john.zweizig@LIGO.ORG $
 //
 // Author: David Chin <dwchin@umich.edu>
 //
@@ -71,6 +71,7 @@
 #include "osc/TransitUp.hh"
 #include "osc/TransitDown.hh"
 
+#include "osc/TestParity.hh"
 
 using namespace std;
 using namespace osc;
@@ -276,6 +277,10 @@ OperStateCondList::OperStateCondList(DaccAPI& dataAccess,
     fractpowerfallPIM["threshold"] = osc::ParamInfo(osc::DOUBLE, false);
     fractpowerfallPIM["nstrides"] = osc::ParamInfo(osc::INT, true, 1, 0.);
 
+    // FRACTPOWERFALL
+    osc::ParamInfoMap testparityPIM;
+    fractpowerfallPIM["value"] = osc::ParamInfo(osc::INT, false);
+
     // DEBUG
     if (mDebug > 2) {
         cout << "OperStateCondList: constructing (debug level "
@@ -417,6 +422,7 @@ OperStateCondList::OperStateCondList(DaccAPI& dataAccess,
     mTypeInfoMap["abspowergain"] = osc::TypeInfo(abspowergainPIM, true);
     mTypeInfoMap["fractpowerrise"] = osc::TypeInfo(fractpowerrisePIM, true);
     mTypeInfoMap["fractpowerfall"] = osc::TypeInfo(fractpowerfallPIM, true);
+    mTypeInfoMap["testparity"] = osc::TypeInfo(testparityPIM, true);
 
     if (mDebug > 1) {
         cout << "OperStateCondList(): mTypeInfoMap.size() = "
@@ -1234,6 +1240,16 @@ void OperStateCondList::readConfig(std::string filename)
                                                dblParams, mDebug);
                         
                     }
+		    else if (osc::stringCaseCmp(typeName,"testparity")) {
+
+                        incrChanUtilMaybe(chanName);
+
+                        (*this)[oscName] =
+                            new TestParity(&mDataAccess, pmOutstream,
+					  chanName, intParams,
+					  dblParams, mDebug);
+                        
+                    }
                 } // if ((int)nParams...) ... else ...
                 
             } else { // NOT atomic OSC type
