@@ -1,4 +1,4 @@
-/* Version $Id: awg_server.c 6507 2011-10-13 20:17:10Z john.zweizig@LIGO.ORG $ */
+/* Version $Id: awg_server.c 7989 2018-01-12 23:13:45Z john.zweizig@LIGO.ORG $ */
 /*----------------------------------------------------------------------*/
 /*                                                         		*/
 /* Module Name: awg_server						*/
@@ -955,6 +955,7 @@ extern int testpoint_manager_rpc;
 #ifdef _ADVANCED_LIGO
       char		section[30];	/* section name */
 #endif
+      char              addr_tmp[32];
 
       /* test if low level init */
       gdsDebug ("start awg server client");
@@ -1033,12 +1034,14 @@ extern int testpoint_manager_rpc;
       /* add configuration info */
 #ifdef GDS_UNIX_TARGET
       sprintf (confbuf, "awg %i 0 %s %ld %ld",
-              testpoint_manager_node,
-              inet_ntoa (host), prognum, progver);
+	       testpoint_manager_node,
+	       inet_ntop(AF_INET, &host, addr_tmp, sizeof(addr_tmp)),
+	       prognum, progver);
 #else
       sprintf (confbuf, "awg %i 0 %s %ld %ld",
-              ((IFO != GDS_IFO2) ? 0 : 1),
-              inet_ntoa (host), prognum, progver);
+	       ((IFO != GDS_IFO2) ? 0 : 1),
+	       inet_ntop(AF_INET, &host, addr_tmp, sizeof(addr_tmp)),
+	       prognum, progver);
 #endif
       conf.id = 0;
       conf.answer = stdAnswer;
