@@ -1,4 +1,4 @@
-/* Version $Id: awgtype.h 7192 2014-10-10 17:14:03Z james.batch@LIGO.ORG $ */
+/* Version $Id: awgtype.h 7990 2018-01-13 01:32:22Z john.zweizig@LIGO.ORG $ */
 /*----------------------------------------------------------------------*/
 /*                                                         		*/
 /* Module Name: awgtype							*/
@@ -641,7 +641,9 @@ extern "C" {
    /** arbitrary waveform */
    awgArb	= 9,
    /** stream waveform */
-   awgStream	= 10
+   awgStream	= 10,
+   /** type 11 used internally (log sweep?) */
+   awgWave11    = 11
    };
    typedef enum AWG_WaveType AWG_WaveType;
 
