@@ -1,4 +1,4 @@
-/* Version $Id: excitation.cc 6465 2011-07-08 20:50:29Z james.batch@LIGO.ORG $ */
+/* Version $Id: excitation.cc 7990 2018-01-13 01:32:22Z john.zweizig@LIGO.ORG $ */
 /* -*- mode: c++; c-basic-offset: 3; -*- */
 /*----------------------------------------------------------------------*/
 /*                                                         		*/
@@ -31,6 +31,7 @@ namespace diag {
    using namespace std;
    using namespace thread;
 
+   static int my_debug = 0 ;
 
    const double excitation::syncDelay = 0.20; // sec
    const double excitation::syncUncertainty = 0.25; // sec
@@ -41,6 +42,8 @@ namespace diag {
    : chnname (""), channeltype (invalid), writeaccess (false), 
    wait (Wait), slot (-1), inUse (1), isTP (false)
    {
+      if (my_debug) cerr << "excitation::excitation(" << Chnname
+			 << ", Wait = " << Wait << ")" << endl ;
       setup (Chnname);
    }
 
@@ -115,6 +118,9 @@ namespace diag {
    {
       semlock		lockit (mux);
    
+      if (my_debug) cerr << "excitation::setup( channel=" << Chnname << ")"
+			 << endl ;
+
       if ((channeltype != invalid) && (slot >= 0)) {
          awgRemoveChannel (slot);
       }
@@ -153,10 +159,14 @@ namespace diag {
          channeltype = testpoint;
          writeaccess = true;
          slot = awgSetChannel (chnname.c_str());
+	 if (my_debug) cerr << "excitation::setup() return slot=" << slot
+			    << endl ;
          return (slot >= 0);
       }
       // not a valid channel
       else {
+	 if (my_debug) cerr << "excitation::setup() return invalid slot"
+			    << endl ;
          return false;
       }
    }
@@ -166,19 +176,29 @@ namespace diag {
    {
       semlock		lockit (mux);
    
+      if (my_debug) cerr << "excitation::add( AWG_Component )" << endl ;
+
       if ((channeltype == invalid) || 
          (!capability (output))) {
+         if (my_debug) cerr << "excitation::add() return false, line "
+			    << __LINE__ << endl ;
          return false;
       }
       /* check for valid waveform component */
       if (comp.wtype == awgNone) {
+         if (my_debug) cerr << "excitation::add() return true, line "
+			    << __LINE__ << endl ;
          return true;
       }
       if (awgIsValidComponent (&comp) == 0) {
+         if (my_debug) cerr << "excitation::add() return false, line "
+			    << __LINE__ << endl ;
          return false;
       }
       if (!capability (multiplewaveforms) &&
          (signals.size() > 0)) {
+         if (my_debug) cerr << "excitation::add() return false, line "
+			    << __LINE__ << endl ;
          return false;
       }
       if (!capability (periodicsignal) && 
@@ -187,11 +207,15 @@ namespace diag {
          (comp.wtype == awgRamp) ||
          (comp.wtype == awgTriangle) ||
          (comp.wtype == awgImpulse))) {
+         if (my_debug) cerr << "excitation::add() return false, line "
+			    << __LINE__ << endl ;
          return false;
       }
       if (!capability (randomsignal) && 
          ((comp.wtype == awgNoiseN) ||
          (comp.wtype == awgNoiseU))) {
+         if (my_debug) cerr << "excitation::add() return false, line "
+			    << __LINE__ << endl ;
          return false;
       }
       /* make sure valid parameters for non-AWG devices */
@@ -206,6 +230,15 @@ namespace diag {
          c.ramptime[1] = 0;	
       }
       /* add waveform */
+      if (my_debug) {
+         cerr << "  c.start = " << (c.start / _ONESEC) << '.'
+	      << (c.start % _ONESEC) << endl ;
+         cerr << "  c.duration = " << c.duration << endl ;
+         cerr << "  c.restart = " << c.restart << endl ;
+         cerr << "  c.ramptime[0] = " << c.ramptime[0] << endl ;
+         cerr << "  c.ramptime[1] = " << c.ramptime[1] << endl ;
+         cerr << "excitation::add() return true" << endl ;
+      }
       signals.push_back (c);
       return true;
    }
@@ -213,7 +246,9 @@ namespace diag {
 
    bool excitation::add (const pointlist& Points)
    {
+      if (my_debug) cerr << "excitation::add( pointlist )" << endl ;
       points = Points;
+      if (my_debug) cerr << "excitation::add() return" << endl ;
       return true;
    }
 
@@ -221,11 +256,13 @@ namespace diag {
    bool excitation::add (const_sigiterator begin, 
                      const_sigiterator end) 
    {
+      if (my_debug) cerr << "excitation::add( sigiterator )" << endl ;
       for (const_sigiterator iter = begin; iter != end; iter++) {
          if (!add (*iter)) {
             return false;
          }
       }
+      if (my_debug) cerr << "excitation::add() return" << endl ;
       return true;
    }
 
@@ -234,35 +271,52 @@ namespace diag {
    {
       double dwell = wait;
    
+      if (my_debug) cerr << "excitation::dwellTime() for channel "
+			 << chnname << endl ;
+      if (my_debug) cerr << "  wait = " << wait << endl ;
+
       /* add uncertainly for no GPS units */
       if (capability (GPSsync)) {
+	 if (my_debug) cerr << "  dwell += syncDelay, syncDelay = "
+			    << syncDelay << endl;
          dwell += syncDelay;
       }
       else {
+	 if (my_debug) cerr << "  dwell += syncUncertainty, syncUncertainty = "
+			    << syncUncertainty << endl ;
          dwell += syncUncertainty;
       }
       /* estimate download time for arbitrary waveform */
       if (capability (waveform) && !points.empty()) {
          switch (channeltype) {
             case DSG : 
-               dwell += sizeof (short) * points.size() / linkSpeed[2]; 
+               dwell += sizeof (short) * points.size() / linkSpeed[1]; 
                break;
             case testpoint:
             case DAC:
-               dwell += sizeof (float) * points.size() / linkSpeed[1];
+               dwell += sizeof (float) * points.size() / linkSpeed[0];
                break;
             default:
                break;
          }
       }
+      if (my_debug) {
+	cerr << "excitation::dwellTime() return dwell = " << dwell << endl;
+      }
       return dwell;
    }
 
 
-   bool excitation::start (tainsec_t start, tainsec_t timeout)
+   bool excitation::start (tainsec_t start, tainsec_t timeout, tainsec_t rampup)
    {
       semlock		lockit (mux);
    
+      if (my_debug) {
+	 cerr << "excitation::start( start=" << start << 
+		  ", timeout=" << timeout << ", rampup=" << 
+		  rampup << ")" << endl ;
+      }
+
       if ((channeltype == invalid) || 
          (!capability (output))) {
          return 0;
@@ -283,11 +337,23 @@ namespace diag {
             iter->start += dt;
          }
       }
+      /* Adjust for ramp up time. */
+      if (rampup > 0) {
+	 if (my_debug) cerr << "  excitation::start(), applying rampup to signallist" << endl ;
+	 for (signallist::iterator iter = signals.begin() ;
+	       iter != signals.end(); iter++) {
+	    iter->start += rampup ;
+	 }
+      }
+      else
+	 if (my_debug) cerr << "  excitation::start(), rampup == 0" << endl ;
+
    
       /* download waveform points */
       if ((channeltype == testpoint) || (channeltype == DAC) ||
          (channeltype == DSG)) {
          if (!points.empty()) {
+	    if (my_debug) cerr << "  excitation::start(), call awgSetWaveform()" << endl ;
             if (awgSetWaveform (slot, &(*points.begin()), points.size()) < 0) {
                return false;
             }
@@ -340,12 +406,19 @@ namespace diag {
          case testpoint:
          case DAC:
             {
-               cerr << "download " << signals.size() << endl;
-               for (const_sigiterator iter = signals.begin();
-                   iter != signals.end(); iter++) {
-                  cerr << "   start = " << (double)(iter->start % (100*_ONESEC))/1E9;
-                  cerr << "   durat = " << (double)iter->duration/1E9 << endl;
-               }
+	       if (my_debug) {
+		  cerr << "switch on excitation, signals.size = " << signals.size() << endl;
+		  for (const_sigiterator iter = signals.begin();
+		      iter != signals.end(); iter++) {
+		     cerr << "   start = " << (double)(iter->start % (100*_ONESEC))/1E9;
+		     cerr << "   durat = " << (double)iter->duration/1E9 << endl;
+		     cerr << "   wtype = " << (int)(iter->wtype) << endl ;
+		     cerr << "   restart = " << (double)(iter->restart) << endl ;
+		     cerr << "   ramptype = " << (int)(iter->ramptype) << endl ;
+		     cerr << "   ramptime[0] = " << (int)(iter->ramptime[0]) << endl ;
+		     cerr << "   ramptime[1] = " << (int)(iter->ramptime[1]) << endl ;
+		  }
+	       }
                if (awgAddWaveform (slot, &(*signals.begin()),
                                   signals.size()) < 0) {
                   return false;
@@ -357,6 +430,7 @@ namespace diag {
                return false;
             }
       }
+      if (my_debug) cerr << "excitation::start() return true" << endl ;
       return true;
    }
 
@@ -365,6 +439,7 @@ namespace diag {
    {
       semlock		lockit (mux);
    
+      if (my_debug) cerr << "excitation::stop( timeout=" << timeout << ", ramptime=" << ramptime << ")" << endl ;
       if (slot < 0) {
          return true;
       }
@@ -387,16 +462,20 @@ namespace diag {
          case DAC:
             if (ramptime <= 0) {
                if (awgClearWaveforms (slot) < 0) {
+		  if (my_debug) cerr << "excitation::stop() return false line " << __LINE__ << endl ;
                   return false;
                }
             }
             else {
                if (awgStopWaveform (slot, 2, ramptime) < 0) {
+		  if (my_debug) cerr << "excitation::stop() return false line " << __LINE__ << endl ;
                   return false;
                }
             }
+	    if (my_debug) cerr << "excitation::stop() return true line " << __LINE__ << endl ;
             return true;
          default:
+	    if (my_debug) cerr << "excitation::stop() return true line " << __LINE__ << endl ;
             return true;
       }
    }
@@ -495,6 +574,7 @@ namespace diag {
    bool excitationManager::init (testpointMgr& TPMgr,
                      bool Silent, tainsec_t rdown)
    {
+      if (my_debug) cerr << "excitationManager::init(..., rdown=" << rdown << ")" << endl ;
       tpMgr = &TPMgr;
       silent = Silent;
       rampdown = rdown;
@@ -502,8 +582,12 @@ namespace diag {
    }
 
 
-   bool excitationManager::start (tainsec_t start, tainsec_t timeout)
+   bool excitationManager::start (tainsec_t start, tainsec_t timeout, 
+				 tainsec_t rampup)
    {
+      if (my_debug) cerr << "excitationManager::start(start=" << 
+			      start << ", timeout=" << timeout <<
+			      ", rampup=" << rampup << ")" << endl ;
       if (silent) {
          return true;
       }
@@ -517,16 +601,19 @@ namespace diag {
    
       for (excitationlist::iterator iter = excitations.begin();
           iter != excitations.end(); iter++) {
-         if (!iter->start (start, timeout)) {
+         if (!iter->start (start, timeout, rampup)) {
             err = true;
          }
       }
+      if (my_debug) cerr << "excitationManager::start() return " << (err ? "false" : "true") << endl ;
       return !err;
    }
 
 
    bool excitationManager::stop (tainsec_t timeout, tainsec_t ramptime)
    {
+      if (my_debug) cerr << "excitationManager::stop(timeout=" << timeout << 
+			      ", ramptime=" << ramptime << ")" << endl ;
       if (silent) {
          return true;
       }
@@ -540,6 +627,7 @@ namespace diag {
             err = true;
          }
       }
+      if (my_debug) cerr << "excitationManager::stop() return " << (err ? "false" : "true") << endl ;
       return !err;
    }
 
@@ -564,6 +652,7 @@ namespace diag {
 
    bool excitationManager::add (const string& channel)
    {
+      if (my_debug) cerr << "excitationManager::add(channel=" << channel << ")" << endl ;
       if (silent) {
          return true;
       }
@@ -597,6 +686,7 @@ namespace diag {
       
          iter = excitations.end();
       }
+      if (my_debug) cerr << "excitationManager::add() return true" << endl ;
       return true;
    }
 
@@ -605,6 +695,9 @@ namespace diag {
                      const string& waveform,
                      double settlingtime)
    {
+      if (my_debug) cerr << "excitationManager::add(channel=" << channel << 
+			", waveform=" << waveform << ", settlingtime=" << 
+			settlingtime << ")" << endl ;
       if (silent) {
          return true;
       }
@@ -666,6 +759,7 @@ namespace diag {
          }
       }
    
+      if (my_debug) cerr << "excitationManager::add() return true" << endl ;
       return true;
    }
 
@@ -673,6 +767,8 @@ namespace diag {
    bool excitationManager:: add (const string& channel,
                      const std::vector<AWG_Component>& awglist)
    {
+      if (my_debug) cerr << "excitationManager::add(channel=" << channel << 
+			", <vector of AWG_Component)" << endl ;
       if (silent) {
          return true;
       }
@@ -711,6 +807,7 @@ namespace diag {
       if (!iter->add (awglist.begin(), awglist.end())) {
          return false;
       }
+      if (my_debug) cerr << "excitationManager::add() return true" << endl ;
       return true;
    }
 
@@ -790,6 +887,7 @@ namespace diag {
 
    bool excitationManager::del (tainsec_t timeout)
    {
+      if (my_debug) cerr << "excitationManager::del(timeout=" << timeout << ")" << endl ;
       if (silent) {
          return true;
       }
@@ -815,12 +913,14 @@ namespace diag {
          }
       }
       excitations.clear();
+      if (my_debug) cerr << "excitationManager::del() return" << endl ;
       return true;
    }
 
 
    double excitationManager::dwellTime () const
    {
+      if (my_debug) cerr << "excitationManager::dwellTime()" << endl ;
       if (silent) {
          return 0;
       }
@@ -832,6 +932,7 @@ namespace diag {
           iter != excitations.end(); iter++) {
          dwell = max (dwell, iter->dwellTime());
       }
+      if (my_debug) cerr << "excitationManager::dwellTime() return " << dwell << endl ;
       return dwell;
    }
 
