@@ -120,7 +120,6 @@ so that you can load the libawg.so and libtestpoint.so shared objects.
 static int SIStrInit(SIStream * sis);
 static int SIStrCreateBuf(SIStream * sis);
 static int SIStrSend(SIStream * sis, int flushflag);
-static int SIStrLog(SIStream * sis, char *condition, int value);
 
 
 /*====== Global variables for internal use =================================*/
@@ -377,18 +376,6 @@ int SIStrOpen(SIStream * sis, char *channel, int samprate,
     }
     sis->comp = 1;
 
-#ifndef DISABLEAWG
-    /* Append a line to the central log */
-    /* If this fails, cancel the injection! We don't want to allow injections
-       without a believable log file! */
-    status = SIStrLog(sis, "start", 0);
-    if (status != 0) {
-	fprintf(stderr,
-		"Aborting Logging because SIStrLog call failed %d\n",
-		status);
-    }
-#endif
-
     return SIStr_OK;
 }
 
@@ -1126,14 +1113,6 @@ int SIStrCleanup(SIStream * sis)
 	}
 	sis->slot = 0;
     }
-#ifndef DISABLEAWG
-    /* If an error occurred, log it */
-    if (retval != SIStr_OK)
-	SIStrLog(sis, "error", retval);
-
-    /* Append a line to the central log */
-    SIStrLog(sis, "stop", 0);
-#endif
 
     return retval;
 }
@@ -1183,133 +1162,6 @@ int SIStrAbort(SIStream * sis)
 }
 
 
-/*==========================================================================*/
-static int SIStrLog(SIStream * sis, char *condition, int value)
-{
-    char infoline[512];
-    char hostname[64];
-    FILE *file;
-    tainsec_t now_ns;
-
-  /*------ Beginning of code ------*/
-
-    if (sis == NULL) {
-	return -1;
-    }
-    if (sis->magic != SIStr_MAGICVAL) {
-	return -2;
-    }
-
-  /*------ Construct the message ------*/
-
-    if (gethostname(hostname, 64)) {
-	return -3;
-    }
-
-    if (strcmp(condition, "start") == 0) {
-	sprintf(infoline, "%17.6f %s start %s %d %d %s", sis->starttime,
-		sis->channel, hostname, getpid(), sis->id, SIStr_appInfo);
-    } else if (strcmp(condition, "error") == 0) {
-	sprintf(infoline, "%17.6f %s error %s %d %d %d",
-		(double) sis->curgps + (double) sis->curepoch / 16.0,
-		sis->channel, hostname, getpid(), sis->id, value);
-    } else {
-	now_ns = TAInow();
-	sprintf(infoline, "%10d.%06d %s %-5s %s %d %d",
-		(int) (now_ns / 1000000000LL),
-		(int) (now_ns % 1000000000LL) / 1000, sis->channel,
-		condition, hostname, getpid(), sis->id);
-    }
-
-  /*------ Write out the message ------*/
-#define LOG_BY_DATE 1
-    file = NULL;
-    /* See if the log directory /ligo/logs/<ifo> exists */
-    {
-	struct stat statbuf;
-	mode_t mode = S_IRUSR | S_IRGRP | S_IROTH |
-	    S_IXUSR | S_IXGRP | S_IXOTH | S_IWUSR | S_IWGRP ;
-	/* Test for /ligo */
-	if ((stat("/ligo", &statbuf) == 0) && S_ISDIR(statbuf.st_mode)) {
-	    /* Test for /ligo/logs or attempt to make it. */
-	    if (((stat("/ligo/logs", &statbuf) == 0) && S_ISDIR(statbuf.st_mode)) || (mkdir("/ligo/logs", mode) == 0)) 
-	    {
-		char dirbuf[64];
-		char *ifo = getenv("ifo");
-
-		if (ifo == NULL) {
-		    return -1;
-		}
-		/* Test for /ligo/logs/<ifo> or attempt to make it. */
-		sprintf(dirbuf, "/ligo/logs/%2s", ifo);
-		if (((stat(dirbuf, &statbuf) == 0) && S_ISDIR(statbuf.st_mode)) || (mkdir(dirbuf, mode) == 0)) 
-	        {
-#ifdef LOG_BY_DATE
-		    /* Test for /ligo/logs/<ifo>/injection_log/ or attempt to make it. */
-		    sprintf(dirbuf, "/ligo/logs/%2s/injection_log", ifo) ;
-		    if (((stat(dirbuf, &statbuf) == 0) && S_ISDIR(statbuf.st_mode)) || (mkdir(dirbuf, mode) == 0)) 
-		    {
-			/* Get the date, month, and day to use for directories and file name. */
-			time_t	t ;
-			struct tm *utc ;
-			t = time((time_t *) NULL) ;
-			if (t < 0) 
-			{
-			    fprintf(stderr, "Unable to get time.\n") ;
-			} 
-			else 
-			{
-			    utc = gmtime(&t) ;
-			    /* The directories under /ligo/logs/<ifo>/injection_log/ will be */
-			    /* yyyy/mm/dd/ */
-			    sprintf(dirbuf, "/ligo/logs/%2s/injection_log/%4d", ifo, utc->tm_year+1900) ;
-			    if (((stat(dirbuf, &statbuf) == 0) && S_ISDIR(statbuf.st_mode)) || mkdir(dirbuf, mode) == 0) 
-			    {
-				/* Try the /ligo/logs/<ifo>/injection_log/<yyyy>/<mm> directory */
-				sprintf(dirbuf, "/ligo/logs/%2s/injection_log/%4d/%2.2d", ifo, utc->tm_year+1900, utc->tm_mon+1) ;
-				if (((stat(dirbuf, &statbuf) == 0) && S_ISDIR(statbuf.st_mode)) || mkdir(dirbuf, mode) == 0) 
-				{
-				    sprintf(dirbuf, "/ligo/logs/%2s/injection_log/%4d/%2.2d/%2.2d", ifo, utc->tm_year+1900, utc->tm_mon+1, utc->tm_mday) ;
-				    if (((stat(dirbuf, &statbuf) == 0) && S_ISDIR(statbuf.st_mode)) || mkdir(dirbuf, mode) == 0) 
-				    {
-					sprintf(dirbuf, "/ligo/logs/%2s/injection_log/%4d/%2.2d/%2.2d/injection.txt",  ifo, utc->tm_year+1900, utc->tm_mon+1, utc->tm_mday) ;
-					file = fopen(dirbuf, "a") ;
-				    }
-				} 
-			    }		
-			} 
-		    } 
-#else
-		    /* All is good, log the event in /ligo/logs/<ifo>/injection_log.txt */
-		    sprintf(dirbuf, "/ligo/logs/%2s/injection_log.txt",
-			    ifo);
-		    file = fopen(dirbuf, "a");
-#endif
-		} else {
-		    fprintf(stderr, "stat of %s failed\n", dirbuf);
-		}
-	    } else {
-		fprintf(stderr, "stat of /ligo/logs failed\n");
-	    }
-	} else {
-	    fprintf(stderr, "stat of /ligo failed\n");
-	}
-    }
-
-    if (file == NULL) {
-	fprintf(stderr, "Warning, couldn't open log file\n");
-	return -4;
-    }
-
-  /*-- Write the line of information --*/
-    fprintf(file, "%s\n", infoline);
-
-  /*-- Close the file and return --*/
-    fclose(file);
-    return 0;
-}
-
-
 /*==========================================================================*/
 char *SIStrErrorMsg(int status)
      /* Returns a pointer to a char array containing the error message for
