@@ -1,4 +1,4 @@
-VCSID("@(#)$Id: gdsmsg_server.c 7338 2015-04-14 23:24:47Z ed.maros@LIGO.ORG $");
+VCSID("@(#)$Id: gdsmsg_server.c 7989 2018-01-12 23:13:45Z john.zweizig@LIGO.ORG $");
 
 /*----------------------------------------------------------------------*/
 /*                                                         		*/
@@ -391,8 +391,7 @@ VCSID("@(#)$Id: gdsmsg_server.c 7338 2015-04-14 23:24:47Z ed.maros@LIGO.ORG $");
    #ifdef OS_VXWORKS
       inet_ntoa_b (addr_cb, cbname);
    #else
-      strncpy (cbname, inet_ntoa (addr_cb), sizeof (cbname));
-      cbname[sizeof(cbname)-1] = 0;
+      inet_ntop(AF_INET, &addr_cb, cbname, sizeof(cbname));
    #endif
       /* create client handle */
       clnt = clnt_create (cbname, prognum_cb, progver_cb, _NETID);
