@@ -1,4 +1,4 @@
-VCSID("@(#)$Id: gdschannel.c 7338 2015-04-14 23:24:47Z ed.maros@LIGO.ORG $");
+VCSID("@(#)$Id: gdschannel.c 7962 2017-11-11 01:42:45Z john.zweizig@LIGO.ORG $");
 
 /*----------------------------------------------------------------------*/
 /*                                                         		*/
@@ -60,6 +60,7 @@ VCSID("@(#)$Id: gdschannel.c 7338 2015-04-14 23:24:47Z ed.maros@LIGO.ORG $");
 #include "dtt/hardware.h"
 #include "dtt/gdsutil.h"
 #include "dtt/gdstask.h"
+/* note: gdssock uses sockutil unless OS_VXWORKS is defined */
 #include "dtt/gdssock.h"
 #include "dtt/gdschannel.h"
 #if (_CHANNEL_DB==_CHN_DB_DAQ)
@@ -929,6 +930,7 @@ static int debug_flag = 0 ;
             close (sock);
             return -11;
          }
+
          j = nameLength ;
          while ((--j >= 0) && (buf[j] == ' ')) {
             buf[j] = '\0';
@@ -957,9 +959,13 @@ static int debug_flag = 0 ;
 	    ftoi.i = CVHex(buf+nameLength + 40, 8);
             chninfo[chninfonum].offset = ftoi.f;
             memcpy(chninfo[chninfonum].unit, buf+nameLength + 48, 40);
+	    /* Make sure the unit string is truncated with a \0 */
             for (p = chninfo[chninfonum].unit + 39 ; 
                 isspace ((int)*p) && (p > chninfo[chninfonum].unit); p--) {
             }
+	    /* Since p points to the last character in the unit string, 
+	       increment it (unless it's pointing to the very last char.) */
+	    if (p < chninfo[chninfonum].unit + 39) ++p;
             *p = 0;
             /*printf ("name = %s\n", chninfo[chninfonum].chName);
             printf ("rate = %i\n", chninfo[chninfonum].dataRate);
@@ -970,7 +976,7 @@ static int debug_flag = 0 ;
             printf ("gain = %f\n", chninfo[chninfonum].gain);
             printf ("slope = %f\n", chninfo[chninfonum].slope);
             printf ("offset = %f\n", chninfo[chninfonum].offset);
-            printf ("unit = %s\n", chninfo[chninfonum].unit);*/
+            printf ("unit = %s\n", chninfo[chninfonum].unit); */
          }
          else {
             chninfo[chninfonum].dataRate  = CVHex (buf + 40, 4);
@@ -998,9 +1004,13 @@ static int debug_flag = 0 ;
 	       ftoi.i = CVHex(buf+76, 8);
                chninfo[chninfonum].offset =  ftoi.f;
                memcpy(chninfo[chninfonum].unit, buf+84, 40);
+	       /* Make sure the unit string is truncated with a \0 */
                for (p = chninfo[chninfonum].unit + 39; 
                    isspace ((int)*p) && (p > chninfo[chninfonum].unit); p--) {
                }
+	       /* Since p points to the last character in the unit string, 
+		  increment it (unless it's pointing to the very last char.) */
+	       if (p < chninfo[chninfonum].unit + 39) ++p;
                *p = 0;
             }
             else {
@@ -1573,6 +1583,16 @@ static int debug_flag = 0 ;
     /* Return if no reply expected. */
       if (reply == 0) 
          return 0;
+
+    /* Make sure that we're getting a reply */
+      rc = socketWait(mSocket, 1.0, wm_read);
+      if (rc < 0) {
+	perror("SendRequest: Error waiting for reply");
+	return 1;
+      } else if (!rc) {
+	if (debug_flag) fprintf(stderr, "SendRequest: No reply in 1 sec\n");
+	return 1;
+      }
    
     /* Read the reply status. */
       rc = RecvRec (mSocket, status, 4, 0);
