@@ -1,4 +1,4 @@
-/* version $Id: testchn.cc 7574 2016-02-16 20:17:52Z james.batch@LIGO.ORG $ */
+/* version $Id: testchn.cc 7990 2018-01-13 01:32:22Z john.zweizig@LIGO.ORG $ */
 /*----------------------------------------------------------------------*/
 /*                                                         		*/
 /* Module Name: testchn							*/
@@ -19,7 +19,7 @@ namespace diag {
    bool channelHandler::setSiteIfo (char SiteDefault, char SiteForce, 
                      char IfoDefault, char IfoForce)
    {
-      siteDefault = siteDefault;
+      siteDefault = SiteDefault;
       siteForce = SiteForce;
       ifoDefault = IfoDefault;
       ifoForce = IfoForce;
