@@ -1,4 +1,4 @@
-VCSID("$(#)$Id: ffttools.cc 7338 2015-04-14 23:24:47Z ed.maros@LIGO.ORG $");
+VCSID("$(#)$Id: ffttools.cc 7690 2016-08-17 00:07:17Z james.batch@LIGO.ORG $");
 /*----------------------------------------------------------------------*/
 /*                                                         		*/
 /* Module Name: ffttools						*/
@@ -18,16 +18,14 @@ VCSID("$(#)$Id: ffttools.cc 7338 2015-04-14 23:24:47Z ed.maros@LIGO.ORG $");
 #include "gdsalgorithm.h"
 #include "dtt/ffttools.hh"
 #include "dtt/diagdatum.hh"
+#include "dtt/awgapi.h"
 
-// Use the settling time and measurement time to calculate a ramp down
-// for excitations.
-#define FFT_RAMP_SETTLING 1
 
 namespace diag {
    using namespace std;
    using namespace thread;
 
-   static const int my_debug=0 ;
+   static const int my_debug=1 ;
 
    // maximum number of sampling points per (excitation) period
    const double _MAX_OVERSAMPLING = 4.0;
@@ -54,6 +52,8 @@ namespace diag {
 
    bool ffttest::tmpresult::allocate (int Size)
    {
+      int my_debug=0 ; // kill debug messages for this function.
+      if (my_debug) cerr << "ffttest::tmpresult::allocate(Size = " << Size << ")" << endl ;
       lock.writelock();
    
       // delete old arrays
@@ -69,6 +69,7 @@ namespace diag {
       size = Size;
       if (size == 0) {
          lock.unlock();
+         if (my_debug) cerr << "ffttest::tmpresult::allocate() return true" << endl ;
          return true;
       }
       else {
@@ -76,6 +77,7 @@ namespace diag {
          x = new (nothrow) float[cmplx ? 2 * size :  size];
          prm.windowed_data = x;
          lock.unlock();
+         if (my_debug) cerr << "ffttest::tmpresult::allocate() allocated data, return" << endl ;
          return valid();
       }
    }
@@ -148,18 +150,24 @@ namespace diag {
 
    bool ffttest::end (std::ostringstream& errmsg)
    {
+      if (my_debug) cerr << "ffttest::end()" << endl ;
       semlock		lockit (mux);
       // delete temporary storage
       tmps.clear();
    
-      return stdtest::end (errmsg);
+      bool rc = stdtest::end (errmsg);
+      if (my_debug) cerr << "ffttest::end() return" << endl ;
+      return rc ;
    }
 
 
    bool ffttest::readParam (ostringstream& errmsg)
    {
+      if (my_debug) cerr << "ffttest::readParam()" << endl;
+
       // call parent method
       if (!stdtest::readParam (errmsg)) {
+         if (my_debug) cerr << "ffttest::readParam() return false line " << __LINE__ << endl ;
          return false;
       }
    
@@ -213,13 +221,18 @@ namespace diag {
             fftSettlingTime << endl;
          err = true;
       }
-#ifdef EXC_RAMP_DOWN
       // Read ramp down time
       if (!test->getParam (*storage->Test, fftRampDown, rampDown)) {
 	 errmsg << "Unable to load value from Test." << fftRampDown << endl ;
 	 err = true ;
       }
-#endif
+      if (my_debug) cerr << "  rampDown parameter = " << rampDown << endl ;
+      // Read ramp up time
+      if (!test->getParam (*storage->Test, fftRampUp, rampUp)) {
+	 errmsg << "Unable to load value from Test." << fftRampUp << endl ;
+	 err = true ;
+      }
+      if (my_debug) cerr << "  rampUp parameter = " << rampUp << endl ;
    
       // read stimuli channel
       if (!readStimuliParam (errmsg, false, allWaveforms)) {
@@ -243,6 +256,7 @@ namespace diag {
       if (AChannels < 0) {
          AChannels = meas.size();
       }
+      if (my_debug) cerr << "ffttest::readParam() return " << (err ? "false" : "true") << endl ;
       return !err;
    }
 
@@ -253,9 +267,11 @@ namespace diag {
       semlock		lockit (mux);
       bool		err = false;
    
+      if (my_debug) cerr << "ffttest::calcTimes(..., t0 = " << t0 << endl ;
       // check settling time
       if (settlingTime < 0) {
          errmsg << "Settling time must be positive or zero" << endl;
+         if (my_debug) cerr << "ffttest::calcTimes() return false line " << __LINE__ << endl ;
          return false;
       }
       // check averages
@@ -305,6 +321,7 @@ namespace diag {
          err = true;
       }
       if (err) {
+         if (my_debug) cerr << "ffttest::calcTimes() return false line " << __LINE__ << endl ;
          return false;
       }
    
@@ -326,6 +343,7 @@ namespace diag {
       if (BW >= fSpan/16 - 1E-12) {
          errmsg << "Bandwidth must be smaller than 1/16th of the " <<
             "frequency span" << endl;
+         if (my_debug) cerr << "ffttest::calcTimes() return false line " << __LINE__ << endl ;
          return false;
       }
    
@@ -337,7 +355,23 @@ namespace diag {
          fMaxMeas = max (fStop, fSpan);
       }
       // determine sampling rates
+      if (my_debug)
+      {
+	 cerr << "ffttest::calcTimes() calling samplingFrequencies()" << endl ;
+	 cerr << "   fMaxMeas   = " << fMaxMeas << endl ;
+	 cerr << "   fMinSample = " << fMinSample << endl ;
+	 cerr << "   fSample    = " << fSample << endl ;
+      }
+      // fMaxMeas is known before this call, fMinSample and fSample are 
+      // assigned values in samplingFrequencies().
       samplingFrequencies (fMaxMeas, fMinSample, fSample);
+      if (my_debug) 
+      {
+	 cerr << "   LINE " << __LINE__ << endl ;
+	 cerr << "   fMaxMeas   = " << fMaxMeas << endl ;
+	 cerr << "   fMinSample = " << fMinSample << endl ;
+	 cerr << "   fSample    = " << fSample << endl ;
+      }
       if (fZoom == 0) {
          // normal data
          if (fMinSample < fSample - 1E-12) {
@@ -372,31 +406,36 @@ namespace diag {
          //fSample = fMinSample;
       }
       if (err) {
+         if (my_debug) cerr << "ffttest::calcTimes() return false line " << __LINE__ << endl ;
          return false;
       }
    
       // calculate time grid
+      // The fSample is the sample rate of the slowest channel. 
       timeGrid = calcTimeGrid (fSample / 2.0, &t0);
    
       // calculate measurement start time
-      mStart = adjustForSampling (settlingTime * measTime, timeGrid);
+      if (my_debug) cerr << "ffttest::calcTimes() - settlingTime = " << settlingTime << ", measTime = " << measTime << endl ;
+      if (rampUp > (settlingTime * measTime)) {
+	 // Use rampUp instead of settlingTime.
+	 if (my_debug) cerr << "  use rampUp (" << rampUp << ") instead of settlingTime" << endl ;
+	 mStart = adjustForSampling (rampUp, timeGrid);
+      }
+      else
+	 mStart = adjustForSampling (settlingTime * measTime, timeGrid);
+      if (my_debug) cerr << "ffttest::calcTimes() - mStart = " << mStart << endl ;
       exct0 = 0;
       mTimeAdd = adjustForSampling (measTime, timeGrid) - measTime;
+      if (my_debug) cerr << "ffttest::calcTimes() - mTimeAdd = " << mTimeAdd << endl ;
 
       // Set the ramp down time for excitations.  The argument to
       // setRampDown() is a long int in nanoseconds, add 0.5 to get
       // rounding correct when the cast to tainsec_t is performed.
-#ifdef EXC_RAMP_DOWN
       // Use a value from a widget to set the ramp down time.
       testExc->setRampDown((tainsec_t)(rampDown * 1E9 + 0.5)) ;
-#else
-#ifdef FFT_RAMP_SETTLING
-      // Use settling time and measTime to calculate a ramp down time.
-      testExc->setRampDown((tainsec_t)(settlingTime * measTime * 1E9 + 0.5)) ;
-      cout << "Measurment time is " << measTime << ", Ramp down time is " << 
-             (settlingTime * measTime) << endl ; 
-#endif
-#endif
+      if (my_debug) cerr << "  rampDown time is " << rampDown * 1E9 << endl ;
+      testExc->setRampUp((tainsec_t)(rampUp * 1E9 + 0.5)) ;
+      if (my_debug) cerr << "  rampUp time is " << rampUp * 1E9 << endl ;
    
       // points in the result array
       points = (int)(ceil ((fStop - fStart) / BW) + 1.5);
@@ -493,6 +532,7 @@ namespace diag {
       fftPlan.window_coeff = new (nothrow) float[fftPoints];
       if (fftPlan.window_coeff == 0) {
          errmsg << "unable to allocate window memory" << endl;
+         if (my_debug) cerr << "ffttest::calcTimes() return false line " << __LINE__ << endl ;
          return false;
       }
       // create FFT plan & calculate window
@@ -522,6 +562,7 @@ namespace diag {
 	    errmsg << "unable to initialize fft plan and window" << endl;
 	    delete [] in ;
 	    delete [] out ;
+            if (my_debug) cerr << "ffttest::calcTimes() return false line " << __LINE__ << endl ;
 	    return false;
 	 }
 	 // These were just used for scratch memory.
@@ -539,6 +580,7 @@ namespace diag {
          windowBW = BW;
       }
    
+      if (my_debug) cerr << "ffttest::calcTimes() return true" << endl ;
       return true;
    }
 
@@ -546,7 +588,7 @@ namespace diag {
    bool ffttest::newMeasPoint (int i, int measPoint)
    {
       semlock		lockit (mux);
-   
+      if (my_debug) cerr << "ffttest::newMeasPoint( i = " << i << ", measPoint = " << measPoint << ")" << endl ; 
       // calulate start time
       tainsec_t	start = T0 + (tainsec_t)
          ((mStart + (double) (i + skipMeas) * (1.0 - overlap) * 
@@ -581,14 +623,17 @@ namespace diag {
       if (!addMeasPartitions (intervals.back(), measPoint * averages + i,
                            fSample, 0, fZoom, (double) fSample / decimate2,
                            fZoomStart)) {
+         if (my_debug) cerr << "ffttest::newMeasPoint() return false line " << __LINE__ << endl ;
          return false;
       }
    
       // add synchronization point
       if (!addSyncPoint (intervals.back(), i, measPoint)) {
+         if (my_debug) cerr << "ffttest::newMeasPoint() return false line " << __LINE__ << endl ;
          return false;
       }
    
+      if (my_debug) cerr << "ffttest::newMeasPoint() return true" << endl ;
       return true;
    }
 
@@ -600,19 +645,22 @@ namespace diag {
       tainsec_t		eStart;		// excitation start	
       tainsec_t		dur;		// excitation duration	
    
+      if (my_debug) cerr << "ffttest::calcMeasurements(..., t0 = " << t0 << ", measPoint = " << measPoint << ")" << endl ;
       // determine excitation signals
+      if (my_debug) cerr << "  rampUp = " << rampUp << ", rampDown = " << rampDown << endl ;
       eStart = t0 + (tainsec_t) (exct0 * 1E9);
       for (stimuluslist::iterator iter = stimuli.begin();
           iter != stimuli.end(); iter++) {
-         if ((iter->waveform == (AWG_WaveType) 10) ||
-            (iter->waveform == (AWG_WaveType) 11)) {
+         if ((iter->waveform == (AWG_WaveType) 10) || (iter->waveform == (AWG_WaveType) 11)) {
             dur = (tainsec_t) ((measTime + mTimeAdd) * 1E9 + 0.5);
          }
          else {
             dur = -1;
          }
-         if (!iter->calcSignal (eStart, dur)) {
+         if (!iter->calcSignal (eStart, dur, rampUp*1E9, rampDown*1E9)) 
+	 {
             errmsg << "Unable to calculate excitation signal" << endl;
+            if (my_debug) cerr << "ffttest::calcMeasurements() return false line " << __LINE__ << endl ;
             return false;
          }
       }
@@ -621,26 +669,32 @@ namespace diag {
       skipMeas = 0;
       for (int i = 0; i < avrgsize; i++) {
          if (!newMeasPoint (i)) {
-            errmsg << "Unable to create measuremennt points" << endl;
+            errmsg << "Unable to create measurement points" << endl;
+            if (my_debug) cerr << "ffttest::calcMeasurements() return false line " << __LINE__ << endl ;
             return false;
          }
       }
+      if (my_debug) cerr << "ffttest::calcMeasurements() return true" << endl ;
       return true;
    }
 
 
    bool ffttest::stopMeasurements (int firstIndex)
    {
+      if (my_debug) cerr << "ffttest::stopMeasurements(firstIndex = " << firstIndex << ")" << endl ;
       semlock		lockit (mux);
       // delete temporary storage
       tmps.clear();
    
-      return stdtest::stopMeasurements (firstIndex);
+      bool rc = stdtest::stopMeasurements (firstIndex);
+      if (my_debug) cerr << "ffttest::stopMeasurements() return " << (rc ? "true" : "false") << endl ;
+      return rc ;
    }
 
 
    bool ffttest::analyze (const callbackarg& id, int measnum, bool& note)
    {
+      if (my_debug) cerr << "ffttest::analyze(..., measnum = " << measnum << ",...)" << endl ;
       semlock		lockit (mux);
    
       /////////////////////////////////////////////////////////
@@ -660,6 +714,7 @@ namespace diag {
                tmps.push_back (tmpresult (iter->readback, fftPoints, 
                                          fZoom > 0, fftPlan));
                if (!tmps.back().valid()) {
+                  if (my_debug) cerr << "ffttest::analyze() return false line " << __LINE__ << endl ;
                   return false;
                }
             }
@@ -672,6 +727,7 @@ namespace diag {
             tmps.push_back (tmpresult (iter->name, fftPoints, 
                                       fZoom > 0, fftPlan));
             if (!tmps.back().valid()) {
+               if (my_debug) cerr << "ffttest::analyze() return false line " << __LINE__ << endl ;
                return false;
             }
          }
@@ -684,6 +740,7 @@ namespace diag {
          if (iobj == 0) {
             iobj = indx.newObject (0);
             if (iobj == 0) {
+               if (my_debug) cerr << "ffttest::analyze() return false line " << __LINE__ << endl ;
                return false;
             }
             storage->addData (*iobj, false);
@@ -759,6 +816,7 @@ namespace diag {
       /////////////////////////////////////////////////////////
       if (!callChannelAnalysis (id, measnum, 
                            (channelAnalysis) &ffttest::fft)) {
+         if (my_debug) cerr << "ffttest::analyze() return false line " << __LINE__ << endl ;
          return false;
       }
    
@@ -767,11 +825,13 @@ namespace diag {
       /////////////////////////////////////////////////////////
       if (!callChannelAnalysis (id, measnum, 
                            (channelAnalysis) &ffttest::cross)) {
+         if (my_debug) cerr << "ffttest::analyze() return false line " << __LINE__ << endl ;
          return false;
       }
    
       // return
       note = true;
+      if (my_debug) cerr << "ffttest::analyze() return true" << endl ;
       return true;
    }
 
@@ -780,11 +840,14 @@ namespace diag {
    bool ffttest::fft (int resultnum, int measnum, 
                      string chnname, bool stim, const callbackarg& id)
    {
+      if (my_debug) cerr << "ffttest::fft(resultnum = " << resultnum << ", measnum = " << measnum << ", chnname = " << chnname << ", stim = " << (stim ? "true" : "false") << ",...)" << endl ;
       // get time series access class
       const diagResult& aChn = diagChn::self();
       // get time series
       gdsDataObject* chndat = storage->findData (chnname);
       if ((chndat == 0) || (chndat->value == 0)) {
+         if (my_debug) cerr << "ffttest::fft() return false line " << __LINE__ << endl ;
+
          return false;
       }
       if (chndat->error) {
@@ -792,12 +855,14 @@ namespace diag {
       }
       int N;
       if (!aChn.getParam (*chndat, stTimeSeriesN, N)) {
+         if (my_debug) cerr << "ffttest::fft() return false line " << __LINE__ << endl ;
          return false;
       }
    
       // get result access class
       const diagResult* aRes = diagResult::self (stObjectTypeSpectrum);
       if (aRes == 0) {
+         if (my_debug) cerr << "ffttest::fft() return false line " << __LINE__ << endl ;
          return false;
       }
    
@@ -832,6 +897,7 @@ namespace diag {
          }
       }
       if (res == 0) {
+         if (my_debug) cerr << "ffttest::fft() return false line " << __LINE__ << endl ;
          return false;
       }
    
@@ -848,6 +914,7 @@ namespace diag {
                 (float*) chndat->value, 1.0/(fSample / decimate2), 
                 OUTPUT_GDSFORMAT, window, tmps[resultnum].fft) < 0) {
          tmps[resultnum].lock.unlock();
+         if (my_debug) cerr << "ffttest::fft() return false line " << __LINE__ << endl ;
          return false;
       }
       // data rotation to move start frequency to lowest bin
@@ -855,6 +922,7 @@ namespace diag {
          if (dataRotator (fftPoints, DATA_COMPLEX, 
                          tmps[resultnum].fft, tmps[resultnum].x) < 0) {
             tmps[resultnum].lock.unlock();
+            if (my_debug) cerr << "ffttest::fft() return false line " << __LINE__ << endl ;
             return false;
          }
          int dPoints = fftPoints / 2 - 
@@ -884,6 +952,7 @@ namespace diag {
       if (fftToPs (points,  (fStart >= 1E-12) ? DATA_COMPLEX : DATA_REAL, 
                   tmps[resultnum].fft, tmps[resultnum].x) < 0) {
          tmps[resultnum].lock.unlock();
+         if (my_debug) cerr << "ffttest::fft() return false line " << __LINE__ << endl ;
          return false;
       }
    
@@ -901,6 +970,7 @@ namespace diag {
       if (avg (&avgprm, 1, tmps[resultnum].x, &num_so_far, 
               (float*) res->value) < 0) {
          tmps[resultnum].lock.unlock();
+         if (my_debug) cerr << "ffttest::fft() return false line " << __LINE__ << endl ;
          return false;
       }
       // cerr << "psd[" << resultnum << "][0] = " << *(float*) res->value <<
@@ -910,6 +980,7 @@ namespace diag {
                      min (measnum + 1, averages));
       tmps[resultnum].lock.unlock();
    
+      if (my_debug) cerr << "ffttest::fft() return true" << endl ;
       return true;
    }
 
@@ -917,6 +988,7 @@ namespace diag {
    bool ffttest::cross (int i, int measnum, string chnname, bool stim,
                      const callbackarg& id) 
    {
+      if (my_debug) cerr << "ffttest::cross(i = " << i << ", measnum = " << measnum << ", chnname = " << chnname << "stim = " << (stim ? "true" : "false") << ",...)" << endl ;
       // only analyze A channels
       if (i >= numA) {
          return true;
@@ -926,6 +998,7 @@ namespace diag {
       int resofs = tmps.size();
       const diagResult* aRes = diagResult::self (stObjectTypeSpectrum);
       if (aRes == 0) {
+         if (my_debug) cerr << "ffttest::cross() return false line " << __LINE__ << endl ;
          return false;
       }
    
@@ -941,6 +1014,7 @@ namespace diag {
          res = aRes->newObject (0, resofs - 1, points, rindex + resofs + i, 
                               -1, gds_complex32);
          if (res == 0) {
+            if (my_debug) cerr << "ffttest::cross() return false line " << __LINE__ << endl ;
             return false;
          }
          // set parameters of crosscorrelation result
@@ -979,6 +1053,7 @@ namespace diag {
          res = aRes->newObject (0, resofs - 1, points, 
                               rindex + resofs + numA + i, -1, gds_float32);
          if (res == 0) {
+            if (my_debug) cerr << "ffttest::cross() return false line " << __LINE__ << endl ;
             return false;
          }
          // set parameters of result
@@ -1021,11 +1096,13 @@ namespace diag {
                diagObjectName::makeName (stResult, rindex + resofs + i);
             gdsDataObject* 	res = storage->findData (resname);
             if (res == 0) {
+               if (my_debug) cerr << "ffttest::cross() return false line " << __LINE__ << endl ;
                return false;
             }
             // calculate cross-correlation
             if (crossPower (points, (fStart >= 1E-12) ? DATA_COMPLEX : DATA_REAL,
                            tmps[i].fft, tmps[b].fft, tmps[i].x) < 0) {
+               if (my_debug) cerr << "ffttest::cross() return false line " << __LINE__ << endl ;
                return false;
             }
          
@@ -1040,6 +1117,7 @@ namespace diag {
             avgprm.number_of_averages = averages;
             int			num_so_far = measnum;
             if (avg (&avgprm, 1, tmps[i].x, &num_so_far, csd) < 0) {
+               if (my_debug) cerr << "ffttest::cross() return false line " << __LINE__ << endl ;
                return false;
             }
             aRes->setParam (*res, stSpectrumAverages, 
@@ -1051,6 +1129,7 @@ namespace diag {
                                  rindex + resofs + numA + i);
             res = storage->findData (resname);
             if (res == 0) {
+               if (my_debug) cerr << "ffttest::cross() return false line " << __LINE__ << endl ;
                return false;
             }
             // get PSD result objects
@@ -1059,6 +1138,7 @@ namespace diag {
             resname = diagObjectName::makeName (stResult, b);
             gdsDataObject* 	res2 = storage->findData (resname);
             if ((res1 == 0) || (res2 == 0)) {
+               if (my_debug) cerr << "ffttest::cross() return false line " << __LINE__ << endl ;
                return false;
             }
          
@@ -1067,6 +1147,7 @@ namespace diag {
             float* coh = (float*) res->value + indx * points;
             if (coherenceCP (points, (float*) res1->value, (float*) res2->value, 
                             csd, coh) < 0) {
+               if (my_debug) cerr << "ffttest::cross() return false line " << __LINE__ << endl ;
                return false;
             }
             aRes->setParam (*res, stSpectrumAverages, 
@@ -1075,6 +1156,7 @@ namespace diag {
          }
       }
    
+      if (my_debug) cerr << "ffttest::cross() return true" << endl ;
       return true;
    }
 
