@@ -1,4 +1,4 @@
-VCSID("$(#)$Id: stdtest.cc 7574 2016-02-16 20:17:52Z james.batch@LIGO.ORG $");
+VCSID("$(#)$Id: stdtest.cc 7990 2018-01-13 01:32:22Z john.zweizig@LIGO.ORG $");
 /* -*- mode: c++; c-basic-offset: 3; -*- */
 /*----------------------------------------------------------------------*/
 /*                                                         		*/
@@ -57,18 +57,23 @@ namespace diag {
    }
 
 
-   bool stdtest::stimulus::calcSignal (tainsec_t t0, tainsec_t duration, tainsec_t ramp)
+   bool stdtest::stimulus::calcSignal (tainsec_t t0, tainsec_t duration,
+				       tainsec_t rampup, tainsec_t rampdown)
    {
       AWG_Component	comp[2];
       int 		cnum = 1;
-      if (my_debug) cerr << "stdtest::stimulus::calcSignal(t0 = " << t0 << ", duration = " << duration << ", ramp = " << ramp << ")" << endl ;
+      if (my_debug) cerr << "stdtest::stimulus::calcSignal(t0 = "
+			 << (t0 / _ONESEC) << '.' << (t0 % _ONESEC)
+			 << ", duration = " << duration << ", rampup = "
+			 << rampup << ")" << endl ;
    
       switch (waveform) {
          case awgSine:
          case awgRamp:
          case awgTriangle:
             {
-	       if (my_debug) cerr << "  waveform type is " << waveform << ", (Sine, Ramp, Triangle)" << endl ;
+	       if (my_debug) cerr << "  waveform type is " << waveform
+				  << ", (Sine, Ramp, Triangle)" << endl ;
                if (awgPeriodicComponent (waveform, freq, ampl, phas,
                                     offs, comp) < 0) {
                   return false;
@@ -76,7 +81,8 @@ namespace diag {
                comp[0].par[2] = phas;
                comp[0].start = t0 ;
                comp[0].duration = duration ;
-	       comp[0].ramptime[0]=ramp ;
+	       comp[0].ramptime[0]=rampup ;
+	       comp[0].ramptime[1]=rampdown ;
                break;
             }
          case awgSquare:
@@ -89,7 +95,8 @@ namespace diag {
                   comp[0].par[2] = phas;
                   comp[0].start = t0 ;
                   comp[0].duration = duration ;
-		  comp[0].ramptime[0]=ramp ;
+		  comp[0].ramptime[0]=rampup ;
+		  comp[0].ramptime[1]=rampdown ;
                }
                else {
                   if (awgSquareWaveComponent (freq, ampl, phas,
@@ -99,7 +106,8 @@ namespace diag {
                   comp[0].start = t0  + (tainsec_t) 
                      (__ONESEC * (fMod (phas / TWO_PI, 1) - 1)/ freq + 0.5);
                   comp[0].duration = duration ;
-		  comp[0].ramptime[0]=ramp ;
+		  comp[0].ramptime[0]=rampup ;
+		  comp[0].ramptime[1]=rampdown ;
                   comp[1].start = t0 ;
                   comp[1].duration = duration ;
                   cnum = 2;
@@ -114,7 +122,8 @@ namespace diag {
                }
                comp[0].start = t0 ;
                comp[0].duration = duration ;
-	       comp[0].ramptime[0]=ramp ;
+	       comp[0].ramptime[0]=rampup ;
+	       comp[0].ramptime[1]=rampdown ;
                break;
             }
          case awgConst:
@@ -124,7 +133,8 @@ namespace diag {
                }
                comp[0].start = t0 ;
                comp[0].duration = duration ;
-	       comp[0].ramptime[0]=ramp ;
+	       comp[0].ramptime[0]=rampup ;
+	       comp[0].ramptime[1]=rampdown ;
                break;
             }
          case awgNoiseN:
@@ -136,7 +146,8 @@ namespace diag {
                }
                comp[0].start = t0 ;
                comp[0].duration = duration ;
-	       comp[0].ramptime[0]=ramp ;
+	       comp[0].ramptime[0]=rampup ;
+	       comp[0].ramptime[1]=rampdown ;
                break;
             }
          case awgArb:
@@ -147,7 +158,8 @@ namespace diag {
                }
                comp[0].start = t0 ;
                comp[0].duration = duration ;
-	       comp[0].ramptime[0]=ramp ;
+	       comp[0].ramptime[0]=rampup ;
+	       comp[0].ramptime[1]=rampdown ;
                break;
             }
          // sweep
@@ -157,11 +169,12 @@ namespace diag {
                long	flag = (waveform == (AWG_WaveType) 10) ? 
                   0 : AWG_SWEEP_LOG;
                if (awgSweepComponents (t0 , duration , freq - frange, freq + 
-                                    frange, ampl - arange, ampl + arange,
-                                    flag, comp, &cnum) < 0) {
+				       frange, ampl - arange, ampl + arange,
+				       flag, comp, &cnum) < 0) {
                   return false;
                }
-	       comp[0].ramptime[0]=ramp ;
+	       comp[0].ramptime[0]=rampup ;
+	       comp[0].ramptime[1]=rampdown ;
                break;
             }
          case awgNone:
@@ -180,10 +193,14 @@ namespace diag {
          return false;
       }
       // fill in ramp parameters (amplitude phase-in only)
-      if (ramp > 0) {
+      if (rampup > 0) {
+#if 1
 	 comp[0].ramptype = RAMP_TYPE (AWG_PHASING_QUADRATIC, 
 			      AWG_PHASING_QUADRATIC, 
 			      AWG_PHASING_LINEAR);
+#else
+	 comp[0].ramptype = 1 ;
+#endif
 	 if (my_debug) cerr << "  calSignal() - Setting ramptype to " << comp[0].ramptype << endl ;
       }
 
@@ -197,11 +214,11 @@ namespace diag {
 
 
    bool stdtest::stimulus::calcSineSignal (tainsec_t t0, 
-                     tainsec_t duration, tainsec_t ramp)
+                     tainsec_t duration, tainsec_t rampup, tainsec_t rampdown)
    {
       AWG_Component		awg;
    
-      if (my_debug) cerr << "stdtest::stimulus::calcSineSignal(t0="<<t0<<", duration="<<duration<<", ramp="<< ramp << ")"<<endl;
+      if (my_debug) cerr << "stdtest::stimulus::calcSineSignal(t0="<<t0<<", duration="<<duration<<", rampup="<< rampup << ")"<<endl;
       // check waveform 
       if (waveform != awgSine) {
          return false;
@@ -217,8 +234,8 @@ namespace diag {
       }
       else {
          // all other signals ramp from previous signal
-         awg.start = t0 + ramp;
-         awg.duration = (duration < 0) ? duration : duration - ramp;
+         awg.start = t0 + rampup;
+         awg.duration = (duration < 0) ? duration : duration - rampup;
       }
    
       // fill in ramp parameters (amplitude phase-in only)
@@ -229,13 +246,15 @@ namespace diag {
       awg.ramptime[1] = 0;
       if (signals.empty()) {
          // first signal includes amplitide ramp up
-         awg.ramptime[0] = ramp;
-	 if (my_debug) cerr << "  signals.empty(), setting awg.ramptime[0] = "<<ramp<<endl ;
+         awg.ramptime[0] = rampup;
+	 if (my_debug) cerr << "  signals.empty(), setting awg.ramptime[0] = "<<rampup<<endl ;
          // set phase to 0 at start
          if (duration >= 0) awg.par[2] = 0; 
-         phas = fmod (TWO_PI * freq * (double) ramp / __ONESEC + awg.par[2], TWO_PI);
+         phas = fmod (TWO_PI * freq * (double) rampup / __ONESEC + awg.par[2], TWO_PI);
       }
       else {
+	 // Subsequent signals don't have ramp up.
+	 awg.ramptime[0] = 0 ;
 	 if (my_debug) cerr << "  Add ramp to previous signal" << endl ;
          // add ramp to previous signal!
          // patch duration of previous signal
@@ -244,11 +263,11 @@ namespace diag {
          awg.par[2] = fmod (signals.back().par[2] - 
                            TWO_PI * (double) signals.back().duration /
                            __ONESEC * signals.back().par[1] -
-                           PI * (double) ramp / __ONESEC * 
+                           PI * (double) rampup / __ONESEC * 
                            (awg.par[1] - signals.back().par[1]), TWO_PI);
          phas = - awg.par[2];
          // patch phase-out of previous signal (both A and f)
-         signals.back().ramptime[1] = ramp;
+         signals.back().ramptime[1] = rampup;
          signals.back().ramppar[0] = awg.par[0];
          signals.back().ramppar[1] = awg.par[1];
          signals.back().ramppar[2] = awg.par[2];
@@ -257,6 +276,7 @@ namespace diag {
    
       signals.push_back (awg);
       if (my_debug) cerr << "    awg.ramptime[0] = "<<awg.ramptime[0]<<", ramptime[1] = "<<awg.ramptime[1] << endl ;
+      if (my_debug) cerr << "stdtest::stimulus::calcSineSignal() return true" << endl ;
       return true;
    }
 
@@ -698,7 +718,7 @@ namespace diag {
    {
       // highest sampling rate
       int	exp;
-      if (my_debug) cerr << "stdtest::samplingFrequencies()" << endl ;
+      if (my_debug) cerr << "stdtest::samplingFrequencies( fMax = " << fMax << ", ...)" << endl ;
       frexp (2.0 * fMax - 1E-8, &exp);
       fSampleMax = ldexp (1.0, exp);
    
@@ -717,7 +737,7 @@ namespace diag {
             fSampleMin = iter->info.dataRate;
          }
       }
-      if (my_debug) cerr << "stdtest::samplingFrequencies() return" << endl ;
+      if (my_debug) cerr << "stdtest::samplingFrequencies(..., fSampleMin = " << fSampleMin << ", fSampleMax = " << fSampleMax << ") return" << endl ;
    }
 
 
@@ -784,13 +804,14 @@ namespace diag {
       if (my_debug) {
 	 cerr << "stdtest::calcTimeGrid( fMax = " << fMax ;
 	 if (t0 != 0)
-	    cerr << ", t0 = " << *t0 << ")" << endl ;
+	    cerr << ", t0 = " << (*t0 / _ONESEC) << '.' << (*t0 % _ONESEC) << ")" << endl ;
 	 else
 	    cerr << ", NULL)" << endl ;
       }
       // start with 1/16384 sec.
       //double tGrid = 1.0 / sin (2);
-      double tGrid = ldexp (1.0, -14);
+      double tGrid = ldexp (1.0, -14); // 0.00006103525625
+      if (my_debug) cerr << "  tGrid = " << tGrid << endl ;
    
       // determine maximum sampling period of stimulus readback & 
       // measurement channels
@@ -798,6 +819,11 @@ namespace diag {
           iter != stimuli.end(); iter++) {
          if (iter->isReadback) {
             if (iter->readbackInfo.dataRate > 0) {
+	       if (my_debug) {
+		  cerr << "  sample rate of " << iter->readbackInfo.chName << " = "
+	            << iter->readbackInfo.dataRate << ", 1/dataRate = " <<
+		    1.0/(double)iter->readbackInfo.dataRate << endl ;
+	       }
                tGrid = max (tGrid, 1.0/(double)iter->readbackInfo.dataRate);
             }
          }
@@ -805,13 +831,20 @@ namespace diag {
       for (measlist::iterator iter = meas.begin();
           iter != meas.end(); iter++) {
          if (iter->info.dataRate > 0) {
+	    if (my_debug) {
+	       cerr << "  sample rate of " << iter->info.chName << " = "
+		 << iter->info.dataRate << ", 1/dataRate = " <<
+		 1.0/(double)iter->info.dataRate << endl ;
+	    }
             tGrid = max (tGrid, 1.0 / (double) iter->info.dataRate);
          }
       }
+      if (my_debug) cerr << "  tGrid = " << tGrid << endl ;
       // adjust time grid if sampling freq much larger 
       // than meas/exc. freq.
       while (1.0 / tGrid > 2 * fMax + 1E-12) {
          tGrid *= 2.0;
+	 if (my_debug) cerr << "  Adjust time grid, tGrid = " << tGrid << endl ;
       }
       // adjust t0 if necessary
       if (t0 != 0) {
@@ -821,7 +854,7 @@ namespace diag {
       if (my_debug) {
 	 cerr << "stdtest::calcTimeGrid() return" ;
 	 if (t0)
-	    cerr << ", t0 modified to " << *t0 ;
+	    cerr << ", t0 modified to " << (*t0 / _ONESEC) << '.' << (*t0 % _ONESEC) ;
 	 cerr << ", tGrid = " << tGrid << endl ;
       }
       return tGrid;
@@ -833,7 +866,7 @@ namespace diag {
    {
       semlock		lockit (mux);
    
-      if (my_debug) cerr << "stdtest::addMeasurements(t0 = " << t0 << ", measPoint = " << measPoint << ")" << endl ;
+      if (my_debug) cerr << "stdtest::addMeasurements(t0 = " << (t0 / _ONESEC) << '.' << (t0 % _ONESEC) << ", measPoint = " << measPoint << ")" << endl ;
       // calculate measurement times
       if (!calcTimes (errmsg, t0)) {
          return false;
@@ -1019,7 +1052,7 @@ namespace diag {
    {
       semlock		lockit (mux);
    
-      if (my_debug) cerr << "stdtest::setup( starttime = " << starttime << ")" << endl ;
+      if (my_debug) cerr << "stdtest::setup( starttime = " << (starttime / _ONESEC) << '.' << (starttime % _ONESEC) << ")" << endl ;
       // make sure partition and excitation lists are empty
       if (!delMeasurements (errmsg)) {
          return false;
@@ -1483,22 +1516,15 @@ extern "C"
       arg.ret = true;
       if (my_debug)
       { // JCB
-	 char str[128] ;
-	 sprintf(str, "chnAnalysisThread: arg.chns size = %d\n", (int) arg.chns.size() ) ;
-	 cerr << str ;
+	 cerr << "chnAnalysisThread: arg.chns size = " << (int) arg.chns.size() << endl ;
       }
       for (chnlist::iterator iter = arg.chns.begin(); iter != arg.chns.end(); iter++) 
       {
 	 if (my_debug)
 	 {
-	    char str[128]; // JCB
-
-	    sprintf(str, "chnAnalysisThread: iter.rnum = %d\n", iter->rnum) ; // JCB
-	    cerr << str ; // JCB
-	    sprintf(str, "chnAnalysisThread: iter.stim = %d\n", iter->stim) ; // JCB
-	    cerr << str ; // JCB
-	    sprintf(str, "chnAnalysisThread: iter.name = %s\n", iter->name.c_str()) ; // JCB
-	    cerr << str ; // JCB
+	    cerr << "chnAnalysisThread: iter.rnum = " << iter->rnum << endl ; // JCB
+	    cerr << "chnAnalysisThread: iter.stim = " << iter->stim << endl ; // JCB
+	    cerr << "chnAnalysisThread: iter.name = " << iter->name << endl ; // JCB
 	 }
          arg.ret &= (arg.test->*arg.method) (iter->rnum, arg.measnum, 
                               iter->name, iter->stim, *(iter->id));
@@ -1507,9 +1533,7 @@ extern "C"
       --(*arg.count) ;
       if (my_debug)
       {
-	 char str[128] ;
-	 sprintf(str, "chnAnalysisThread: arg.count decremented to %d\n", (*arg.count)) ;
-	 cerr << str ;
+	 cerr << "chnAnalysisThread: arg.count decremented to " << (*arg.count) << endl ;
       }
 #else
       {
@@ -1518,9 +1542,7 @@ extern "C"
 	 {
 	    if (my_debug)
 	    {
-	       char str[128] ;
-	       sprintf(str, "chnAnalysisThread: sem_post returned %d\n", retval) ;
-	       cerr << str ;
+	       cerr << "chnAnalysisThread: sem_post returned " << retval << endl ;
 	    }
 	 }
       }
@@ -1572,9 +1594,7 @@ extern "C"
       {
 	 if (my_debug)
 	 { // JCB
-	    char str[128] ;
-	    sprintf(str, "callChannelAnalysis: meas has %d items\n", (int) meas.size()) ;
-	    cerr << str ;
+	    cerr << "callChannelAnalysis: meas has " << (int) meas.size() << " items" << endl ;
 	 }
 	 for (measlist::iterator iter = meas.begin(); iter != meas.end(); iter++) 
 	 {
@@ -1583,16 +1603,12 @@ extern "C"
 	    }
 	    if (my_debug)
 	    { // JCB
-	       char str[128] ;
-	       sprintf(str, "callChannelAnalysis: creating name for %s\n", iter->info.chName) ;
-	       cerr << str ;
+	       cerr << "callChannelAnalysis: creating name for " << iter->info.chName << endl ;
 	    }
 	    rec.name = diagObjectName::makeName ( iter->info.chName, step, num);
 	    if (my_debug)
 	    { // JCB
-	       char str[64] ;
-	       sprintf(str, "   name is %s\n", rec.name.c_str()) ;
-	       cerr << str ;
+	       cerr << "   name is " << rec.name << endl ;
 	    }
 	    rec.rnum = rnum;
 	    rec.stim = false;
@@ -1642,9 +1658,8 @@ extern "C"
       
 	 if (my_debug)
 	 { // JCB
-	    char str[256] ;
-	    sprintf(str, "callChannelAnalysis: use threads.\ncallChannelAnalysis: %d chns in args list.\n", (int) chns.size()) ;
-	    cerr << str ;
+	    cerr << "callChannelAnalysis: use threads." << endl ;
+	    cerr << "callChannelAnalysis: " << (int) chns.size() << " chns in args list." << endl ;
 	 }
          // split list
          int i = 0;
@@ -1654,9 +1669,8 @@ extern "C"
          }
 	 if (my_debug)
 	 { // JCB
-	    char str[256] ;
-	    sprintf(str, "callChannelAnalysis: i = %d\ncallChannelAnalysis: size of args[0].chns = %d\n", i, (int) args[0].chns.size()) ;
-	    cerr << str ;
+	    cerr << "callChannelAnalysis: i = " << i << endl ;
+	    cerr << "callChannelAnalysis: size of args[0].chns = " << (int) args[0].chns.size() << endl ;
 	 }
          // create threads
 #ifdef P__DARWIN
@@ -1669,27 +1683,22 @@ extern "C"
 	    if ((retval = sem_init (&count, 0, 0)) < 0)
 	    { // JCB
 	       {
-		  char str[128] ;
-		  sprintf(str, "callChannelAnalysis: sem_init() returned %d at %s, line %d.\n", retval, __FILE__, __LINE__) ;
-		  cerr << str ;
+		  cerr << "callChannelAnalysis: sem_init() returned " << retval << " at " << __FILE__ << ", line " << __LINE__ << endl ;
 	       }
 	       abort() ; // Don't continue.
 	    }
 	 }
 	 { // JCB
-	    char str[512] ;
 	    int	value ;
 	    if (sem_getvalue(&count, &value))
 	    {
-	       sprintf(str, "callChannelAnalysis: sem_getvalue() failed in %s, line %d\n", __FILE__, __LINE__) ;
-	       cerr << str ;
+	       cerr << "callChannelAnalysis: sem_getvalue() failed in " << __FILE__ << ", line " << __LINE__ << endl ;
 	    }
 	    else
 	    {
 	       if (my_debug)
 	       {
-		  sprintf(str, "callChannelAnalysis: sem_init(&count, 0 0), count = %d\n", value) ;
-		  cerr << str ;
+		  cerr << "callChannelAnalysis: sem_init(&count, 0 0), count = " << value << endl ;
 	       }
 	    }
 	 }
@@ -1704,34 +1713,28 @@ extern "C"
 	       --count ;
 	       if (my_debug)
 	       {
-		  char str[128] ;
-		  sprintf(str, "callChannelAnalysis: count decremented to %d because chns.empty() is true\n",count) ;
-		  cerr << str ;
+		  cerr << "callChannelAnalysis: count decremented to " << count << " because chns.empty() is true" << endl ;
 	       }
 #else
 	       {
 		  // don't ignore the return value of system calls.
 		  int retval ;
-		  char str[512] ;
 		  if ((retval = sem_post (&count)) < 0)
 		  {
-		     sprintf(str, "callChannelAnalysis: sem_post(&count) failed in %s at line %d\n", __FILE__, __LINE__) ;
-		     cerr << str ;
+		     cerr << "callChannelAnalysis: sem_post(&count) failed in " << __FILE__ << " at line " << __LINE__ << endl ;
 		  }
 		  else
 		  {
 		     int value ;
 		     if (sem_getvalue(&count, &value))
 		     {
-			sprintf(str, "callChannelAnalysis: sem_getvalue() failed in %s, line %d\n", __FILE__, __LINE__) ;
-			cerr << str ;
+			cerr << "callChannelAnalysis: sem_getvalue() failed in " << __FILE__ << " at line " << __LINE__ << endl ;
 		     }
 		     else
 		     {
 			if (my_debug)
 			{
-			   sprintf(str, "callChannelAnalysis: sem_post(&count) returned %d, count = %d\n", retval, value) ;
-			   cerr << str ;
+			   cerr << "callChannelAnalysis: sem_post(&count) returned " << retval << ", count = " << value << endl ;
 			}
 		     }
 		  }
@@ -1747,19 +1750,16 @@ extern "C"
             int attr = PTHREAD_CREATE_DETACHED;
 	    if (my_debug)
 	    { // JCB
-	       char str[256] ;
-	       sprintf(str, "callChannelAnalysis: Creating thread %d\n  args[%d].measnum = %d\n  args[%d].chns.size = %d\n\n", i, i, args[i].measnum, i, (int) args[i].chns.size()) ;
-	       cerr << str ;
+	       cerr << "callChannelAnalysis: Creating thread " << i << 
+	               " args[" << i << "].measnum = " << args[i].measnum <<
+		       " args[" << i << "].chns.size = " << (int) args[i].chns.size() << endl ;
 	    }
 	    if (my_debug)
 	    {
 	       for (unsigned int n = 0; n < args[i].chns.size(); n++) // JCB
 	       { // JCB
-		  char str[128] ;
-		  sprintf(str, "    args[%d].chns[%d].rnum = %d\n", i, n, args[i].chns[n].rnum) ;
-		  cerr << str ;
-		  sprintf(str, "    args[%d].chns[%d],name = %s\n", i, n, args[i].chns[n].name.c_str()) ;
-		  cerr << str ;
+		  cerr << "    args[" << i << "].chns[" << n << "].rnum = " << args[i].chns[n].rnum << endl ;
+		  cerr << "    args[" << i << "].chns[" << n << "],name = " << args[i].chns[n].name << endl ;
 	       } // JCB
 	    }
             // create thread
@@ -1772,9 +1772,7 @@ extern "C"
 #ifdef P__DARWIN
 	 if (my_debug)
 	 {
-	    char str[128] ;
-	    sprintf(str, "callChannelAnalysis: done creating threads, semaphore count value is %d\n", count) ;
-	    cerr << str; 
+	    cerr << "callChannelAnalysis: done creating threads, semaphore count value is " << count << endl ; 
 	 }
 	 // count will be positive while there are threads that have not returned.
 	 while (count > 0)
@@ -1790,19 +1788,16 @@ extern "C"
 	 }
 #else
 	 {
-	    char str[256] ;
 	    int value ;
 	    if (sem_getvalue(&count, &value))
 	    {
-	       sprintf(str, "callChannelAnalysis: sem_getvalue() failed in %s at %d\n", __FILE__, __LINE__) ;
-	       cerr << str; 
+	       cerr << "callChannelAnalysis: sem_getvalue() failed in " << __FILE__ << " at line " << __LINE__ << endl ; 
 	    }
 	    else
 	    {
 	       if (my_debug)
 	       {
-		  sprintf(str, "callChannelAnalysis: done creating threads, semaphore count value is %d\n", value) ;
-		  cerr << str; 
+		  cerr << "callChannelAnalysis: done creating threads, semaphore count value is " << value << endl ; 
 	       }
 	    }
 	 }
@@ -1811,10 +1806,8 @@ extern "C"
 	    {
 	       if (my_debug)
 	       { // JCB
-		  char str[512] ;
 		  int  err = errno ;
-		  sprintf(str, "callChannelAnalysis: sem_wait() failed, %s in %s at %d\n", strerror(err), __FILE__, __LINE__) ;
-		  cerr << str ;
+		  cerr << "callChannelAnalysis: sem_wait() failed, " << strerror(err) << " in " <<  __FILE__ << " at line " << __LINE__ << endl ;
 	       }
 	    }
          }
@@ -1828,10 +1821,8 @@ extern "C"
 	 {
 	    if (my_debug)
 	    {
-	       char str[512] ;
 	       int err = errno ;
-	       sprintf(str, "callChannelAnalysis: sem_destroy() failed, %s in %s at %d\n", strerror(err), __FILE__, __LINE__) ;
-	       cerr << str ;
+	       cerr << "callChannelAnalysis: sem_destroy() failed, " << strerror(err) << " in " <<  __FILE__ << " at line " << __LINE__ << endl ;
 	    }
 	 }
 #endif
