@@ -1,4 +1,4 @@
-VCSID("@(#)$Id: timeseries.cc 7338 2015-04-14 23:24:47Z ed.maros@LIGO.ORG $"); 
+VCSID("@(#)$Id: timeseries.cc 7690 2016-08-17 00:07:17Z james.batch@LIGO.ORG $"); 
 /*----------------------------------------------------------------------*/
 /*                                                         		*/
 /* Module Name: timeseries						*/
@@ -246,7 +246,19 @@ namespace diag {
             tsSettlingTime << endl;
          err = true;
       }
-      // read settling time
+      // Read ramp down time
+      if (!test->getParam (*storage->Test, tsRampDown, rampDown)) {
+         errmsg << "Unable to load value from Test." << tsRampDown << endl ;
+         err = true ;
+      }
+      if (my_debug) cerr << "  rampDown parameter = " << rampDown << endl ;
+      // Read ramp up time
+      if (!test->getParam (*storage->Test, tsRampUp, rampUp)) {
+         errmsg << "Unable to load value from Test." << tsRampUp << endl ;
+         err = true ;
+      }
+      if (my_debug) cerr << "  rampUp parameter = " << rampUp << endl ;
+      // read dead time
       if (!test->getParam (*storage->Test, tsDeadTime, deadTime)) {
          errmsg << "Unable to load values from Test." <<
             tsDeadTime << endl;
@@ -297,6 +309,7 @@ namespace diag {
       semlock		lockit (mux);
       bool		err = false;
    
+      if (my_debug) cerr << "imeseries::calcTimes(..., t0 = " << t0 << ")" << endl ;
       // check measurement time
       if (measTime <= 0) {
          errmsg << "Measurement time must be positive" << endl;
@@ -347,6 +360,7 @@ namespace diag {
       if (err) {
          return false;
       }
+      // Number of result records
       rnumber = 0;
       for (stimuluslist::iterator iter = stimuli.begin();
           iter != stimuli.end(); iter++) {
@@ -359,31 +373,64 @@ namespace diag {
       // highest frequency of interest
       fMaxMeas = sigBW;
       // determine sampling rates
+      if (my_debug)
+      {
+	 cerr << "timeseries::calcTimes() calling samplingFrequencies()" << endl ;
+         cerr << "   fMaxMeas   = " << fMaxMeas << endl ;
+	 cerr << "   fMinSample = " << fMinSample << endl ;
+	 cerr << "   fMaxSample = " << fMaxSample << endl ;
+      }
+
       samplingFrequencies (fMaxMeas, fMinSample, fMaxSample);
+      if (my_debug)
+      {
+	 cerr << "   LINE " << __LINE__ << endl ;
+	 cerr << "   fMaxMeas   = " << fMaxMeas << endl ;
+	 cerr << "   fMinSample = " << fMinSample << endl ;
+	 cerr << "   fMaxSample = " << fMaxSample << endl ;
+      }
    
       // calculate time grid
       timeGrid = calcTimeGrid (fMaxSample / 2.0, &t0);
    
       if (my_debug)
       {
-	 cerr << "calcTimes() fMaxMeas = " << fMaxMeas 
-	    << " fMinSample = " << fMinSample
-	    << " fMaxSample = " << fMaxSample
-	    << " timeGrid = " << timeGrid << endl ;
+	 cerr << "   fMaxMeas = " << fMaxMeas << endl ;
+	 cerr << "   fMinSample = " << fMinSample << endl ;
+	 cerr << "   fMaxSample = " << fMaxSample << endl ;
+	 cerr << "   timeGrid = " << timeGrid << endl ;
       }
 
       // calculate measurement start time
+
       if (preTriggerTime >= 0) {
-         // trigger is applied after measurement starts
-         mStart = adjustForSampling (settlingTime * measTime, timeGrid);
+	 if (rampUp > (settlingTime * measTime)) {
+	    // Use rampUp instead of settlingTime.
+	    if (my_debug) cerr << "  use rampUp (" << rampUp << ") instead of settlingTime" << endl ;
+	    mStart = adjustForSampling (rampUp, timeGrid) ;
+	 }
+	 else
+	    // trigger is applied after measurement starts
+	    mStart = adjustForSampling (settlingTime * measTime, timeGrid);
       }
       else {
-         // trigger is applied before measurement starts
-         mStart = adjustForSampling (settlingTime * measTime - 
+	 if (rampUp > (settlingTime * measTime)) {
+	    // Use rampUp instead of settlingTime.
+	    if (my_debug) cerr << "  use rampUp (" << rampUp << ") instead of settlingTime (trigger)" << endl ;
+	    mStart = adjustForSampling (rampUp - preTriggerTime * measTime, timeGrid);
+	 }
+	 else
+	    // trigger is applied before measurement starts
+	    mStart = adjustForSampling (settlingTime * measTime - 
                               preTriggerTime * measTime, timeGrid);
       }
-      exct0 = mStart + preTriggerTime * measTime;
+      if (my_debug) cerr << "timeseries::calcTimes() - mStart = " << mStart << endl ;
+
+      //exct0 = mStart + preTriggerTime * measTime;
+      exct0 = 0 ;
       mTimeAdd = adjustForSampling (measTime, timeGrid) - measTime;
+      if (my_debug) cerr << "timeseries::calcTimes() -  mTimeAdd = " << mTimeAdd << endl ;
+
       if (dTime >= 0) {
          dTime = adjustForSampling (deadTime, timeGrid);
       }
@@ -391,6 +438,12 @@ namespace diag {
          dTime = - adjustForSampling (-deadTime, timeGrid);
       }
    
+      // Use a value from a widget to set the ramp down time.
+      testExc->setRampDown((tainsec_t)(rampDown * 1E9 + 0.5)) ;
+      if (my_debug) cerr << "  rampDown time is " << rampDown * 1E9 << endl ;
+      testExc->setRampUp((tainsec_t)(rampUp * 1E9 + 0.5)) ;
+      if (my_debug) cerr << "  rampUp time is " << rampUp * 1E9 << endl ;
+
       // handle averaging
       avrgsize = averages;
       if (avrgsize * (measTime + mTimeAdd) < _TIME_AHEAD) {
@@ -416,11 +469,9 @@ namespace diag {
       semlock		lockit (mux);
    
       if (my_debug)
-	 cerr << "timeseries::newMeasPoint()" << endl ;
+	 cerr << "timeseries::newMeasPoint(i = " << i << ", measPoint = " << measPoint << ")" << endl ;
       // calulate start time
-      tainsec_t	start = T0 + (tainsec_t)
-         ((mStart + (double) (i + skipMeas) * 
-          (measTime + mTimeAdd)) * 1E9 + 0.5);
+      tainsec_t	start = T0 + (tainsec_t) ((mStart + (double) (i + skipMeas) * (measTime + mTimeAdd)) * 1E9 + 0.5);
    
       if (my_debug)
       {
@@ -455,8 +506,8 @@ namespace diag {
 	       cerr << "    start recalculate, = " << start << endl ;
          }
       }
-      cerr << "start " << start << " " << mStart << " " <<
-         (measTime + mTimeAdd) << endl;
+      //cerr << "start " << start << " " << mStart << " " <<
+       //  (measTime + mTimeAdd) << endl;
    
       // fine adjust to time grid & calc. duration
       start = fineAdjustForSampling (start, timeGrid);
@@ -482,6 +533,7 @@ namespace diag {
          return false;
       }
    
+      if (my_debug) cerr << "timeseries::newMeasPoint() return true" << endl ;
       return true;
    }
 
@@ -494,6 +546,7 @@ namespace diag {
       tainsec_t		dur;		// excitation duration	
    
       // determine excitation signals
+      if (my_debug) cerr << "timeseries::calcMeasurements(..., t0 = " << t0 << "< measPoint = " << measPoint << ")" << endl ;
       eStart = t0 + (tainsec_t) (exct0 * 1E9);
       for (stimuluslist::iterator iter = stimuli.begin();
           iter != stimuli.end(); iter++) 
@@ -510,7 +563,8 @@ namespace diag {
          if (iter->freq <= 0) {
             iter->freq = 1.0 / (measTime + mTimeAdd);
          }
-         if (!iter->calcSignal (eStart, dur)) {
+         if (!iter->calcSignal (eStart, dur, rampUp*1E9, rampDown*1E9)) 
+	 {
             errmsg << "Unable to calculate excitation signal" << endl;
             iter->freq = fold;
             return false;
@@ -522,10 +576,11 @@ namespace diag {
       skipMeas = 0;
       for (int i = 0; i < avrgsize; i++) {
          if (!newMeasPoint (i)) {
-            errmsg << "Unable to create measuremennt points" << endl;
+            errmsg << "Unable to create measurement points" << endl;
             return false;
          }
       }
+      if (my_debug) cerr << "timeseries::calcMeasurements() return true" << endl ;
       return true;
    }
 
