@@ -1,4 +1,4 @@
-/* Version $Id: testpoint.c 6507 2011-10-13 20:17:10Z john.zweizig@LIGO.ORG $ */
+/* Version $Id: testpoint.c 7989 2018-01-12 23:13:45Z john.zweizig@LIGO.ORG $ */
 /*----------------------------------------------------------------------*/
 /*                                                         		*/
 /* Module Name: testpoint						*/
@@ -1005,12 +1005,16 @@ printf("node %d valid=%d\n", node, tpNode[node].valid);
          }
       	 /* read node */
          if (*p == '*') {
+#ifdef CLEAR_ALL_TP_ALLOWED
             for (node = 0; node < TP_MAX_NODE; node++) {
                if (tpNode[node].valid) {
                   tpClear (node, NULL, 0);
                }
             }
             return cmdreply ("test point cleared");
+#else
+            return cmdreply ("Clearing all test points on all nodes is not allowed") ;
+#endif
          }
          /* try reading node */
 	 char *endptr;
@@ -1530,7 +1534,8 @@ printf("node %d valid=%d\n", node, tpNode[node].valid);
             (rpcGetHostaddress (remotehost, &addr) != 0)) {
             continue;
          }
-         inet_ntoa_b (addr, tpNode[node].hostname);
+         inet_ntop(AF_INET, &addr, tpNode[node].hostname,
+		   sizeof(tpNode[node].hostname));
       
          /* get rpc parameters from parameter file */
          prognum = RPC_PROGNUM_TESTPOINT;
