@@ -1,4 +1,4 @@
-/* Version $Id: testpoint_server.c 7058 2014-03-31 22:08:09Z james.batch@LIGO.ORG $ */
+/* Version $Id: testpoint_server.c 7989 2018-01-12 23:13:45Z john.zweizig@LIGO.ORG $ */
 /*----------------------------------------------------------------------*/
 /*                                                         		*/
 /* Module Name: testpoint_server					*/
@@ -758,9 +758,10 @@
       struct in_addr	addr;		/* client address */
    
    #ifdef DEBUG
-      char		buf[256];
+      char		buf[256], tmp[32];
       rpcGetClientaddress (rqstp->rq_xprt, &addr);
-      sprintf (buf, "keep alive %i from %s", id, inet_ntoa (addr));
+      sprintf (buf, "keep alive %i from %s", id,
+	       inet_ntop(AF_INET, &addr, tmp, sizeof(tmp)));
       gdsDebug (buf);
       printf ("%s\n", buf);
    #endif
@@ -770,6 +771,7 @@
          *ret = tpclntID++;
       }
       else if (id < 0) {
+	 char tmp[32];
          rpcGetClientaddress (rqstp->rq_xprt, &addr);
          for (i = 0; i < _TP_MAX_USER; i++) {
             /* look for free id */
@@ -780,15 +782,16 @@
                MUTEX_RELEASE (servermux);
                {
 		 time_t now = time (NULL);
-	         printf ("Allocate new TP handle %i by %s at %s\n", 
-	                 i, inet_ntoa (addr), ctime (&now));
+	         printf ("Allocate new TP handle %i by %s at %s\n", i,
+	                 inet_ntop(AF_INET, &(addr), tmp, sizeof(tmp)),
+			 ctime (&now));
 		 fflush(stdout);
 	       }
                return TRUE;
             }
          }
 	 printf ("Failed to allocate TP handle by %s\n", 
-	         inet_ntoa (addr));
+		 inet_ntop(AF_INET, &(addr), tmp, sizeof(tmp)));
          *ret = -1;
       }
       else if ((id >= _TP_MAX_USER) || (!tpclnts[id].valid)) {
@@ -1481,7 +1484,8 @@
             continue;
          }
 #endif
-         inet_ntoa_b (addr, tplist[node].hostname);
+         inet_ntop(AF_INET, &addr, tplist[node].hostname,
+		   sizeof(tplist[node].hostname));
       
          /* get rpc parameters from parameter file */
          prognum = RPC_PROGNUM_TESTPOINT;
@@ -1605,6 +1609,7 @@
    
       /* register with rpc service */
       for (node = 0, reg = 0; node < TP_MAX_NODE; node++) {
+	 char addr_tmp[32];
          if (!tplist[node].valid) {
             continue;
          }
@@ -1647,8 +1652,8 @@
             pConf++;
          }
          sprintf (pConf, "tp %i 0 %s %ld %ld", node,
-                 inet_ntoa (host), tplist[node].prognum, 
-                 tplist[node].progver);
+		  inet_ntop(AF_INET, &host, addr_tmp, sizeof(addr_tmp)),
+		  tplist[node].prognum, tplist[node].progver);
       }
    
       if (reg == 0) {
