@@ -1,4 +1,4 @@
-VCSID("@(#)$Id: gdssched_client.c 7338 2015-04-14 23:24:47Z ed.maros@LIGO.ORG $");
+VCSID("@(#)$Id: gdssched_client.c 7989 2018-01-12 23:13:45Z john.zweizig@LIGO.ORG $");
 
 /*----------------------------------------------------------------------*/
 /*                                                         		*/
@@ -933,8 +933,7 @@ VCSID("@(#)$Id: gdssched_client.c 7338 2015-04-14 23:24:47Z ed.maros@LIGO.ORG $"
    #ifdef OS_VXWORKS
       inet_ntoa_b (data->remotehost, cbname);
    #else
-      strncpy (cbname, inet_ntoa (data->remotehost), sizeof (cbname));
-      cbname[sizeof(cbname)-1] = 0;
+      inet_ntop(AF_INET, &(data->remotehost), cbname, sizeof (cbname));
    #endif
       /* create client handle */
       clnt = clnt_create (cbname, data->remotenum, 
@@ -1243,9 +1242,7 @@ VCSID("@(#)$Id: gdssched_client.c 7338 2015-04-14 23:24:47Z ed.maros@LIGO.ORG $"
       #ifdef OS_VXWORKS
          inet_ntoa_b (data->remotehost, hostname);
       #else
-         strncpy (hostname, inet_ntoa (data->remotehost), 
-                 sizeof (hostname));
-         hostname[sizeof(hostname)-1] = 0;
+         inet_ntop(AF_INET, &(data->remotehost), hostname, sizeof (hostname));
       #endif
          data->clnt = clnt_create (hostname, data->remotenum, 
                                   data->remotever, _NETID);
