@@ -1,4 +1,4 @@
-VCSID("@(#)$Id: gdssched_server.c 7338 2015-04-14 23:24:47Z ed.maros@LIGO.ORG $");
+VCSID("@(#)$Id: gdssched_server.c 7989 2018-01-12 23:13:45Z john.zweizig@LIGO.ORG $");
 
 /*----------------------------------------------------------------------*/
 /*                                                         		*/
@@ -569,8 +569,7 @@ VCSID("@(#)$Id: gdssched_server.c 7338 2015-04-14 23:24:47Z ed.maros@LIGO.ORG $"
    #ifdef OS_VXWORKS
       inet_ntoa_b (arg->addr, cbname);
    #else
-      strncpy (cbname, inet_ntoa (arg->addr), sizeof (cbname));
-      cbname[sizeof(cbname)-1] = 0;
+      inet_ntop(AF_INET, &(arg->addr), cbname, sizeof (cbname));
    #endif
       /* create client handle */
       clnt = clnt_create (cbname, arg->prognum, 
