@@ -78,7 +78,8 @@ namespace diag {
    dataBroker::dataBroker (gdsStorage* dat, 
                      testpointMgr* TPMgr, double Lazytime) 
    : storage (dat), tpMgr (TPMgr), lazytime (Lazytime), cleartime (0), 
-   nexttimestamp (0), starttime (0), stoptime (0), TID (0), cleanTID (0)
+   nexttimestamp (0), starttime (0), stoptime (0), TID (0), cleanTID (0),
+   pauseTest(0), abortTest(0)
    {
       semlock		lockit (mux);	// lock mutex */
    
