@@ -1,4 +1,4 @@
-VCSID("$(#)$Id: rtddinput.cc 7574 2016-02-16 20:17:52Z james.batch@LIGO.ORG $");
+VCSID("$(#)$Id: rtddinput.cc 7775 2016-10-21 15:05:17Z james.batch@LIGO.ORG $");
 /* -*- mode: c++; c-basic-offset: 3; -*- */
 /*----------------------------------------------------------------------*/
 /*                                                         		*/
@@ -95,6 +95,7 @@ namespace diag {
 /*----------------------------------------------------------------------*/
    int rtddManager::ndstask (rtddManager& RTDDMgr) 
    {
+      if (my_debug) cerr << "rtddManager::ndstask()" << endl ;
       DAQSocket*	nds = &RTDDMgr.nds;
       char*		buf = 0;// data buffer
       int		len;	// length of read buffer
@@ -192,6 +193,7 @@ namespace diag {
          pthread_setcancelstate (PTHREAD_CANCEL_DISABLE, 0);
       }
    
+      if (my_debug) cerr << "rtddManager::ndstask() return" << endl ;
       return 0;
    }
 
@@ -276,6 +278,8 @@ namespace diag {
       semlock		lockit (mux);	// lock mutex */
       tainsec_t		chnactive;	// time when channel active
    
+      if (my_debug) cerr << "rtddManager::set(" << start/_ONESEC << '.' << start%_ONESEC << ",...)"
+            << endl ;
       // check if lazy clears have to be committed
       if ((cleartime > 0) && !areUsed()) {
          mux.unlock();
@@ -352,6 +356,7 @@ namespace diag {
          *active = max (now, *active);
       }
    
+      if (my_debug) cerr << "rtddManager::set() return" << endl ;
       return true;
    }
 
@@ -359,6 +364,7 @@ namespace diag {
    bool rtddManager::set (taisec_t start, taisec_t duration)
    {
       semlock		lockit (mux);	// lock mutex */
+      if (my_debug) cerr << "rtddManager::set(" << start << ", " << duration << ')' << endl ;
       cerr << "TIME STAMP BEFORE START = " << timeStamp() << endl;
    
       // make sure nds is stopped
@@ -692,6 +698,7 @@ namespace diag {
       }
    
       // create nds task
+      if (my_debug) cerr << "  Create the nds task." << endl ;
       int		attr;	// task create attribute
    #ifdef OS_VXWORKS
       attr = VX_FP_TASK;
@@ -708,6 +715,7 @@ namespace diag {
       }
       // cerr << "nds started" << endl;
    
+      if (my_debug) cerr << "rtddManager::ndsStart() return true" << endl ;
       return true;
    }
 
@@ -728,17 +736,31 @@ namespace diag {
       // wait for data to become available
       if (my_debug)
       {
-	 cerr << "  Wait for data to become available if " << TAInow() << " < " << (start + duration + _NDS_DELAY) * _ONESEC << endl ;
+	 tainsec_t t = TAInow() ;
+	 cerr << "  Wait for data to become available if " << t/_ONESEC << '.' << t%_ONESEC << " < " << (start + duration + _NDS_DELAY) << endl ;
 	 if (TAInow() < (unsigned) (start + duration + _NDS_DELAY) * _ONESEC) 
 	 {
 	    taisec_t temp = (start+duration+_NDS_DELAY)*_ONESEC - TAInow() ;
 	    if (my_debug) cerr << "   (Wait time = " << temp / _ONESEC << "." << temp % _ONESEC <<")"<< endl ;
 	 }
       }
+      // Need to check for abort in this loop if it's available.
       while (TAInow() < (unsigned) (start + duration + _NDS_DELAY) * _ONESEC) {
+	 if (abortTest && *abortTest)
+	 {
+	    // Abort command was sent. abortTest defined in databroker class.
+	    if (my_debug) cerr << "  Test aborted by command." << endl ;
+	    break ;
+	 }
          timespec wait = {0, 250000000};
          nanosleep (&wait, 0);
       }
+      
+      // See if the user bailed out waiting for data.
+      if (abortTest && *abortTest) {
+	 return false ;
+      }
+
       if (my_debug) cerr << "    Data available..." << endl ;
    
       // set last time
