@@ -1,4 +1,4 @@
-/* version $Id: rpcinc.h 7389 2015-06-11 18:51:56Z james.batch@LIGO.ORG $ */
+/* version $Id: rpcinc.h 7989 2018-01-12 23:13:45Z john.zweizig@LIGO.ORG $ */
 /*----------------------------------------------------------------------*/
 /*                                                         		*/
 /* Module Name: rpcinc.h						*/
@@ -596,8 +596,8 @@ int rpcProbe (const char* host, const u_long prognum,
 
 
 #ifndef OS_VXWORKS
-#define inet_ntoa_b(addr, host) \
-			strncpy (host, inet_ntoa (addr), 80)
+  // #define inet_ntoa_b(addr, host) strncpy (host, inet_ntoa (addr), 80)
+#define inet_ntoa_b(addr, host) inet_ntop(AF_INET, &(addr), host, sizeof(host))
 #endif
 
 
