@@ -1,4 +1,4 @@
-VCSID("@(#)$Id: fchannel.cc 7338 2015-04-14 23:24:47Z ed.maros@LIGO.ORG $");
+VCSID("@(#)$Id: fchannel.cc 7574 2016-02-16 20:17:52Z james.batch@LIGO.ORG $");
 /* -*- mode: c++; c-basic-offset: 3; -*- */
 #include <time.h>
 #include <fnmatch.h>
@@ -15,6 +15,7 @@ VCSID("@(#)$Id: fchannel.cc 7338 2015-04-14 23:24:47Z ed.maros@LIGO.ORG $");
 namespace fantom {
    using namespace std;
 
+   static int my_debug = 0 ;
 
 
 //////////////////////////////////////////////////////////////////////////
@@ -39,10 +40,10 @@ namespace fantom {
 // channelentry                                                         //
 //                                                                      //
 //////////////////////////////////////////////////////////////////////////
-   channelentry::channelentry (const char* name, float rate)
+   channelentry::channelentry (const char* name, float rate, int dcuid)
    : fActive (name != 0), fName (name ? name : ""), fRate (rate),
      fUDN (""), fIsDuplicate (false), fHasDuplicate (false),
-     fWildcard (false)
+     fWildcard (false), fDCUID(dcuid)
    {
       if ((fName.find ('*') != string::npos) || 
          (fName.find ('?') != string::npos) || 
@@ -54,8 +55,24 @@ namespace fantom {
 //______________________________________________________________________________
    bool channelentry::operator== (const channelentry& chn) const
    {
+#if 0
       return ((strcasecmp (fName.c_str(), chn.fName.c_str()) == 0) &&
+	     (fRate == chn.fRate) &&
              (strcasecmp (fUDN.c_str(), chn.fUDN.c_str()) == 0));
+#else
+      // Compare both the name and the data rate to determine if the channel
+      // entries are equal.
+      bool rc = strcasecmp (fName.c_str(), chn.fName.c_str()) == 0 ;
+      if (rc) {
+	 rc = chn.fRate == 0 || fRate == 0 || fRate == chn.fRate ;
+	 if (!rc) {
+	    if (my_debug) cerr << "channelentry::operator==, " << chn.fName << " has different rates, " << chn.fRate << " and " << fRate << endl ;
+	 }
+	 else
+	    rc = strcasecmp (fUDN.c_str(), chn.fUDN.c_str()) == 0 ;
+      }
+      return rc ;
+#endif
    }
 
 //______________________________________________________________________________
@@ -66,17 +83,36 @@ namespace fantom {
    }
 
 //______________________________________________________________________________
-   bool channelentry::checkDuplicate (channelentry& chn)
+   bool channelentry::checkDuplicateNameRate (channelentry& chn)
    {
       if (strcasecmp (fName.c_str(), chn.fName.c_str()) == 0) {
-         chn.fIsDuplicate = true;
-         fHasDuplicate = true;
-         chn.fHasDuplicate = true;
-         return true;
+	 if ( fRate == 0 || chn.fRate == 0 || fRate == chn.fRate ) 
+	 {
+	    chn.fIsDuplicate = true;
+	    fHasDuplicate = true;
+	    chn.fHasDuplicate = true;
+	    return true;
+	 }
+	 else {
+	    if (my_debug) cerr << "channelentry::checkDuplicateNameRate() - " << chn.fName << " has multiple rates, " << chn.fRate << " and " << fRate << endl ;
+	    return false;
+	 }
       }
-      else {
-         return false;
+      else
+	 return false ;
+   }
+
+//______________________________________________________________________________
+   bool channelentry::checkDuplicateName (channelentry& chn)
+   {
+      if (strcasecmp (fName.c_str(), chn.fName.c_str()) == 0) {
+	 chn.fIsDuplicate = true;
+	 fHasDuplicate = true;
+	 chn.fHasDuplicate = true;
+	 return true;
       }
+      else
+	 return false ;
    }
 
 
@@ -146,23 +182,31 @@ namespace fantom {
    }
 
 //______________________________________________________________________________
-   bool SortChannels (channellist& list)
+   bool SortChannels (channellist& list, bool check_rate)
    {
+      if (my_debug) cerr << "SortChannels() - size of list = " << list.size() << endl ;
       sort (list.begin(), list.end());
       if (!list.empty()) {
          chniter i = list.begin();
          chniter j = list.begin();
-         for (++j; j != list.end(); ++i, ++j) {
-            i->checkDuplicate (*j);
-         }
+	 if (check_rate) {
+	    for (++j; j != list.end(); ++i, ++j) {
+	       i->checkDuplicateNameRate (*j);
+	    }
+	 } else {
+	    for (++j; j != list.end(); ++i, ++j) {
+	       i->checkDuplicateName (*j);
+	    }
+	 }
       }
+      if (my_debug) cerr << "SortChannels() - return. Size of list = " << list.size() << endl ;
       return true;
    }
 
 //______________________________________________________________________________
-   chniter FindChannel (channellist& list, const char* name)
+   chniter FindChannel (channellist& list, const char* name, const float rate)
    {
-      channelentry chn (name);
+      channelentry chn (name, rate);
       chniter i = lower_bound (list.begin(), list.end(), chn);
       if ((i != list.end()) && (*i == chn)) {
          return i;
@@ -173,9 +217,9 @@ namespace fantom {
    }
 
 //______________________________________________________________________________
-   const_chniter FindChannelConst (const channellist& list, const char* name)
+   const_chniter FindChannelConst (const channellist& list, const char* name, const float rate)
    {
-      channelentry chn (name);
+      channelentry chn (name, rate);
       const_chniter i = lower_bound (list.begin(), list.end(), chn);
       if ((i != list.end()) && (*i == chn)) {
          return i;
@@ -487,16 +531,30 @@ namespace fantom {
                      channellist& list2,
                      const channelquerylist* filter)
    {
+      if (my_debug) {
+	 cerr << "FilterChannels()" << endl ;
+	 cerr << "FilterChannels - size of list1 is " << list1.size() << endl ;
+	 cerr << "FilterChannels - size of list2 is " << list2.size() << endl ;
+	 if (filter)
+	    cerr << "FilterChannels - filter is " << filter->str() << endl ;
+      }
       if (filter == 0) {
+	 if (my_debug) cerr << "FilterChannels - filter is null" << endl ;
          copy (list1.begin(), list1.end(), back_inserter (list2));
       }
       else {
          for (const_chniter i = list1.begin(); i != list1.end(); ++i) {
+	    if (my_debug) cerr << "  i->Name() = " << i->Name() << endl ;
             if (QueryChannel (*i, filter)) {
                list2.push_back (*i);
             }
          }
       }
+      if (my_debug) {
+	 cerr << "FilterChannels at end" << endl ;
+	 cerr << "FilterChannels - size of list1 is " << list1.size() << endl ;
+	 cerr << "FilterChannels - size of list2 is " << list2.size() << endl ;
+      }
       return true;
    }
 
