@@ -801,6 +801,9 @@ namespace fantom {
       case STF:
 	 ctyp = cSTrend;
 	 break;
+      case RDS:
+	 ctyp = cRDS ;
+	 break ;
       default:
 	 break;
       }
@@ -821,6 +824,11 @@ namespace fantom {
       if (my_debug) cerr << " readChnDaqServer() - calling Available(ctyp, " << "0" << ", c) " << endl ;
       // rc holds the number of channels available if >= 0, otherwise an error code.
       rc = daq->Available (ctyp, 0, c);
+      // Get reduced data set channels from NDS2.
+      if (ctyp == cRaw) {
+	 int nRDS = daq->addAvailable (cRDS, 0, c);
+	 if (nRDS > 0) rc += nRDS;
+      }
       if (rc < 0) {
 	 cerr << "  No nds2 channels available, rc = " << rc << endl;	 
       }
