@@ -14,6 +14,9 @@
 #include <TGMsgBox.h>
 #include <time.h>
 #include <algorithm>
+#include <iostream>
+
+static int my_debug = 0 ;
 
 namespace dfm {
    using namespace std;
@@ -609,6 +612,7 @@ namespace dfm {
 //______________________________________________________________________________
    Bool_t TLGDfmSelection::UpdateChannels (bool read) 
    {
+      if (my_debug) cerr << "TLGDfmSelection::UpdateChannels(read = " << (read ? "true" : "false") << ")" << endl ;
       if (!fChannelsel) {
          return kFALSE;
       }
@@ -626,6 +630,7 @@ namespace dfm {
          if (read) {
             if (fChannels->IsEnabled()) {
                string chn = fChannels->GetText();
+	       if (my_debug) cerr << "  fChannels->GetText() = " << chn << endl ;
                return entry->setChannels (chn.c_str());
             }
             else {
@@ -641,6 +646,7 @@ namespace dfm {
             }
             else {
                fChannels->SetText (entry->getChannels().c_str());
+	       if (my_debug) cerr << "  entry->getChannels() = " << entry->getChannels() << endl ;
                fChannels->SetState (kTRUE);
             }
          }
@@ -1252,14 +1258,17 @@ namespace dfm {
 //______________________________________________________________________________     
    Bool_t TLGDfmSelection::GetChannelList (channellist& chnavail)     
    {
+      if (my_debug) std::cerr << "TLGDfmSelection::GetChannelList()" << std::endl ;
       chnavail.clear();
       UpdateChannels();
       if (fSel.isMultiple()) {
+	 if (my_debug) std::cerr << "  GetChannelList() - multiple selected dataservers" << std::endl ;
          for (selserveriter sel = fSel.begin(); 
              sel != fSel.end(); ++sel) {
             dataserver* ds = fDacc->get ((const char*)sel->getName());
             if (!ds) {
                continue;
+	       if (my_debug) std::cerr << "   dataserever name = " << sel->getName() << std::endl ;
             }
             // go through UDN list
             channelquerylist q (sel->channels());
@@ -1275,14 +1284,22 @@ namespace dfm {
       }
       else {
          // input entry (if single selection)
+	 if (my_debug) std::cerr << "  GetChannelList() - single selected dataserver" << std::endl ;
          selserverentry* entry = fSel.selectedEntry();
          dataserver* ds = 0;
          if (entry) {
             ds = fDacc->get ((const char*)entry->getName());
+	    if (my_debug) std::cerr << "   dataserever name = " << entry->getName() << std::endl ;
          }
          // go through UDN list
          if (ds) {
+	    // fSel is a selservers class.  selectedS() returns a 
+	    // selserverentry& which is fSel.fActiveS,
+	    // selserverentry::channels() returns a channellist& which is 
+	    // selserverentry.fChannels.channel
+	    // A channellist is a vector<channelentry>
             channelquerylist q = fSel.selectedS().channels();
+	    if (my_debug) cerr << "     The channelquerylist is constructed from " << fSel.selectedS().channels().size() << " channel entries" << endl ;
             for (UDNiter i = entry->getUDN().begin(); 
                 i != entry->getUDN().end(); ++i) {
                UDNInfo* f = ds->get (i->first);
@@ -1293,6 +1310,7 @@ namespace dfm {
             }
          }
       }
+      if (my_debug) std::cerr << "TLGDfmSelection::GetChannelList() - return" << std::endl ;
       return kTRUE;
    }
 
