@@ -1,4 +1,4 @@
-/* version $Id: TLGMainWindow.cc 7060 2014-03-31 22:12:28Z james.batch@LIGO.ORG $ */
+/* version $Id: TLGMainWindow.cc 7582 2016-03-01 22:25:48Z john.zweizig@LIGO.ORG $ */
 /* -*- mode: c++; c-basic-offset: 3; -*- */
 /*---------------------------------------------------------------------------*/
 /*                                                                           */
@@ -12,11 +12,7 @@
 #include <strings.h>
 #include <iostream>
 #include <fstream>
-#ifdef __GNU_STDC_OLD
-#include <gnusstream.h>
-#else
 #include <sstream>
-#endif
 #include <deque>
 #include <string>
 
