@@ -1,4 +1,4 @@
-VCSID("$(#)$Id: TLGPrint.cc 7625 2016-05-13 22:27:25Z john.zweizig@LIGO.ORG $");
+VCSID("$(#)$Id: TLGPrint.cc 7982 2018-01-07 03:51:27Z john.zweizig@LIGO.ORG $");
 
 #include "PConfig.h"
 #include "ligogui/TLGPrint.hh"
@@ -1065,8 +1065,8 @@ namespace ligogui {
          fTempfileUse = kFALSE;
       }
       else {
-	 #define L_tmpnam 32
-         char buf[L_tmpnam];
+	 //#define L_tmpnam 32
+         char buf[32];
 	 strcpy(buf, "/tmp/TLGPrint-XXXXXX");
 	 int fdtmp = mkstemp(buf);
 	 if ( fdtmp < 0 )
