@@ -1,4 +1,4 @@
-VCSID("$(#)$Id: FilterFile.cc 7389 2015-06-11 18:51:56Z james.batch@LIGO.ORG $");
+VCSID("$(#)$Id: FilterFile.cc 7865 2017-03-21 18:57:42Z james.batch@LIGO.ORG $");
 /* -*- mode: c++; c-basic-offset: 3; -*- */
 #include <time.h>
 #include <stdio.h>
@@ -1013,7 +1013,7 @@ static int linenum ;
       // create coefficients after it's called.
       for (FilterModuleList::iterator i = fModules.begin(); i != fModules.end(); ++i) 
       {
-         i->checkDesign();
+	 i->checkDesign();
 	 if (!i->errorsEmpty())
 	 {
 	    // Copy the errors from the module to the file error list. 
@@ -1029,6 +1029,17 @@ static int linenum ;
       return maxlen;
    }
 
+//______________________________________________________________________________
+   // Convert the filters to a new sample rate.  When done, set the fSample to
+   // the new rate.  This is not commonly done, but is needed if you change the
+   // rate of the model that uses these filters.
+   void FilterFile::convertFilters(double newRate)
+   {
+      for (FilterModuleList::iterator i = fModules.begin(); i != fModules.end(); ++i)
+      {
+	 i->changeSampleRate(newRate) ;
+      }
+   }
 //______________________________________________________________________________
    bool FilterFile::write (const char* filename)
    {
@@ -1098,7 +1109,7 @@ static int linenum ;
    int FilterFile::write (char* beg, int maxlen)
    {
       // Format of filter definitions and coefficients.  These are extended precision.
-      const char *format_str1 = "%-8s %i %2i %i %6i %6i %-10s %22.16g %20.16f %20.16f %20.16f %20.16f" ;
+      const char *format_str1 = "%-8s %i %2i %i %6i %6i %-10s %26.24e %20.16f %20.16f %20.16f %20.16f" ;
       const char *format_str2 = "%63s %20.16f %20.16f %20.16f %20.16f" ;
 
       if (!update()) {
@@ -1110,7 +1121,7 @@ static int linenum ;
       if (legacy_write)
       {
 	 // Replace the format with the original strings.
-	 format_str1 = "%-8s %i %2i %i %6i %6i %-10s %22.14g %20.14f %20.14f %20.14f %20.14f" ;
+	 format_str1 = "%-8s %i %2i %i %6i %6i %-10s %26.14f %20.14f %20.14f %20.14f %20.14f" ;
 	 format_str2 = "%63s %20.14f %20.14f %20.14f %20.14f" ;
       }
    
@@ -1180,20 +1191,43 @@ static int linenum ;
                string s;
                char buf[256];
 
+	       // This is 
+	       // "# DESIGN   SFM_NAME n " where n is the filter section.
                sprintf (buf, "%s   %s %i ", kSectionDesignDef,
                        mod->getName(), i);
                s += buf;
                string linebreak = " \\## ";
                linebreak.append (s.size() - 2, ' ');
                string cmd = sect.getDesign();
-	       // Strip any leading spaces from the design string.  These can
+	       // Strip any leading whitespace from the design string.  These can
 	       // creep in if the design is hand edited, for example.
 	       unsigned int space_cnt = 0 ;
-	       while (space_cnt < cmd.length() && cmd.at(space_cnt) == ' ')
+	       while (space_cnt < cmd.length() && (cmd.at(space_cnt) == ' ' || cmd.at(space_cnt) == '\n' || cmd.at(space_cnt) == '\t'))
 		  ++space_cnt ;
 	       if (space_cnt < cmd.length() && space_cnt > 0)
 		  cmd = cmd.substr(space_cnt) ;
 
+	       // Remove trailing characters.  The design string should end
+	       // with a ')' character.
+	       size_t cpos = cmd.find_last_of(')') ;
+	       if (cpos != string::npos && cpos+1 < cmd.length()) {
+		  cmd = cmd.substr(0,cpos+1) ;
+	       }
+
+	       // Now for the hard part - there may be blank lines which
+	       // should be stripped out.  In this case, there will be a 
+	       // '\n' followed by 0 or more whitespace followed by '\n'.
+	       // There may be more than one...
+	       size_t spos = 0 ; // Start for search.
+	       while ((cpos = cmd.find_first_of('\n', spos)) != string::npos && cpos+1 < cmd.length()) {
+		  cpos++ ;
+		  if (cmd.at(cpos) == ' ' || cmd.at(cpos) == '\n' || cmd.at(cpos) == '\t') {
+		     cmd.erase(cpos,1) ;
+		  }
+		  else {
+		     spos = cpos ;
+		  }
+	       }
 	       
                string::size_type pos;
                while ((pos = cmd.find ('\n')) != string::npos) 
@@ -1209,6 +1243,7 @@ static int linenum ;
                p = putline (p, end, s.c_str());
             }
          }
+	 // This visually separates the designs from the coefficient strings.
          sprintf (buf, "### %-72s ###", "");
          p = putline (p, end, buf);
       
