@@ -1,5 +1,5 @@
 /* -*- mode: c++; c-basic-offset: 3; -*- */
-/* Version $Id: TLGChannelBox.cc 7182 2014-10-01 20:44:25Z john.zweizig@LIGO.ORG $ */
+/* Version $Id: TLGChannelBox.cc 7574 2016-02-16 20:17:52Z james.batch@LIGO.ORG $ */
 /*---------------------------------------------------------------------------*/
 /*                                                                           */
 /* Module Name:  TLGChannelBox						     */
@@ -21,6 +21,7 @@
 namespace ligogui {
    using namespace std;
 
+   static const int my_debug = 0 ;
 
 //--- Some utility functions ---------------------------------------------------
 #if 0
@@ -46,6 +47,27 @@ namespace ligogui {
 
    //-----------------------------------Sort functions
 
+   int ChannelTree_channelcmpNameRate(const void *s1, const void *s2) {
+      const ChannelEntry *c1 = (ChannelEntry *) s1 ;
+      const ChannelEntry *c2 = (ChannelEntry *) s2 ;
+      int nameval = strcasecmp(c1->Name(), c2->Name()) ;
+      // If the names are identical, compare based on rate.
+      if (nameval == 0)
+      {
+	 if (c1->Rate() < c2->Rate())
+	 {
+	    if (my_debug) cerr << c1->Name() << " has two rates, " << c1->Rate() << ", " << c2->Rate() << endl ;
+	    return -1 ;
+         } else if (c1->Rate() == c2->Rate()) {
+	    return 0 ;
+	 } else {
+	    if (my_debug) cerr << c1->Name() << " has two rates, " << c1->Rate() << ", " << c2->Rate() << endl ;
+	    return 1 ;
+	 }
+      }
+      return nameval ;
+   }
+
    int ChannelTree_channelcmp (const void* s1, const void* s2) {
       return strcasecmp(((ChannelEntry*)s1)->Name(), 
 			((ChannelEntry*)s2)->Name());
@@ -190,7 +212,7 @@ extern "C"
       }
       else {
          ::qsort(fChannels, chnnum, sizeof (ChannelEntry), 
-                 ChannelTree_channelcmp);
+		 ChannelTree_channelcmpNameRate) ; // Compare both name and data rate.
       }
       cout << "Channels set from string list: " << chnnum 
 	   << " type: " << fChannelTreeType << endl;
@@ -201,6 +223,12 @@ extern "C"
    Bool_t ChannelTree::SetChannels (const char* chnnames)
    {
       ReSize(0);
+      if (my_debug) {
+	 cerr << "ChannelTree::SetChannels( char *chnnames)" << endl ;
+	 for (int i = 0; i < 256; i++) 
+	    cerr << chnnames[i] ;
+	 cerr << endl ;
+      }
       return MakeChannelList (chnnames, fChannels, fChnNum, fChannelTreeType);
    }
 
@@ -208,6 +236,7 @@ extern "C"
    ChannelTree::MakeChannelList (const char* chnnames,	ChannelEntry*& chns, 
 				 UInt_t& chnnum, Int_t tree_type)
    {
+      if (my_debug) cerr << "ChannelTree::MakeChannelList( char * chnnames, ...)" << endl ;
       // delete existing memory
       if (chns != 0) {
          delete [] chns;
@@ -278,14 +307,16 @@ extern "C"
    Bool_t 
    ChannelTree::SortChannelList(ChannelEntry chns[], UInt_t chnnum, 
 				Int_t tree_type) {
+      if (my_debug) cerr << "ChannelTree::SortChannelList()" << endl ;
       if ((tree_type & kChannelTreeSeparateSlow) != 0) {
          ::qsort(chns, chnnum, sizeof (ChannelEntry),  
 		 ChannelTree_channelcmprate);
       }
       else {
          ::qsort(chns, chnnum, sizeof (ChannelEntry), 
-                 ChannelTree_channelcmp);
+		  ChannelTree_channelcmpNameRate) ; // Compare both name and data rate.
       }
+      if (my_debug) cerr << "ChannelTree::SortChannelList() - return true" << endl ;
       return kTRUE;
    }
 
@@ -706,11 +737,11 @@ extern "C"
 
             if (fChnClient == 0) 
 	    {
-               AddChannel (pItems, entryname, fChannels[i].Name(), i);
+               AddChannel (pItems, entryname, fChannels[i].Name(), (long) (fChannels[i].Rate()));
             }
             else 
 	    {
-               AddChannel (pItems, entryname, fChannels[i].Name(), i, fLeftArrow, fLeftArrow);
+               AddChannel (pItems, entryname, fChannels[i].Name(), (long) (fChannels[i].Rate()), fLeftArrow, fLeftArrow);
             }
          }
          // oddball channel names: mark them and add at end
@@ -824,6 +855,7 @@ extern "C"
      ChannelTree (chnnames, chnnum, copy, type)
    {
       SetChannelClient(fClient);
+      // This is the ChannelTree::BuildChannelTree().
       BuildChannelTree();
    }
 
@@ -834,6 +866,7 @@ extern "C"
    : TLGComboTree (p, id, editable, option), ChannelTree (chnnames, type)
    {
       SetChannelClient(fClient);
+      // This is the ChannelTree::BuildChannelTree().
       BuildChannelTree();
    }
 
