@@ -1,4 +1,4 @@
-VCSID("@(#)$Id: TLGLBTree.cc 7338 2015-04-14 23:24:47Z ed.maros@LIGO.ORG $");
+VCSID("@(#)$Id: TLGLBTree.cc 7574 2016-02-16 20:17:52Z james.batch@LIGO.ORG $");
 
 /* -*- mode: c++; c-basic-offset: 3; -*- */
 //////////////////////////////////////////////////////////////////////////
@@ -30,6 +30,7 @@ VCSID("@(#)$Id: TLGLBTree.cc 7338 2015-04-14 23:24:47Z ed.maros@LIGO.ORG $");
 #include <TGPicture.h>
 #include <TGCanvas.h>
 
+#include <iostream> // For debug messages...  JCB
 
 namespace ligogui {
 
@@ -887,8 +888,7 @@ namespace ligogui {
                      const char *string, const char* fullname, void *userData, 
                      const TGPicture *open, const TGPicture *closed)
    {
-      TLGLBTreeEntry *item = 
-         AddItem (parent, string, fullname, open, closed);
+      TLGLBTreeEntry *item = AddItem (parent, string, fullname, open, closed);
       if (item) item->SetUserData(userData);
       return item;
    }
@@ -1172,7 +1172,7 @@ extern "C"
 
 //______________________________________________________________________________
    TLGLBTreeEntry *TLGLBTreeContainer::FindByFullname (TLGLBTreeEntry* item, 
-                     const char* fullname)
+                     const char* fullname, const int rate)
    {
    // Find item by userData.
       if (!item) {
@@ -1188,10 +1188,12 @@ extern "C"
       }
    
       while (item) {
-         if (item->fFullname && (strcmp (item->fFullname, fullname) == 0))
+	 // Always compare the name, only compare the rate if it's not -1 or 0.
+         if (item->fFullname && (strcmp (item->fFullname, fullname) == 0) && 
+	      ((rate == -1) || (rate == 0 )|| (rate == (long) (item->fUserData))))
             return item;
          if (item->fFirstchild) {
-            TLGLBTreeEntry* found = FindByFullname (item->fFirstchild, fullname);
+            TLGLBTreeEntry* found = FindByFullname (item->fFirstchild, fullname, rate);
             if (found) 
                return found;
          }
@@ -1479,8 +1481,9 @@ extern "C"
    {
    // Return id of selected listbox item.
       TLGLBTreeEntry * item = GetSelectedEntry();
-      if (item) 
+      if (item) {
          return item->GetUserData();
+      }
       else 
          return 0;
    }
@@ -1531,9 +1534,10 @@ extern "C"
    } 
 
 //______________________________________________________________________________
-   TLGLBTreeEntry *TLGLBTree::SelectByName (const char* fullname, Bool_t sel) 
+   TLGLBTreeEntry *TLGLBTree::SelectByName (const char* fullname, Bool_t sel, const int rate) 
    { 
-      TLGLBTreeEntry * item = fLbc->FindByFullname (0, fullname);
+      // fLbc is a TLGLBTreeContainer pointer.  Call TLGLBTreeContainer::FindByFullname().
+      TLGLBTreeEntry * item = fLbc->FindByFullname (0, fullname, rate);
       if (item) {
          if (sel) {
             fLbc->HighlightItem (item);
