@@ -1,4 +1,4 @@
-VCSID("@(#)$Id: DAQSocket.cc 7338 2015-04-14 23:24:47Z ed.maros@LIGO.ORG $");
+VCSID("@(#)$Id: DAQSocket.cc 7582 2016-03-01 22:25:48Z john.zweizig@LIGO.ORG $");
 /* -*- mode: c++; c-basic-offset: 3; -*- */
 //
 //    Implementation of the C++ DAQ client interface (DAQSocket) class
@@ -31,8 +31,8 @@ VCSID("@(#)$Id: DAQSocket.cc 7338 2015-04-14 23:24:47Z ed.maros@LIGO.ORG $");
 #include "DAQSocket.hh"
 #include "Time.hh"
 #include "Interval.hh"
-#include <stdio.h>
-#include <errno.h>
+#include <cstdio>
+#include <cerrno>
 #include <unistd.h>
 #include <sys/socket.h>
 #include <arpa/inet.h>
@@ -41,11 +41,7 @@ VCSID("@(#)$Id: DAQSocket.cc 7338 2015-04-14 23:24:47Z ed.maros@LIGO.ORG $");
 #include <sys/file.h>
 #include <iostream>
 #include <cstring>
-#ifndef __GNU_STDC_OLD
 #include <sstream>
-#else
-#include "gnusstream.h"
-#endif
 
 #define _TIMEOUT 10000000	/* 10 sec */
 #ifdef P__WIN32
