@@ -454,8 +454,7 @@ NDS2Socket::GetData(wait_time timeout) {
 
 //======================================  Receive proprietary data into buffer
 int 
-NDS2Socket::RecvData(wait_time timeout) 
-{
+NDS2Socket::RecvData(wait_time timeout) {
     //----------------------------------  Read in the data header. Calculate
     //                                    the record length.
     int rc = RecvRec(reinterpret_cast<char*>(&mRecvBuf.ref_header()), 
@@ -483,6 +482,8 @@ NDS2Socket::RecvData(wait_time timeout)
     //----------------------------------  Read in the data body
     mRecvBuf.reserve(ndata);
     rc = RecvRec (mRecvBuf.ref_data(), ndata, true, timeout);
+    if (mDebug) cout << "RecvData: received " << rc << "/" <<  ndata
+		     << " bytes of data" << endl;
     if (rc <= 0) return rc;
 
     //----------------------------------  Calculate offsets and swap data
@@ -640,6 +641,12 @@ NDS2Socket::RecvReconfig(count_type block_len, wait_time maxwait){
 	lp->mRate = rate;
 	if (RecvFloat(lp->mOffset) != sizeof(int)) return -1;
 	if (RecvFloat(lp->mSlope)  != sizeof(int)) return -1;
+	if (mDebug) {
+	    cout << i << " " << lp->mStatus << " " << lp->mBOffset << " "
+		 << lp->mDatatype << " " << lp->mChanType << " "
+		 << lp->mRate << " " << lp->mOffset << " " << lp->mSlope
+		 << endl;
+	}
     }
     return -2;
 }
