@@ -299,7 +299,7 @@ extern "C"
       if (IN_MULTICAST (ntohl(name.sin_addr.s_addr))) {
          multicast = true;
          // multicast: set number of hopes
-         unsigned char ttl = mcast_TTL;
+         unsigned char ttl = par.mcast_TTL;
          if (setsockopt (sock, IPPROTO_IP, IP_MULTICAST_TTL, 
                         (char*) &ttl, sizeof (ttl)) == -1) {
 	    save_error("frameSend::open Error in setsockopt");
