@@ -30,15 +30,15 @@ namespace framexmit {
 	rcvInBufferMax(16*65536),  // max. socket input buffer length (bytes)
 	rcvOutBuffersize(65536),   // receive socket output buffer length(bytes)
 	rcvpacketbuffersize(1024), // receiver packet buffer length (packets)
-      maxRetry(5),                 // maximum number of retries to rebroadcast
-      retryTimeout(250000),        // timeout for each retry (usec)
-      maxSequenceOutOfSync(5),     // maximum a sequence can be out of sync
-      retransmissionAverage(10.1), // number of data segments used to determine
+	maxRetry(5),               // maximum number of retries to rebroadcast
+	retryTimeout(250000),      // timeout for each retry (usec)
+	maxSequenceOutOfSync(5),   // maximum a sequence can be out of sync
+	retransmissionAverage(10.1), // number of data segments used to determine
                                    // the average retransmission rate
-      rcvErrorRate(0),             // artifically introduced receiver error
+	rcvErrorRate(0),           // artifically introduced receiver error
                                    // rate, only valid if compiled with DEBUG
-      sndMaxPacketRebroadcast(3),  // maximum times a packet is rebroadcast
-      sndRebroadcastEpoch(250000), // Length of rebroadcast epoch (usec)
+	sndMaxPacketRebroadcast(3),  // maximum times a packet is rebroadcast
+	sndRebroadcastEpoch(250000), // Length of rebroadcast epoch (usec)
 #if defined(PBTEASEPACKET0)
         teasePacket0(0),           // Default to teasing out unseen packets
 	lastFrameDurationDefault(4), // The duration of the last frame (in seconds)
@@ -49,7 +49,7 @@ namespace framexmit {
 #endif // PBTEASEPACKET0
       minInterBufferTime(0),       // Minimum time (usec) between buffers
       nRepeatPktMax(0),            // Maximum buffer size (pkts) to be repeated
-      nRepeatPktNum(0)            // Number of packets to be repeated
+      nRepeatPktNum(0)             // Number of packets to be repeated
    {
    }
 
@@ -98,8 +98,10 @@ namespace framexmit {
    //=====================================  Set a parameter
    bool
    fxparameters::set_parameter(const string& name, double data) {
-      // maximum times a packet is rebroadcast
-      if (name == "sndMaxPacketRebroadcast") {
+      if (name == "mcast_TTL") {
+	 mcast_TTL = data;  // time-to-live counter preset
+      }
+      else if (name == "sndMaxPacketRebroadcast") {
 	 sndMaxPacketRebroadcast = data;
       }
       else if (name == "sndRebroadcastEpoch") {
@@ -111,6 +113,9 @@ namespace framexmit {
       else if (name == "packetBurstInterval") {
 	 packetBurstInterval = data;  // delay between successive bursts
       }
+      else if (name == "rcvDelayTick") {
+	 rcvDelayTick = data;  // delay between successive bursts
+      }
       else if (name == "lostPacketWait") {
 	 lostPacketWait = data;  // Time to wait for missing packet (usec)
       }
