@@ -159,7 +159,7 @@ table::addRow(void) {
 
 //======================================  Erase one or more rows
 void 
-table::eraseRow(int row, int count) throw(runtime_error)
+table::eraseRow(int row, int count)
 {
    if (row < 0 || row >= mRow) throw runtime_error("Invalid row number");
    int nCol = getNColumn();
@@ -190,7 +190,7 @@ table::eraseRow(int row, int count) throw(runtime_error)
 //======================================  Insert a number into a cell
 void 
 table::insertData(int row, int col, double x, int wid, int prec) 
-   throw(runtime_error)
+  
 {
    ostringstream ss;
    if (wid>0)  ss.width(wid);
@@ -206,7 +206,7 @@ table::insertData(int row, int col, double x, int wid, int prec)
 //======================================  Insert a number into a cell
 void 
 table::insertData(int row, int col, long x, int wid, int radix) 
-   throw(runtime_error)
+  
 {
    ostringstream ss;
    if (wid>0)  ss.width(wid);
@@ -233,7 +233,6 @@ table::insertData(int row, int col, long x, int wid, int radix)
 //======================================  Insert text into a cell
 void 
 table::insertData(int row, int col, const string& txt) 
-   throw(runtime_error)
 {
    insertData(row, col, text(txt));
 }
@@ -241,7 +240,6 @@ table::insertData(int row, int col, const string& txt)
 //======================================  Insert data into a cell
 void 
 table::insertData(int row, int col, const object& obj) 
-   throw(runtime_error)
 {
    int inx = inxrc(row, col);
    if ( mData[inx] == 0 ) mData[inx] = new cell();
@@ -250,7 +248,7 @@ table::insertData(int row, int col, const object& obj)
 
 //======================================  Insert a row in front of "row"
 void 
-table::insertRow(int row) throw(runtime_error)
+table::insertRow(int row)
 {
    int svEnd = mData.size();
    addRow();
