@@ -277,7 +277,7 @@ Translator::Export(const void* lcl, size_type lclen, Buffer& b) {
     size_type      itab = 0;
     bool        cont = true;
 
-    if (isHeaderOK()) {
+    if (isHeaderOK() && mOffset <= nbyt) {
         nbyt   -= mOffset;
 	in     += mOffset;
 	itab    = mLvPtr[mLevel];
@@ -432,9 +432,6 @@ Translator::Export(const void* lcl, size_type lclen, Buffer& b) {
 	  else if (!(--mLvRpt[mLevel])) {  
 	    mLevel -= 1;}
 
-	  else if ((mLvRpt[mLevel] < 0) && (nbyt <= 0)) {
-	    mLevel -= 1;}
-
 	  else {
 	    itab = mLvPtr[mLevel];}
 	  break;
@@ -465,7 +462,7 @@ Translator::Export(const void* lcl, size_type lclen, Buffer& b) {
 		    else            loop = 2;
 		else if (mFormat == NO_TRANS) loop = 1;
 	    } else if (wc < rep) {
-	        if ((nbyt <= 0) || (obyt > lwd)) loop = 3;
+	        if ((nbyt == 0) || (obyt > lwd)) loop = 3;
 		else loop = 2;
 	    }
 	}
@@ -670,10 +667,6 @@ Translator::Import(const Buffer& b, void* lcl, size_type maxlen,
 	    if (!(mLvRpt[mLevel] -= 1)) {
 	      mLevel -= 1;}
 
-	    else if ((mLvRpt[mLevel] < 0) &&
-		     !isMultiBuffer() && (nbyt <= 0)) {
-	      mLevel -= 1;}
-
 	    else {
 	      itab = mLvPtr[mLevel];}
 	    break;
@@ -710,7 +703,7 @@ Translator::Import(const Buffer& b, void* lcl, size_type maxlen,
 		    loop = 1;
 		}
 	    } else if (wc < rep) {
-	        if (nbyt <= 0)       loop = 2;
+	        if (nbyt == 0)       loop = 2;
 		else if (obyt < lwd) loop = 3;
 	        else                 loop = 4;
 	    }
