@@ -1,4 +1,4 @@
-VCSID("@(#)$Id: Xsil.cc 7338 2015-04-14 23:24:47Z ed.maros@LIGO.ORG $");
+VCSID("@(#)$Id: Xsil.cc 7582 2016-03-01 22:25:48Z john.zweizig@LIGO.ORG $");
 #define __NOMEMMAPFILE
 #include "PConfig.h"
 #include "xml/Xsil.hh"
@@ -6,11 +6,7 @@ VCSID("@(#)$Id: Xsil.cc 7338 2015-04-14 23:24:47Z ed.maros@LIGO.ORG $");
 #include "tconv.h"
 #include <stdio.h>
 #include <inttypes.h>
-#ifdef __GNU_STDC_OLD
-#include <gnusstream.h>
-#else
 #include <sstream>
-#endif
 #include <fstream>
 #include <iostream>
 #include <cstring>
