@@ -4,11 +4,7 @@
 #include <stdio.h>
 #include <cstring>
 #include <cstdlib>
-#ifdef __GNU_STDC_OLD
-#include <gnusstream.h>
-#else
 #include <sstream>
-#endif
 
 namespace xml {
    using namespace std;
