@@ -594,7 +594,7 @@ GainMon::ProcessData(void) {
             //----- Copy data to strain_noise_ampl and clean up.
 	    strain_noise_ampl = PSDed_data;
 	    strain_noise_ampl.setData(PSDed_data.getNStep() + 1, strainvalues);
-	    delete strainvalues;
+	    delete[] strainvalues;
 
 	} else { 
 
@@ -613,7 +613,7 @@ GainMon::ProcessData(void) {
 	    }
 	    strain_noise_ampl.setData(nsteps + 1, data);
 	    f_7_3.setData(nsteps + 1, data);
-	    delete data;
+	    delete[] data;
       	}
 	
 	//---------- Shift DMTViewer TSeries data one time step.
