@@ -8,6 +8,9 @@
 
 using namespace std;
 
+static const string env_char_list =
+  "ABCDEFGHIJKLMNOPQRSTUVWXYZ_abcdefghijklmnopqrstuvwxyz0123456789";
+
 namespace wpipe {
 
   //====================================  Skip pointer past spaces and tabs.
@@ -211,30 +214,52 @@ namespace wpipe {
     return r;
   }
 
-  
   //====================================  Parse a list of strings.
   str_vect
   eval_str(const std::string& str) {
     str_vect r;
     string s;
     const char* ptr = str.c_str();
-    bool instr = false;
-    while (*ptr && *ptr != '}') {
+    bool instr = false, plaintext = true;
+    int inbrace=0;
+    int strdelim = 0;
+    while (*ptr) {
       switch (*ptr) {
+      //--------------------------------  String delimiters
       case '\'':
       case '"':
-	if (instr) {
+	//------------------------------  Start of string
+	if (!instr) {
+	  instr = true;
+	  strdelim = *ptr;
+	  plaintext = false;
+	}
+	//------------------------------  end of string
+	else if (*ptr == strdelim) {
 	  r.push_back(s);
 	  s.clear();
+	  strdelim = 0;
+	  instr = false;
+	}
+	//------------------------------  wrong type delimiter in string
+	else {
+	  s += *ptr;	  
 	}
-	instr = !instr;
 	break;
+	
+      //--------------------------------  inter-string delimiters
       case '{':
-      case ' ':
+      case '}':
       case ',':
-	if (!instr) break;
+      case ' ':
+	if (!instr) {
+	  if (*ptr == '{') inbrace++;
+	  else if (*ptr == '}') inbrace--;
+	  plaintext = false;
+	  break;
+	}
       default:
-	if (instr) {
+	if (instr || plaintext) {
 	  s += *ptr;
 	} else {
 	  error("Unexpected character");
@@ -242,7 +267,13 @@ namespace wpipe {
       }
       ptr++;
     }
-    if (instr) error("Unterminated string");
+    if (plaintext && !s.empty()) {
+      r.push_back(s);
+    } else if (instr) {
+      error("Unterminated string");
+    } else if (inbrace) {
+      error("Unterminated braces");
+    }
     //cout << "eval_str output = [";
     //for (size_t i=0; i<r.size(); i++) cout << " " << r[i];
     //cout << " ]" << endl;
@@ -332,6 +363,23 @@ namespace wpipe {
     return ret;
   }
 
+  //====================================  Substitute environment variables
+  std::string
+  subst_env(const std::string& str) {
+    string path = str;
+    size_t ienv = path.find("$");
+    while (ienv != string::npos) {
+      size_t lenv = path.find_first_not_of(env_char_list, ienv+1);
+      if (lenv == string::npos) lenv = path.size() - ienv;
+      else                      lenv -= ienv;
+      const char* cenv = getenv(path.substr(ienv+1, lenv-1).c_str());
+      if (cenv) path.replace(ienv, lenv, cenv);
+      else      path.erase(ienv, lenv);
+      ienv = path.find("$");
+    }
+    return path;
+  }
+
   //====================================  Convert string to lower case
   std::string 
   tolower(const std::string& str) {
@@ -376,3 +424,41 @@ namespace wpipe {
     if (thresh >= level) cout << txt << endl;
   }
 }
+
+#include <sys/wait.h>
+
+namespace matlab {
+  std::string
+  system(const std::string& cmd) {
+    int fd[2];
+    if (pipe(fd) < 0) {
+      perror("Error creating pipe in system");
+      return "";
+    }
+    pid_t pid = fork();
+    if (pid < 0) {
+      perror("error forking process in system");
+      close(fd[0]);
+      close(fd[1]);
+    } else if (!pid) {
+      if (dup2(fd[1], 1) < 0) perror("dup2 error in system");
+      int rc = execl("/bin/sh", "/bin/sh", "-c", cmd.c_str());
+      close(fd[1]);
+    } else {
+      char buf[257];
+      int status;
+      waitpid(pid, &status, 0);
+      string result;
+      int rc = read(fd[0], buf, 256);
+      result += string(buf, rc);
+      while (rc == 256) {
+	rc = read(fd[0], buf, 256);
+	result += string(buf, rc);
+      }
+      if (rc < 0) perror("error reading pipe in system");
+      close(fd[0]);
+      return result;
+    }
+    return ""; // error return
+  }
+}
