@@ -41,7 +41,6 @@ namespace wpipe {
    const double tfbox::_dt = 0.0;        // Omicron slop constant
    const bool   tfbox::_flextile = false; // Omicron flexible tiles
 
-
    //====================================  tfBox constructor
    tfbox::tfbox(const wevent& evt, double tInflation, double fInflation) {
       double delta_t = tInflation * evt.duration;
@@ -54,13 +53,13 @@ namespace wpipe {
    }
 
    //====================================  tfbox test overlap
-   bool 
+   inline bool 
    tfbox::overlap(const tfbox& box) const {
       return _tmin < (box._tmax + _dt) && box._tmin < (_tmax + _dt) && 
-	 _fmin < box._fmax && box._fmin < _fmax;
+	     _fmin < box._fmax         && box._fmin < _fmax;
    }
 
-   //====================================  tfbox test overlap
+   //====================================  tfbox merge boxes
    void
    tfbox::merge(const tfbox& box) {
        if (box._tmin < _tmin) _tmin = box._tmin;
