@@ -2,6 +2,8 @@
 #include "wfigure.hh"
 #include "TCanvas.h"
 #include "DVecType.hh"
+#include "Hanning.hh"
+#include "WelchPSD.hh"
 #include <iostream>
 #include <fstream>
 #include <sstream>
@@ -164,6 +166,34 @@ wfigure::set_format(const std::string& fmt) {
     }
 }
 
+//======================================  plot an amplitude spectrogram
+void 
+wfigure::asdspectrogram(const TSeries& data, Interval dT,
+			const dble_vect& fRange,
+			const std::string& channelName) {
+    Hanning hw;
+    WelchPSD w(Interval(1.0), 0.50, &hw);
+    asdspectrogram(data, dT, fRange, channelName, w);
+}
+
+//======================================  plot an amplitude spectrogram
+void 
+wfigure::asdspectrogram(const TSeries& data, Interval dT, 
+			const dble_vect& fRange, const string& title,
+			const WelchPSD& psdest) {
+    Interval tStep = data.getTStep();
+    double   fNy   = 0.5/double(tStep);
+    double fMax = fRange[1];
+    if (fMax > fNy) fMax = fNy;
+    
+    _plot.set_color(600);
+    string yttl = "Frequency [Hz]";
+    _plot.ylabel(yttl);
+    double tink = _plot.xTimeScale(dT, "Time");
+    _plot.title(title);
+    _plot.spectrogram(data, dT, fRange[0], fMax, &psdest);
+}
+
 //======================================  plot a time series
 void 
 wfigure::wtimeseries(const TSeries& ts, const Time& centerTime, 
