@@ -47,6 +47,7 @@ wplot_syntax(void) {
 const std::string evnt_raw   = "eventgram_raw";
 const std::string evnt_white = "eventgram_whitened";
 const std::string evnt_auto  = "eventgram_autoscaled";
+const std::string spec_asd   = "asd_spectrogram";
 const std::string spec_raw   = "spectrogram_raw";
 const std::string spec_white = "spectrogram_whitened";
 const std::string spec_auto  = "spectrogram_autoscaled";
@@ -59,7 +60,6 @@ const std::string tser_hipas = "timeseries_highpassed";
 int 
 main(int argc, const char* argv[]) {
    plot_chan par;
-   par.reset();
 
    try {
       plot_config(argc, argv, par);
@@ -197,10 +197,12 @@ wpipe::wplot(const plot_chan& pchan) {
    double highPassCutoff = -1;
    double lowPassCutoff = -1;
    double whiteningDuration = -1;
+   int minAllowableIndep = 50;
 
    wtile tiling(timeRange, qRange, frequencyRange, sampleFrequency, 
 		maximumEnergyLoss, highPassCutoff, lowPassCutoff, 
-		whiteningDuration, pchan.transientFactor, debugLevel);
+		whiteningDuration, pchan.transientFactor, 
+		minAllowableIndep, debugLevel);
 
 
    //  The threshold is set to yield the specified false event rate when 
@@ -468,6 +470,15 @@ wpipe::wplot(const plot_chan& pchan) {
 				     channelNameString);
 	 }
 
+	 //-----------------------------  ASD spectrogram
+	 else if (pltType == spec_asd) {
+	    Interval dT = rawData[0].getInterval()
+	                / double(pchan.plotHorizontalResolution);
+	    figureHandle.asdspectrogram(rawData[0], dT,
+					plotFrequencyRange, 
+					channelNameString);
+	 }
+
 	 //-----------------------------  Raw spectrogram
 	 else if (pltType == spec_raw) {
 	    figureHandle.set_smooth(pchan.nSmooth, pchan.smoothOpt);
@@ -475,7 +486,8 @@ wpipe::wplot(const plot_chan& pchan) {
 				      centerTime, 
 				      tRange, plotFrequencyRange, 
 				      qRange, plotNormalizedEnergyRange, 
-				      pchan.plotHorizontalResolution);
+				      pchan.plotHorizontalResolution, 
+				      pchan.plotVerticalResolution);
 	 }
 
 	 //-----------------------------  Whitened spectrogram
@@ -485,7 +497,8 @@ wpipe::wplot(const plot_chan& pchan) {
 				      centerTime, tRange, 
 				      plotFrequencyRange, 
 				      qRange, plotNormalizedEnergyRange, 
-				      pchan.plotHorizontalResolution);
+				      pchan.plotHorizontalResolution, 
+				      pchan.plotVerticalResolution);
 	 }
 
 	 //-----------------------------  Auto-scaled spectrogram
@@ -495,7 +508,8 @@ wpipe::wplot(const plot_chan& pchan) {
 				      centerTime, tRange,
 				      plotFrequencyRange, qRange, 
 				      autoNormalizedEnergyRange, 
-				      pchan.plotHorizontalResolution);
+				      pchan.plotHorizontalResolution, 
+				      pchan.plotVerticalResolution);
 	 }
 
 	 //-----------------------------  Raw eventgram
@@ -557,7 +571,8 @@ wpipe::wplot(const plot_chan& pchan) {
 
 //======================================  Search channel constructor.
 plot_chan::plot_chan(void) {
-   clear();
+   def_params();
+   reset();
 }
 
 //======================================  Plot type list
@@ -566,85 +581,58 @@ static const char* plot_types[] = {
       "timeseries_raw", "timeseries_whitened", "timeseries_highpassed", 
       "eventgram_whitened", "eventgram_raw", "eventgram_autoscaled", 0};
 
-
-//======================================  Clear search channel descriptor.
-void
-plot_chan::clear(void) {
-   channelName.clear();
-   eventTime = Time(0);
-   frameType.clear();
-   timeShifts.clear();
-   sampleFrequency = 0;
-   searchTimeRange = 0;
-   searchFrequencyRange.clear();
-   searchQRange.clear();
-   searchMaximumEnergyLoss = 0;
-   whiteNoiseFalseRate = 0;
-   eventThreshold = 0;
-   searchWindowDuration = 0;
-   plotTimeRanges.clear();
-   plotFrequencyRange.clear();
-   plotNormalizedEnergyRange.clear();
-   colorMap.clear();
-   colorMapFile.clear();
-   nSmooth = 0;
-   smoothOpt.clear();
-   debugLevel = 0;
-}
-
 //======================================  Set up parameter definitions.
 void
-plot_chan::def_params(param_list& par) {
-   par.add_param("channelName", channelName);
-   par.add_param("frameType", frameType);
-   par.add_param("timeShifts", timeShifts);
-   par.add_param("frameCacheFile", frameCacheFile);
-   par.add_param("ndsServer", ndsServer);
-   par.add_param("outDir", outDir);
-   par.add_param("outputDirectory", outDir); // backward compatible alias
-   par.add_param("plotFile", plotFile);
-   par.add_param("eventTime", eventTime);
-   par.add_param("sampleFrequency", sampleFrequency);
-   par.add_param("searchTimeRange", searchTimeRange);
-   par.add_param("searchFrequencyRange", searchFrequencyRange);
-   par.add_param("searchQRange", searchQRange);
-   par.add_param("searchMaximumEnergyLoss", searchMaximumEnergyLoss);
-   par.add_param("whiteNoiseFalseRate", whiteNoiseFalseRate);
-   par.add_param("eventThreshold", eventThreshold);
-   par.add_param("searchWindowDuration", searchWindowDuration);
-   par.add_param("plotTimeRanges", plotTimeRanges);
-   par.add_param("plotFrequencyRange", plotFrequencyRange);
-   par.add_param("plotNormalizedEnergyRange", plotNormalizedEnergyRange);
-   par.add_param("plotType", plotType);
-   par.add_param("transientFactor", transientFactor);
-   par.add_param("outlierFactor", outlierFactor);
-   par.add_param("plotHorizontalResolution", plotHorizontalResolution);
-   par.add_param("plotDurationInflation", plotDurationInflation);
-   par.add_param("plotBandwidthInflation", plotBandwidthInflation);
-   par.add_param("plotThreshold", plotThreshold);
-   par.add_param("maximumSignificants", maximumSignificants);
-   par.add_param("maximumMosaics", maximumMosaics);
-   par.add_param("plotThumbnail", plotThumbnail);
-   par.add_param("nSmooth", nSmooth);
-   par.add_param("smoothOption", smoothOpt);
-   par.add_param("plotSize", plotSize);
-   par.add_param("colorMap", colorMap);
-   par.add_param("colorMapFile", colorMapFile);
-   par.add_param("plotFormat", plotFormat);
-   par.add_param("zUnits", zUnits);
-   par.add_param("debugLevel", debugLevel);
+plot_chan::def_params(void) {
+   add_param("channelName", channelName);
+   add_param("frameType", frameType);
+   add_param("timeShifts", timeShifts);
+   add_param("frameCacheFile", frameCacheFile);
+   add_param("ndsServer", ndsServer);
+   add_param("outDir", outDir);
+   add_param("outputDirectory", outDir); // backward compatible alias
+   add_param("plotFile", plotFile);
+   add_param("eventTime", eventTime);
+   add_param("sampleFrequency", sampleFrequency);
+   add_param("searchTimeRange", searchTimeRange);
+   add_param("searchFrequencyRange", searchFrequencyRange);
+   add_param("searchQRange", searchQRange);
+   add_param("searchMaximumEnergyLoss", searchMaximumEnergyLoss);
+   add_param("whiteNoiseFalseRate", whiteNoiseFalseRate);
+   add_param("eventThreshold", eventThreshold);
+   add_param("searchWindowDuration", searchWindowDuration);
+   add_param("plotTimeRanges", plotTimeRanges);
+   add_param("plotFrequencyRange", plotFrequencyRange);
+   add_param("plotNormalizedEnergyRange", plotNormalizedEnergyRange);
+   add_param("plotType", plotType);
+   add_param("transientFactor", transientFactor);
+   add_param("outlierFactor", outlierFactor);
+   add_param("plotHorizontalResolution", plotHorizontalResolution);
+   add_param("plotVerticalResolution", plotVerticalResolution);
+   add_param("plotDurationInflation", plotDurationInflation);
+   add_param("plotBandwidthInflation", plotBandwidthInflation);
+   add_param("plotThreshold", plotThreshold);
+   add_param("maximumSignificants", maximumSignificants);
+   add_param("maximumMosaics", maximumMosaics);
+   add_param("plotThumbnail", plotThumbnail);
+   add_param("nSmooth", nSmooth);
+   add_param("smoothOption", smoothOpt);
+   add_param("plotSize", plotSize);
+   add_param("colorMap", colorMap);
+   add_param("colorMapFile", colorMapFile);
+   add_param("plotFormat", plotFormat);
+   add_param("zUnits", zUnits);
+   add_param("debugLevel", debugLevel);
 }
 
 //======================================  Set configuration struct to defaults
 void
 plot_chan::reset(void) {
-   clear();
+   clear_all();
    const double dInf(1.0/0.0);
-   channelName.clear();
    frameType.resize(1, "NDS2");
    timeShifts.resize(1, 0.0);
    ndsServer = "nds.ligo.caltech.edu:31200";
-   eventTime = Time(0);
    sampleFrequency = 4096;
    searchTimeRange = 64;
    double fRange[] = {0, dInf};
@@ -672,15 +660,11 @@ plot_chan::reset(void) {
 
    // display parameters
    plotHorizontalResolution = 512;
+   plotVerticalResolution = 256;
    plotDurationInflation = 0.5;
    plotBandwidthInflation = 0.5;
-   nSmooth = 0;
-   smoothOpt.clear();
-   plotSize.clear();
    plotFormat = "png";
    plotThumbnail = false;
-   colorMap.clear();
-   colorMapFile.clear();
    zUnits = "NormE";
 
    // limits on number of significant tiles
@@ -691,9 +675,7 @@ plot_chan::reset(void) {
 //======================================  Scan the configuration.
 void
 wpipe::plot_config(int argc, const char* argv[], plot_chan& p) {
-   param_list par;
-   p.def_params(par);
-   
+  
    //-----------------------------------  Get init file parameters
    string parfile;
    const char* homep = getenv("HOME");
@@ -702,7 +684,8 @@ wpipe::plot_config(int argc, const char* argv[], plot_chan& p) {
       parfile += "/";
    }
    parfile += ".wplotrc";
-   if (!access(parfile.c_str(), R_OK)) {
+   if (exist(parfile, "file")) {
+      cout << "Opening file: " << parfile << endl;
       ifstream in(parfile.c_str());
       while (in.good()) {
 	 string line;
@@ -711,13 +694,7 @@ wpipe::plot_config(int argc, const char* argv[], plot_chan& p) {
 	 size_t inx = line.find("#");
 	 if (inx != string::npos) line.erase(inx);
 	 if (!line.empty()) {
-	    inx = line.find_first_of(":=");
-	    // parse configuration line
-	    string parameterName = deblank(line.substr(0, inx));
-	    string parameterValue;
-	    if (inx != string::npos) parameterValue=deblank(line.substr(inx+1));
-	    else                     parameterValue="true";
-	    par.set_param(parameterName, parameterValue);
+	    p.assign_param(line, ":=");
 	 }
       }
    }
@@ -734,21 +711,8 @@ wpipe::plot_config(int argc, const char* argv[], plot_chan& p) {
 	 error("Help requested");
       }
 
-      // locate field separator
-      string::size_type colonIndex = cmdstr.find_first_of(":=");
-
-      // if (field separator not located, report syntax error
-      if (colonIndex == string::npos) {
-	 cerr << "syntax error parsing command line argument: " 
-	      << cmdstr << endl;
-	 error("syntax error processing configuration file");
-      }
-
       // parse configuration line
-      string parameterName = cmdstr.substr(0, colonIndex);
-      string parameterValue = cmdstr.substr(colonIndex + 1);
-
-      par.set_param(parameterName, parameterValue);
+      p.assign_param(cmdstr, ":=");
 
    }      // end loop over command line arguments.
    p.validate();
@@ -757,9 +721,7 @@ wpipe::plot_config(int argc, const char* argv[], plot_chan& p) {
 //======================================  Display channel parameters.
 void
 plot_chan::display(std::ostream& out) const {
-   param_list par;
-   const_cast<plot_chan*>(this)->def_params(par);
-   par.display(out, "  ");
+   param_list::display(out, "  ");
 }
 
 //======================================  Check parameter validity
