@@ -95,8 +95,6 @@ namespace wpipe {
 	 double df   = 2.0 * edgewid * fSample / fRawSample;
 	 int ncof = 0;
 	 double* h = 0;
-	 cout << "filter params: edge, df, attenuaiton " << edge <<", " << df
-	      << ", " << attenuation << endl;
 	 int stat = FirW(ncof, 6, 1, edge, 0.0, df, attenuation, h);
 	 if (stat > 0) {
 	    filter_coefs.ReSize(ncof);
@@ -144,8 +142,6 @@ namespace wpipe {
 
       //--------------------------------  Filter and decimate
       long downSampleFactor = 1.0 / (tsin.getTStep() * fSample);
-      cout << "resampling " << tsin.getStartTime().getS() << "-"
-	   << tsin.getEndTime().getS() << " factor " << downSampleFactor<< endl;
       TSeries aa = filt(tsin);
 #ifdef WRESAMPLE_PLOTS
       GDSPlot p;
