@@ -6,7 +6,8 @@
 #include "wfigure.hh"
 #include "wframecache.hh"
 #include "wmeasure.hh"
-#include "wreaddata.hh"
+//#include "wreaddata.hh"
+#include "channelCache.hh"
 #include "wresample.hh"
 #include "wtile.hh"
 #include "wtransform.hh"
@@ -16,6 +17,7 @@
 #include "TSeries.hh"
 #include "fSeries/DFT.hh"
 #include "Interval.hh"
+#include "redirect_std.hh"
 
 //======================================  C++ and system headers.
 #include <fstream>
@@ -30,6 +32,8 @@
 using namespace std;
 using namespace wpipe;
 
+static const double dInf(1.0/0.0);
+
 //======================================  Syntax output function
 static void
 wscan_syntax(void) {
@@ -77,7 +81,15 @@ main(int argc, const char* argv[]) {
       debugLevel = strtol(argv[6],0,0);
    }
 
-   cout << "wscan parameters: " <<endl;
+   if (generateReport) {
+      string logfile = outDir;
+      if (!outDir.empty() && outDir[outDir.size()-1] != '/') logfile += "/";
+      logfile += "log.txt";
+      wlog(debugLevel, 1, string("output redirected to ") + logfile);
+      redirect_std(logfile, 3);
+   }
+
+   cout << "wscan parameters: " << endl;
    cout << "   event time       = " << eventTimeString << endl;
    cout << "   config file      = " << configFile << endl;
    cout << "   frame cache      = " << frameCacheFile << endl;
@@ -85,9 +97,46 @@ main(int argc, const char* argv[]) {
    cout << "   generate report  = " << boolstr_yn(generateReport) << endl;
    cout << "   debug level      = " << debugLevel << endl;
 
+
+   // default configuration parameters
+   search_chan defchan;
+   defchan.sampleFrequency = 4096;
+   defchan.searchTimeRange = 64;
+   double fRange[] = {0, dInf};
+   defchan.searchFrequencyRange = dble_vect(fRange, fRange+2);
+   double qRange[] = {4, 64};
+   defchan.searchQRange = dble_vect(qRange, qRange+2);
+   defchan.searchMaximumEnergyLoss = 0.2;
+   defchan.whiteNoiseFalseRate = 1e-2;
+   defchan.searchWindowDuration = 0.1;
+   defchan.whiteningDuration = -1.0;
+   double plotRange[] = {1, 4, 16};
+   defchan.plotTimeRanges = dble_vect(plotRange, plotRange+3);
+   double plotFRange[]  = {0, dInf};
+   defchan.plotFrequencyRange = dble_vect(plotFRange, plotFRange+2);
+   //notused double defaultPlotMaximumEnergyLoss = 0.2;
+   double plotNormER[] = {0, 25.5};
+   defchan.plotNormalizedEnergyRange = dble_vect(plotNormER, plotNormER+2);
+   //notused bool defaultAlwaysPlotFlag = 0;
+   defchan.plotHorizontalResolution = 512;
+   defchan.plotVerticalResolution = 256;
+
+   try {
+      for (int i=7; i<argc; i++) {
+	 cout << "Add parameter: " << argv[i] << endl;
+	 defchan.assign_param(argv[i]);
+	 cout << "Incremental parameter list: " << endl;
+	 defchan.display(cout);
+      }
+   }
+   catch (exception& e) {
+      cerr << "caught exception assigning parameter: " << e.what() << endl;
+      exit(1);
+   }
+   
    try {
       wscan(eventTimeString, configFile, frameCacheFile, outDir,
-	    generateReport, debugLevel);
+	    generateReport, debugLevel, defchan);
    }
    catch (exception& e) {
       cerr << "caught exception: " << e.what() << endl;
@@ -140,12 +189,20 @@ insert_scripts(ostream& file) {
    }
 }
 
+//======================================  Empty ts test
+inline bool
+any_ts_empty(const wpipe::tser_vect& v) {
+   for (size_t i=0; i<v.size(); i++) {
+      if (v[i].empty()) return true;
+   }
+   return false;
+}
+
 //======================================  scan function.
 void
 wpipe::wscan(const std::string& eventTimeString, const std::string& configFile, 
 	     const std::string& frameCacheFile, const std::string& outDir, 
-	     bool generateReport, int debugLevel) {
-   const double dInf(1.0/0.0);
+	     bool generateReport, int debugLevel, const search_chan& defchan) {
 
    wfigure figureHandle;
 
@@ -153,26 +210,6 @@ wpipe::wscan(const std::string& eventTimeString, const std::string& configFile,
    //                                   defaults                              //
    /////////////////////////////////////////////////////////////////////////////
 
-   // default configuration parameters
-   search_chan defchan;
-   defchan.sampleFrequency = 4096;
-   defchan.searchTimeRange = 64;
-   double fRange[] = {0, dInf};
-   defchan.searchFrequencyRange = dble_vect(fRange, fRange+2);
-   double qRange[] = {4, 64};
-   defchan.searchQRange = dble_vect(qRange, qRange+2);
-   defchan.searchMaximumEnergyLoss = 0.2;
-   defchan.whiteNoiseFalseRate = 1e-2;
-   defchan.searchWindowDuration = 0.1;
-   double plotRange[] = {1, 4, 16};
-   defchan.plotTimeRanges = dble_vect(plotRange, plotRange+3);
-   double plotFRange[]  = {0, dInf};
-   defchan.plotFrequencyRange = dble_vect(plotFRange, plotFRange+2);
-   //notused double defaultPlotMaximumEnergyLoss = 0.2;
-   double plotNormER[] = {0, 25.5};
-   defchan.plotNormalizedEnergyRange = dble_vect(plotNormER, plotNormER+2);
-   //notused bool defaultAlwaysPlotFlag = 0;
-
    /////////////////////////////////////////////////////////////////////////////
    //                            hard coded parameters                        //
    /////////////////////////////////////////////////////////////////////////////
@@ -184,7 +221,6 @@ wpipe::wscan(const std::string& eventTimeString, const std::string& configFile,
    //notused double bandwidthInflation = 1.0;
 
    // display parameters
-   int plotHorizontalResolution = 512;
    double plotDurationInflation = 0.5;
    double plotBandwidthInflation = 0.5;
 
@@ -370,10 +406,17 @@ wpipe::wscan(const std::string& eventTimeString, const std::string& configFile,
    /////////////////////////////////////////////////////////////////////////////
    ofstream htmlFID;
    if (generateReport) {
-
+      // copy the style sheet.
+      ostringstream cp_style_cmd;
+      cp_style_cmd << "/bin/cp " << OMEGA_DATA << "/wstyle.css "
+		   << outputDirectory << "/wstyle.css";
+      if (system(cp_style_cmd.str().c_str())) {
+	 wlog(debugLevel, 0, "Failed to copy wstyle.css to html directory.");
+      }
+	 
       // report status
       wlog(debugLevel, 1, "opening html report");
-
+      
       // open web page
       string fullHtmlFile = outputDirectory + "/" + htmlFile;
       htmlFID.open(fullHtmlFile.c_str());
@@ -442,15 +485,39 @@ wpipe::wscan(const std::string& eventTimeString, const std::string& configFile,
   
    resampler resample;
 
+   channelCache chanCache(frameCache, debugLevel);
+   for (int channelNumber=0; channelNumber<numberOfChannels; channelNumber++) {
+      const search_chan& config_i = configuration[channelNumber];
+      double    sampleFrequency = config_i.sampleFrequency;
+      double    timeRange = config_i.searchTimeRange;
+      // find closest sample time to event time
+      Time centerTime = Time(eventTime.getS());
+      centerTime += round(double(eventTime-centerTime)*sampleFrequency)
+	            / sampleFrequency;
+
+      // determine segment start and stop times
+      Time startTime = centerTime - Interval(timeRange / 2.);
+      if (startTime-Time(startTime.getS()) < Interval(0.5)) {
+	 startTime = Time(startTime.getS());
+      } else {
+	 startTime = Time(startTime.getS()+1);
+      }
+      Time stopTime = startTime + timeRange;
+
+      chanCache.request(config_i.channelName, config_i.frameType,
+		   startTime, stopTime, config_i.timeShifts);
+   }
+   
    // initialize section status
    int inSectionFlag = 0;
 
    // begin loop over channel configurations
    for (int channelNumber=0; channelNumber<numberOfChannels; channelNumber++) {
+      const search_chan& config_i = configuration[channelNumber];
       resample.reset();
       dble_vect emptyRange;
 
-      if (debugLevel > 1) configuration[channelNumber].display(cout);
+      if (debugLevel > 1) config_i.display(cout);
 
       /////////////////////////////////////////////////////////////////////////
       //                        add section to html report                   //
@@ -537,27 +604,30 @@ wpipe::wscan(const std::string& eventTimeString, const std::string& configFile,
       /////////////////////////////////////////////////////////////////////////
 
       // extract search configuration for channel
-      str_vect  channelName = configuration[channelNumber].channelName;
+      str_vect  channelName = config_i.channelName;
       string    channelNameString = strrep(channelName[0], ";", ":");
-      str_vect  frameType = configuration[channelNumber].frameType;
-      dble_vect timeShifts = configuration[channelNumber].timeShifts;
-      double    sampleFrequency = configuration[channelNumber].sampleFrequency;
-      double    timeRange = configuration[channelNumber].searchTimeRange;
-      dble_vect frequencyRange=configuration[channelNumber].searchFrequencyRange;
-      dble_vect qRange = configuration[channelNumber].searchQRange;
-      double maximumEnergyLoss = configuration[channelNumber].searchMaximumEnergyLoss;
-      double searchWindowDuration = configuration[channelNumber].searchWindowDuration;
-      bool alwaysPlotFlag = configuration[channelNumber].alwaysPlotFlag;
-
+      str_vect  frameType = config_i.frameType;
+      dble_vect timeShifts = config_i.timeShifts;
+      double    sampleFrequency = config_i.sampleFrequency;
+      double    timeRange = config_i.searchTimeRange;
+      dble_vect frequencyRange=config_i.searchFrequencyRange;
+      dble_vect qRange = config_i.searchQRange;
+      double maximumEnergyLoss = config_i.searchMaximumEnergyLoss;
+      double searchWindowDuration = config_i.searchWindowDuration;
+      bool alwaysPlotFlag = config_i.alwaysPlotFlag;
+      int plotHorizontalResolution = config_i.plotHorizontalResolution;
+      int plotVerticalResolution = config_i.plotVerticalResolution;
+      
+      
       // Plot parameters
       dble_vect plotTimeRanges;
       dble_vect plotFrequencyRange;
       dble_vect plotNormalizedEnergyRange;
       if (generateReport) {
-	 plotTimeRanges = configuration[channelNumber].plotTimeRanges;
-	 plotFrequencyRange = configuration[channelNumber].plotFrequencyRange;
+	 plotTimeRanges = config_i.plotTimeRanges;
+	 plotFrequencyRange = config_i.plotFrequencyRange;
 	 plotNormalizedEnergyRange = 
-	    configuration[channelNumber].plotNormalizedEnergyRange;
+	    config_i.plotNormalizedEnergyRange;
       }
 
       // display status
@@ -583,11 +653,13 @@ wpipe::wscan(const std::string& eventTimeString, const std::string& configFile,
       wlog(debugLevel, 2, "  tiling for search");
       double highPassCutoff = -1;
       double lowPassCutoff = -1;
-      double whiteningDuration = -1;
+      double whiteningDuration = config_i.whiteningDuration;
+      int minAllowableIndeps = 50;
 
       wtile tiling(timeRange, qRange, frequencyRange, sampleFrequency, 
 		   maximumEnergyLoss, highPassCutoff, lowPassCutoff, 
-		   whiteningDuration, transientFactor, debugLevel);
+		   whiteningDuration, transientFactor, minAllowableIndeps,
+		   debugLevel);
 
 
       //  The threshold is set to yield the specified false event rate when 
@@ -596,8 +668,8 @@ wpipe::wscan(const std::string& eventTimeString, const std::string& configFile,
       //  It is also only a rough estimate, and the result false event rate
       //  may vary significantly depending on the quality of the data.
       //
-      double whiteNoiseFalseRate = configuration[channelNumber].whiteNoiseFalseRate;
-      double eventThreshold = configuration[channelNumber].eventThreshold;
+      double whiteNoiseFalseRate = config_i.whiteNoiseFalseRate;
+      double eventThreshold = config_i.eventThreshold;
       if (eventThreshold == 0) {
 	 eventThreshold = tiling.threshold_from_rate(whiteNoiseFalseRate);
       }
@@ -607,12 +679,14 @@ wpipe::wscan(const std::string& eventTimeString, const std::string& configFile,
       // read data from frame file
       wlog(debugLevel, 2, "  reading data");
       tser_vect rawData;
-      wreaddata(frameCache, channelName, frameType, 
-		startTime, stopTime, timeShifts, debugLevel,
-		rawData);
+      //wreaddata(frameCache, channelName, frameType, 
+      //	startTime, stopTime, timeShifts, debugLevel,
+      //	rawData);
+      chanCache.read(channelName, frameType, startTime, stopTime,
+		     timeShifts, rawData);
 
       // check for read error
-      if (rawData.empty()) {
+      if (rawData.empty() || any_ts_empty(rawData)) {
 	 wlog(debugLevel, 1, "  ERROR: cannot load frame data");
 	 continue;
       }
@@ -633,7 +707,19 @@ wpipe::wscan(const std::string& eventTimeString, const std::string& configFile,
       //--------------------------------  Resample data
       wlog(debugLevel, 2, "  resampling data");
       tser_vect rsamp;
-      rsamp = resample.wresample(rawData, sampleFrequency);
+      try {
+	 rsamp = resample.wresample(rawData, sampleFrequency);
+      } catch (exception& e) {
+	 cerr << "  Exception in " << channelName[0] << " resampler: "
+	      << e.what() << endl;
+	 continue;
+      }
+      
+      // check for read error
+      if (rsamp.empty() || any_ts_empty(rsamp)) {
+	 wlog(debugLevel, 1, "  ERROR: cannot resample data");
+	 continue;
+      }
 
       // high pass filter and whiten data
       wlog(debugLevel, 2, "  conditioning data");
@@ -866,8 +952,8 @@ wpipe::wscan(const std::string& eventTimeString, const std::string& configFile,
 	 htmlFID << "most significant tile:" << endl
 		 << " t = " << mostSignificantTimeHtml << " s," << endl
 		 << " f = " << mostSignificantFrequencyHtml << " Hz," << endl
-		 << " Q = " <<mostSignificantQHtml << "," << endl
-		 << " Z = " <<mostSignificantNormalizedEnergyHtml << "," << endl
+		 << " Q = " << mostSignificantQHtml << "," << endl
+		 << " Z = " << mostSignificantNormalizedEnergyHtml << "," << endl
 		 << " X = " << mostSignificantAmplitudeHtml 
 		 << " Hz<sup>-&frac12;</sup>," << endl 
 		 << " SNR = " << mostSignificantSNRHtml << endl
@@ -925,8 +1011,8 @@ wpipe::wscan(const std::string& eventTimeString, const std::string& configFile,
 	 ///////////////////////////////////////////////////////////////////////
 
 	 //  Set figure style parameters
-	 if (!configuration[channelNumber].colorMap.empty()) {
-	    figureHandle.set_palette(configuration[channelNumber].colorMap);
+	 if (!config_i.colorMap.empty()) {
+	    figureHandle.set_palette(config_i.colorMap);
 	 }
 	 
 	 
@@ -979,7 +1065,8 @@ wpipe::wscan(const std::string& eventTimeString, const std::string& configFile,
 	    // print high pass filtered time series to file
 	    wlog(debugLevel, 2, "    printing high passed time series");
 	    figName << eventTimeString << "_" << channelNameString << "_" 
-		    << setprecision(2) << plotTimeRange << "_timeseries_highpassed";
+		    << setprecision(2) << plotTimeRange
+		    << "_timeseries_highpassed";
 	    figBasePath = outputDirectory + "/" + figName.str();
 	    figureHandle.wprintfig(figBasePath);
 	    figName.str("");
@@ -1019,7 +1106,8 @@ wpipe::wscan(const std::string& eventTimeString, const std::string& configFile,
 	    figureHandle.wspectrogram(rawTransform[0], tiling, centerTime, 
 				      tRange, plotFrequencyRange, 
 				      qRange, plotNormalizedEnergyRange, 
-				      plotHorizontalResolution);
+				      plotHorizontalResolution,
+				      plotVerticalResolution);
 
 	    // print autoscaled spectrogram to file
 	    wlog(debugLevel, 2, "    printing raw spectrogram");
@@ -1039,7 +1127,8 @@ wpipe::wscan(const std::string& eventTimeString, const std::string& configFile,
 				      centerTime, tRange, 
 				      plotFrequencyRange, 
 				      qRange, plotNormalizedEnergyRange, 
-				      plotHorizontalResolution);
+				      plotHorizontalResolution,
+				      plotVerticalResolution);
 
 	    // print whitened spectrogram to file
 	    wlog(debugLevel, 2, "    printing whitened spectrogram");
@@ -1059,7 +1148,8 @@ wpipe::wscan(const std::string& eventTimeString, const std::string& configFile,
 				      centerTime, tRange,
 				      plotFrequencyRange, qRange, 
 				      autoNormalizedEnergyRange, 
-				      plotHorizontalResolution);
+				      plotHorizontalResolution,
+				      plotVerticalResolution);
 
 	    // print autoscaled spectrogram to file
 	    wlog(debugLevel, 2, "    printing autoscaled spectrogram");
@@ -1209,7 +1299,7 @@ wpipe::wscan(const std::string& eventTimeString, const std::string& configFile,
    wlog(debugLevel, 1, "closing xml summary");
    fprintf(xmlSummaryFID, "</Stream>\n");
    fprintf(xmlSummaryFID, "</Table>\n");
-    fprintf(xmlSummaryFID, "</LIGO_LW>\n");
+   fprintf(xmlSummaryFID, "</LIGO_LW>\n");
    fclose(xmlSummaryFID);
 
    //-----------------------------------  Exit
@@ -1222,28 +1312,149 @@ wpipe::wscan(const std::string& eventTimeString, const std::string& configFile,
 
 //======================================  Search channel constructor.
 search_chan::search_chan(void) {
-   clear();
+   init_map();
 }
 
-//======================================  Clear search channel descriptor.
+//======================================  Search channel constructor.
+search_chan::search_chan(const search_chan& x) {
+   init_map();
+   copy(x);
+}
+
+//======================================  Initialize the parameter map
 void
-search_chan::clear(void) {
-   channelName.clear();
-   frameType.clear();
-   sampleFrequency = 0;
-   searchTimeRange = 0;
-   searchFrequencyRange.clear();
-   searchQRange.clear();
-   searchMaximumEnergyLoss = 0;
-   whiteNoiseFalseRate = 0;
-   eventThreshold = 0;
-   searchWindowDuration = 0;
-   plotTimeRanges.clear();
-   plotFrequencyRange.clear();
-   plotNormalizedEnergyRange.clear();
-   alwaysPlotFlag = false;
-   colorMap.clear();
-   zUnits.clear();
+search_chan::init_map(void) {
+   add_param("channelName", channelName);
+   add_param("timeShifts", timeShifts);
+   add_param("frameType", frameType);
+   add_param("sampleFrequency", sampleFrequency);
+   add_param("searchTimeRange", searchTimeRange);
+   add_param("searchFrequencyRange", searchFrequencyRange);
+   add_param("searchQRange", searchQRange);
+   add_param("searchMaximumEnergyLoss", searchMaximumEnergyLoss, 0);
+   add_param("whiteNoiseFalseRate", whiteNoiseFalseRate, 0);
+   add_param("eventThreshold", eventThreshold, 0);
+   add_param("searchWindowDuration", searchWindowDuration, 0);
+   add_param("whiteningDuration", whiteningDuration, -1.0);
+   add_param("plotTimeRanges", plotTimeRanges);
+   add_param("plotFrequencyRange", plotFrequencyRange);
+   add_param("plotNormalizedEnergyRange", plotNormalizedEnergyRange);
+   add_param("alwaysPlotFlag", alwaysPlotFlag, false);
+   add_param("plotHorizontalResolution", plotHorizontalResolution, 0);
+   add_param("plotVerticalResolution", plotVerticalResolution, 0);
+   add_param("colorMap", colorMap);
+   add_param("zUnits", zUnits);
+}
+
+//======================================  Validate scan parameters
+void
+search_chan::validate(int channelNumber, const search_chan& def) {
+   // validate channel configuration
+   size_t nChan = channelName.size();
+   if (!nChan) {
+      cerr << "channel name not specified for channel number " 
+	   << channelNumber << endl;
+      error("channel name not specified");
+   }
+   if (frameType.size() < nChan) {
+      cerr << "frame type(s) not specified for channel number " 
+	   << channelNumber << endl;
+      error("frame type(s) not specified");
+   }
+   if (timeShifts.size() < nChan) {
+      timeShifts.resize(nChan, 0.0);
+   }
+   if (sampleFrequency == 0) {
+      cerr << "WSCAN:incompleteConfiguration" 
+	   << "sample frequency not specified for channel number"
+	   << channelNumber << endl;
+      sampleFrequency = def.sampleFrequency;
+   }
+   if (searchTimeRange == 0) {
+      cerr << "WSCAN:incompleteConfiguration"
+	   << "search time range not specified for channel number "
+	   << channelNumber << endl;
+      searchTimeRange = def.searchTimeRange;
+   }
+   if (fmod(searchTimeRange, 1) != 0) {
+      cerr << "WSCAN:invalidConfiguration: " 
+	   << "search time range non integer for channel number "
+	   << channelNumber << endl;
+      error("WSCAN:invalidConfiguration");
+   }
+   if (searchFrequencyRange[1] < 0) {
+      cout << "WSCAN:incompleteConfiguration "
+	   << "search frequency range not specified for channel number "
+	   << channelNumber << endl;
+      searchFrequencyRange[0] = def.searchFrequencyRange[0];
+      searchFrequencyRange[1] = def.searchFrequencyRange[1];
+   }
+   if (searchQRange[1] == 0) {
+      cout << "WSCAN:incompleteConfiguration "
+	   <<	"search Q range not specified for channel number "
+	   << channelNumber << endl;
+      searchQRange[0] = def.searchQRange[0];
+      searchQRange[1] = def.searchQRange[1];
+   }
+   if (searchMaximumEnergyLoss == 0) {
+      cerr << "WSCAN:incompleteConfiguration"
+	   << "search maximum energy loss not specified for channel "
+	   << "number " << channelNumber << endl;
+      searchMaximumEnergyLoss = def.searchMaximumEnergyLoss;
+   }
+   if (!whiteNoiseFalseRate && !eventThreshold) {
+      cerr << "WSCAN:incompleteConfiguration"
+	   << "event threshold / false rate not specified "
+	   << "for channel number " << channelNumber << endl;
+#ifdef OMEGA_MATLAB_BUGS
+      searchMaximumEnergyLoss = def.whiteNoiseFalseRate;
+#else
+      whiteNoiseFalseRate = def.whiteNoiseFalseRate;
+      eventThreshold      = def.eventThreshold;
+#endif
+   }
+   if (searchWindowDuration == 0) {
+      cerr << "WSCAN:incompleteConfiguration"
+	   << "search window duration not specified for channel number "
+	   << channelNumber << endl;
+      searchWindowDuration =  def.searchWindowDuration;
+   }
+   //----------------------------------- set default whitening duration.
+   //   Note that by defaultm, the whitening duration is set in wtile so the
+   //   current default value is -1 which indicates that the value is unset.
+   if (whiteningDuration < 0) {
+      whiteningDuration = def.whiteningDuration;
+   }
+   if (plotTimeRanges.empty()) {
+      cerr << "WSCAN:incompleteConfiguration" 
+	   <<	"plot time ranges not specified for channel number "
+	   << channelNumber << endl;
+      plotTimeRanges = def.plotTimeRanges;
+   }
+   if (plotFrequencyRange.empty()) {
+      //cerr << "WSCAN:incompleteConfiguration "
+      //     << "plot frequency range not specified for channel number "
+      //     << channelNumber << endl;
+      plotFrequencyRange = def.plotFrequencyRange;
+   }
+   if (plotNormalizedEnergyRange.empty()) {
+      cerr << "WSCAN:incompleteConfiguration "
+	   <<"plot normalized energy range not specified for channel number "
+	   << channelNumber << endl;
+      plotNormalizedEnergyRange = def.plotNormalizedEnergyRange;
+   }
+   if (!plotHorizontalResolution)
+      plotHorizontalResolution = def.plotHorizontalResolution;
+   if (!plotVerticalResolution)
+      plotVerticalResolution = def.plotVerticalResolution;
+   if (colorMap.empty()) colorMap = def.colorMap;
+   if (zUnits.empty())   zUnits   = def.zUnits;
+   //if (alwaysPlotFlag == false) {
+   //cerr << "WSCAN:incompleteConfiguration"
+   //     << "always plot flag not specified for channel number "
+   //     << channelNumber << endl;
+   //alwaysPlotFlag = defaultAlwaysPlotFlag;
+   //}
 }
 
 //======================================  Scan the configuration.
@@ -1339,7 +1550,7 @@ wpipe::scan_config(const std::string& file, const search_chan& def,
       if (configurationLine == "{") {
 
 	 // increment channel number
-	 temp_chan.clear();
+	 temp_chan.clear_all();
 	 channelNumber = configuration.size();
 
 	 // continue to next line
@@ -1349,205 +1560,20 @@ wpipe::scan_config(const std::string& file, const search_chan& def,
       // check for end of existing channel configuration
       if (configurationLine == "}") {
 
-	 // validate channel configuration
-	 size_t nChan = temp_chan.channelName.size();
-	 if (!nChan) {
-	    cerr << "channel name not specified for channel number " 
-		 << channelNumber << endl;
-	    error("channel name not specified");
-	 }
-	 if (temp_chan.frameType.size() < nChan) {
-	    cerr << "frame type(s) not specified for channel number " 
-		 << channelNumber << endl;
-	    error("frame type(s) not specified");
-	 }
-	 if (temp_chan.timeShifts.size() < nChan) {
-	    temp_chan.timeShifts.resize(nChan, 0.0);
-	 }
-	 if (temp_chan.sampleFrequency == 0) {
-	    cerr << "WSCAN:incompleteConfiguration" 
-		 << "sample frequency not specified for channel number"
-		 << channelNumber << endl;
-	    temp_chan.sampleFrequency = def.sampleFrequency;
-	 }
-	 if (temp_chan.searchTimeRange == 0) {
-	    cerr << "WSCAN:incompleteConfiguration"
-		 << "search time range not specified for channel number "
-		 << channelNumber << endl;
-	    temp_chan.searchTimeRange = def.searchTimeRange;
-	 }
-	 if (fmod(temp_chan.searchTimeRange, 1) != 0) {
-	    cerr << "WSCAN:invalidConfiguration: " 
-		 << "search time range non integer for channel number "
-		 << channelNumber << endl;
-	    error("WSCAN:invalidConfiguration");
-	 }
-	 if (temp_chan.searchFrequencyRange[1] < 0) {
-	    cout << "WSCAN:incompleteConfiguration "
-		 << "search frequency range not specified for channel number "
-		 << channelNumber << endl;
-	    temp_chan.searchFrequencyRange[0] = def.searchFrequencyRange[0];
-	    temp_chan.searchFrequencyRange[1] = def.searchFrequencyRange[1];
-	 }
-	 if (temp_chan.searchQRange[1] == 0) {
-	    cout << "WSCAN:incompleteConfiguration "
-		 <<	"search Q range not specified for channel number "
-		 << channelNumber << endl;
-	    temp_chan.searchQRange[0] = def.searchQRange[0];
-	    temp_chan.searchQRange[1] = def.searchQRange[1];
-	 }
-	 if (temp_chan.searchMaximumEnergyLoss == 0) {
-	    cerr << "WSCAN:incompleteConfiguration"
-		 << "search maximum energy loss not specified for channel "
-		 << "number " << channelNumber << endl;
-	    temp_chan.searchMaximumEnergyLoss = def.searchMaximumEnergyLoss;
-	 }
-	 if (!temp_chan.whiteNoiseFalseRate && !temp_chan.eventThreshold) {
-	    cerr << "WSCAN:incompleteConfiguration"
-		 << "event threshold / false rate not specified "
-		 << "for channel number " << channelNumber << endl;
-#ifdef OMEGA_MATLAB_BUGS
-	    temp_chan.searchMaximumEnergyLoss = def.whiteNoiseFalseRate;
-#else
-	    temp_chan.whiteNoiseFalseRate = def.whiteNoiseFalseRate;
-	    temp_chan.eventThreshold      = def.eventThreshold;
-#endif
-	 }
-	 if (temp_chan.searchWindowDuration == 0) {
-	    cerr << "WSCAN:incompleteConfiguration"
-		 << "search window duration not specified for channel number "
-		 << channelNumber << endl;
-	    temp_chan.searchWindowDuration =  def.searchWindowDuration;
-	 }
-	 if (temp_chan.plotTimeRanges.empty()) {
-	    cerr << "WSCAN:incompleteConfiguration" 
-		 <<	"plot time ranges not specified for channel number "
-		 << channelNumber << endl;
-	    temp_chan.plotTimeRanges = def.plotTimeRanges;
-	 }
-	 if (temp_chan.plotFrequencyRange.empty()) {
-	    //cerr << "WSCAN:incompleteConfiguration "
-	    //     << "plot frequency range not specified for channel number "
-	    //     << channelNumber << endl;
-	    temp_chan.plotFrequencyRange = def.plotFrequencyRange;
-	 }
-	 if (temp_chan.plotNormalizedEnergyRange.empty()) {
-	    cerr << "WSCAN:incompleteConfiguration "
-		 <<"plot normalized energy range not specified for channel number "
-		 << channelNumber << endl;
-	    temp_chan.plotNormalizedEnergyRange = def.plotNormalizedEnergyRange;
-	 }
-	 //if (temp_chan.alwaysPlotFlag == false) {
-	 //cerr << "WSCAN:incompleteConfiguration"
-	 //     << "always plot flag not specified for channel number "
-	 //     << channelNumber << endl;
-	 //temp_chan.alwaysPlotFlag = defaultAlwaysPlotFlag;
-	 //}
-
+	 temp_chan.validate(channelNumber, def);
 	 configuration.push_back(temp_chan);
 	 channelNumber = configuration.size();
+	 temp_chan.clear_all();
 	 // continue to next line
 	 continue;
       }
-
-      // locate field separator
-      string::size_type colonIndex = configurationLine.find(":");
-
-      // if (field separator not located, report syntax error
-      if (colonIndex == string::npos) {
-	 cerr << "syntax error processing configuration file "
-	      << file << ":" << endl << configurationLine << endl;
-	 error("syntax error processing configuration file");
-      }
     
-      // parse configuration line
-      string parameterName = configurationLine.substr(0, colonIndex);
-      string parameterValue = configurationLine.substr(colonIndex + 1);
-      parameterName = deblank(parameterName);
-      parameterValue = deblank(parameterValue);
-      const char* parValue = parameterValue.c_str();
-
       // assign parameters based on name
-      if (parameterName == "channelName") {
-	 temp_chan.channelName = eval_str(parameterValue);
-      } else if (parameterName == "frameType") {
-	 temp_chan.frameType = eval_str(parameterValue);
-      } else if (parameterName == "timeShifts") {
-	 temp_chan.timeShifts = eval(parameterValue);
-      } else if (parameterName ==  "sampleFrequency") {
-	 temp_chan.sampleFrequency = strtod(parValue, 0);
-      } else if (parameterName ==  "searchTimeRange") {
-	 temp_chan.searchTimeRange = strtod(parValue, 0);
-      } else if (parameterName ==  "searchFrequencyRange") {
-	 temp_chan.searchFrequencyRange = eval(parameterValue);
-      } else if (parameterName ==  "searchQRange") {
-	 temp_chan.searchQRange = eval(parameterValue);
-      } else if (parameterName ==  "searchMaximumEnergyLoss") {
-	 temp_chan.searchMaximumEnergyLoss = strtod(parValue, 0);
-      } else if (parameterName ==  "whiteNoiseFalseRate") {
-	 temp_chan.whiteNoiseFalseRate = strtod(parValue, 0);
-      } else if (parameterName ==  "eventThreshold") {
-	 temp_chan.eventThreshold = strtod(parValue, 0);
-      } else if (parameterName ==  "searchWindowDuration") {
-	 temp_chan.searchWindowDuration = strtod(parValue, 0);
-      } else if (parameterName ==  "plotTimeRanges") {
-	 temp_chan.plotTimeRanges = eval(parameterValue);
-      } else if (parameterName ==  "plotFrequencyRange") {
-	 temp_chan.plotFrequencyRange = eval(parameterValue);
-      } else if (parameterName ==  "plotNormalizedEnergyRange") {
-	 temp_chan.plotNormalizedEnergyRange = eval(parameterValue);
-      } else if (parameterName ==  "alwaysPlotFlag") {
-	 if (parameterValue == "true") {
-	    temp_chan.alwaysPlotFlag = true;
-	 } else if (parameterValue == "false") {
-	    temp_chan.alwaysPlotFlag = false;
-	 } else {
-	    temp_chan.alwaysPlotFlag = strtol(parValue,0,0)!=0;
-	 }
-      }
-      else if (parameterName ==  "colorMap") {
-	 temp_chan.colorMap=parameterValue;
-      }
-      else if (parameterName ==  "zUnits") {
-	 temp_chan.zUnits=parameterValue;
-      }
-      else {
-	 cerr << "unknown configuration parameter " << parameterName << endl;
-	 error("unknown configuration parameter");
-      }
-
+      temp_chan.assign_param(configurationLine, ":");
+      
       // end loop over channel configuration file
    }
 
    // close configuration file
    configurationFID.close();
 }
-
-//======================================  Diaplay channel parameters.
-void
-search_chan::display(std::ostream& out) const {
-   out << "channelName:               ";
-   wpipe::display(channelName, out) << endl;
-   out << "frameType:                 ";
-   wpipe::display(frameType, out) << endl;
-   out << "timeShifts:                ";
-   wpipe::display(timeShifts, out) << endl;
-   out << "sampleFrequency:           " << sampleFrequency << endl;
-   out << "searchTimeRange:           " << searchTimeRange << endl;
-   out << "searchFrequencyRange:      "; 
-   wpipe::display(searchFrequencyRange, out) << endl;
-   out << "searchQRange:              ";
-   wpipe::display(searchQRange, out) << endl;
-   out << "searchMaximumEnergyLoss:   " << searchMaximumEnergyLoss << endl;
-   out << "whiteNoiseFalseRate:       " << whiteNoiseFalseRate << endl;
-   out << "searchWindowDuration:      " << searchWindowDuration << endl;
-   out << "plotTimeRange:             ";
-   wpipe::display(plotTimeRanges, out) << endl;
-   out << "plotFrequencyRange:        ";
-   wpipe::display(plotFrequencyRange, out) << endl;
-   out << "plotNormalizedEnergyRange: ";
-   wpipe::display(plotNormalizedEnergyRange, out) << endl;
-   out << "alwaysPlotFlag:            " << boolstr_tf(alwaysPlotFlag) << endl;
-   out << "colorMap:                  " << colorMap << endl;
-   out << "zUnits:                    " << zUnits << endl;
-}
