@@ -203,8 +203,31 @@ wsearch(const Time& start, const Time& stop,
    // report status
    wlog(debugLevel, 1, "reading parameter file");
 
+   // get parameter defaults
+   wparameters defpars;
+   defpars.set_defaults();
+   string rcfile = subst_env("$HOME/.wstreamrc");
+   if (exist(rcfile, "file")) {
+      ifstream inrc(rcfile.c_str());
+      if (inrc.is_open()) {
+	 wlog(debugLevel, 1, string("Read default parameters from: ") + rcfile);
+	 defpars.read_params(inrc, debugLevel);
+	 if (debugLevel > 3) defpars.display(cout);
+      }
+   }
+   
+   rcfile = subst_env(".wstreamrc");
+   if (exist(rcfile, "file")) {
+      ifstream inrc(rcfile.c_str());
+      if (inrc.is_open()) {
+	 wlog(debugLevel, 1, string("Read default parameters from: ") + rcfile);
+	 defpars.read_params(inrc, debugLevel);
+	 if (debugLevel > 3) defpars.display(cout);
+      }
+   }
+
    // read parameters
-   wparameters pars(parameterFile, debugLevel);
+   wparameters pars(parameterFile, defpars, debugLevel);
    pars.display(cout);
 
    /////////////////////////////////////////////////////////////////////////////
@@ -219,7 +242,8 @@ wsearch(const Time& start, const Time& stop,
    wtile tiling(pars.blockDuration, pars.qRange, pars.frequencyRange, 
 		pars.sampleFrequency, pars.maximumMismatch, 
 		pars.highPassCutoff, pars.lowPassCutoff, 
-		pars.whiteningDuration, pars.transientFactor, debugLevel);
+		pars.whiteningDuration, pars.transientFactor, 
+		pars.minAllowableIndependents, debugLevel);
 
    if (debugLevel >=2) {
       cout << "  whiteningDuration:   " << tiling.whiteningDuration() << endl;
@@ -272,7 +296,11 @@ wsearch(const Time& start, const Time& stop,
 				       / (pars.blockDuration 
 					  - minimumBlockOverlap)));
 
-   // block overlap in seconds between blocks if more than one block
+   // block overlap in seconds between blocks if more than one block.
+   // Overlap is calculated so that the blocks are uniformly spaced so
+   // that the start of the first block corresponds to the start of the
+   // segment and the end of the last block corresponds to the end of the
+   // segment.
    double blockOverlap = 0;
    if (numberOfBlocks > 1) {
       blockOverlap = (pars.blockDuration * numberOfBlocks
