@@ -17,7 +17,7 @@
 using namespace wpipe;
 using namespace std;
 // Shourov K. Chatterji <shourov@ligo.mit.edu>
-// $Id: wspectrogram.m 2753 2010-02-26 21:33:24Z jrollins $
+// $Id:  $
 
 //======================================  Plot a spectrogram.
 void 
@@ -25,7 +25,7 @@ wfigure::spectro_plot(const qTransform& transform, const wtile& tiling,
 		      const Time& referenceTime, const dble_vect& timeRange, 
 		      const dble_vect& requestedFrequencyRange, size_t iQmin,
 		      size_t iQmax, const dble_vect& normalizedEnergyRange, 
-		      long horizontalResolution)
+		      long horizontalResolution, long verticalResolution)
 {
 
    // spectrogram boundary
@@ -177,14 +177,51 @@ wfigure::spectro_plot(const qTransform& transform, const wtile& tiling,
 	    maximumNormalizedEnergy = tmp;
 	 }	
       }
-    
+
+      //------------------------------- rebin vertical
+      size_t nVert = row;
+      if (row < verticalResolution) {
+	 nVert = verticalResolution;
+	 
+	 //---------------------------- Starting f bin positions
+	 lcl_array<double> fbin0(row);
+	 for (size_t ix=0; ix<row; ix++) fbin0[ix]=(ix + 0.5) / double(row);
+
+	 //---------------------------- rebinned f positions
+	 lcl_array<double> frebin0(nVert);
+	 for (size_t ix=0; ix<nVert; ix++) frebin0[ix]=(ix + 0.5)/double(nVert);
+
+	 //----------------------------  
+	 lcl_array<double> rawybin(row);
+	 lcl_array<double> rawybinp(row);
+	 lcl_array<double> arrayYX(nVert*horizontalResolution);
+	 for (size_t ix=0; ix<horizontalResolution; ix++) {
+	    for (size_t iy=0; iy<row; iy++) {
+	       rawybin[iy] = normalizedEnergies[ix+horizontalResolution*iy];
+	    }
+	    spline_pchip_set(row, fbin0, rawybin, rawybinp);
+	    spline_pchip_val(row, fbin0, rawybin, rawybinp, 
+			     nVert, frebin0, arrayYX + ix*nVert);
+	 }
+	 //----------------------------  Transpose and move to nomalizedEnergies
+	 lcl_array<double> transpose(nVert*horizontalResolution);
+	 for (size_t ix=0; ix<horizontalResolution; ix++) {
+	    for (size_t iy=0; iy<nVert; iy++) {
+	       transpose[ix + horizontalResolution*iy] = arrayYX[iy + nVert*ix];
+	    }
+	 }
+	 normalizedEnergies.swap(transpose);
+      }
+      
       //------------------------------- Set up frequency binning
-      lcl_array<double> fBins(row+1);
-      double hwid = sqrt(frequencies[1]/frequencies[0]);
-      for (size_t i=0; i<row; i++) {
-	 fBins[i] = frequencies[iFmin + i]/hwid;
+      lcl_array<double> fBins(nVert+1);
+      double bwid = exp(log(frequencies[iFmax-1]/frequencies[iFmin])
+			/(iFmax - iFmin -1));
+      fBins[0] = frequencies[iFmin] / sqrt(bwid);
+      double fwid = exp(log(bwid)*(iFmax - iFmin)/double(nVert));
+      for (size_t i=1; i<=nVert; i++) {
+	 fBins[i] = fBins[i-1] * fwid;
       }
-      fBins[row] = frequencies[iFmax - 1]*hwid;
 
       //////////////////////////////////////////////////////////////////////////
       //                           set colormap scaling                       //
@@ -233,7 +270,7 @@ wfigure::spectro_plot(const qTransform& transform, const wtile& tiling,
       } else {
 	 _plot.zlabel(_zUnits);
       }
-      _plot.surf(horizontalResolution, times, row, fBins, normalizedEnergies);
+      _plot.surf(horizontalResolution, times, nVert, fBins, normalizedEnergies);
 
    }      // end loop over planes
 }
@@ -244,7 +281,7 @@ wfigure::spectro_data(const qTransform& transform, const wtile& tiling,
 		      const Time& referenceTime, const dble_vect& timeRange, 
 		      const dble_vect& requestedFrequencyRange, size_t iQmin,
 		      size_t iQmax, const dble_vect& normalizedEnergyRange, 
-		      long horizontalResolution)
+		      long horizontalResolution, long verticalResolution)
 {
    double dInf = 1.0 / 0.0;
    // set title properties
@@ -355,7 +392,7 @@ wfigure::wspectrogram(const qTransform& transform, const wtile& tiling,
 		      const Time& referenceTime, const dble_vect& tRange, 
 		      const dble_vect& fRange, const dble_vect& Qrnge, 
 		      const dble_vect& normalizedEnergyRange, 
-		      long horizontalResolution)
+		      long horizontalResolution, long verticalResolution)
 {
 
    /////////////////////////////////////////////////////////////////////////////
@@ -459,11 +496,13 @@ wfigure::wspectrogram(const qTransform& transform, const wtile& tiling,
       cout << "Plotting data" << endl;
       spectro_plot(transform, tiling, referenceTime, timeRange, 
 		   requestedFrequencyRange, iQmin, iQmax,
-		   normalizedEnergyRange, horizontalResolution);
+		   normalizedEnergyRange, horizontalResolution,
+		   verticalResolution);
    } else {
       cout << "Spewing data" << endl;
       spectro_data(transform, tiling, referenceTime, timeRange, 
 		   requestedFrequencyRange, iQmin, iQmax,
-		   normalizedEnergyRange, horizontalResolution);
+		   normalizedEnergyRange, horizontalResolution,
+		   verticalResolution);
    }
 }
