@@ -49,7 +49,6 @@
 
 #include "EggTimer.hh"
 #include "MultiDacc.hh"
-#include "SigFlag.hh"
 
 #include <iostream>
 #include <iomanip>
@@ -111,8 +110,6 @@ main(int argc, const char* argv[]) {
 void
 wstream(const std::string& params, const std::string& cache,
 	const std::string& outdir, int debugLevel) {
-   SigFlag term(SIGTERM);
-   term.add(SIGINT);
 
    /////////////////////////////////////////////////////////////////////////////
    //                           start analysis timer                          //
@@ -170,21 +167,43 @@ wstream(const std::string& params, const std::string& cache,
    /////////////////////////////////////////////////////////////////////////////
    //              Loop over channel blocks... read parameters                //
    /////////////////////////////////////////////////////////////////////////////
-   int chan_loop = 0;
+
+   //-----------------------------------  Look for defaults in .wstreamrc files
+   double blockDuration = 0;
+   double blockOverlap  = 0;
+   wparameters defpars;
+   defpars.set_defaults();
+   string rcfile = subst_env("$HOME/.wstreamrc");
+   if (exist(rcfile, "file")) {
+      ifstream inrc(rcfile.c_str());
+      if (inrc.is_open()) {
+	 wlog(debugLevel, 1, string("Read default parameters from: ") + rcfile);
+	 defpars.read_params(inrc, debugLevel);
+	 if (debugLevel > 3) defpars.display(cout);
+      }
+   }
+   
+   rcfile = subst_env(".wstreamrc");
+   if (exist(rcfile, "file")) {
+      ifstream inrc(rcfile.c_str());
+      if (inrc.is_open()) {
+	 wlog(debugLevel, 1, string("Read default parameters from: ") + rcfile);
+	 defpars.read_params(inrc, debugLevel);
+	 if (debugLevel > 3) defpars.display(cout);
+      }
+   }
+
+   //-----------------------------------  Read in parameter file
    ifstream parFile(parameterFile.c_str());
    if (!parFile.is_open()) {
       error("error opening parameter file");
    }
    wlog(debugLevel, 1, string("reading parameter file: ") + parameterFile);
 
-   double blockDuration = 0;
-   double blockOverlap  = 0;
-   wparameters defpars;
-   defpars.set_defaults();
-
    //----------------------------------- Loop over channel groups
    strchan_vect chanvect;
    size_t totalChans = 0;
+   int chan_loop = 0;
    while (!chan_loop) {
 
       //--------------------------------  Read parameters for one channel group
@@ -194,7 +213,10 @@ wstream(const std::string& params, const std::string& cache,
 
       //--------------------------------  Save default structure.
       if (pars.groupName == "default") {
-	 defpars = pars;
+	 wparameters temp;
+	 temp.copy(defpars);
+	 defpars.copy(pars);
+	 defpars.merge_defaults(temp);
 	 cout << "================  Default parameters  ==============" << endl;
 	 defpars.display(cout);
 	 cout << "====================================================" << endl;
@@ -330,7 +352,7 @@ wstream(const std::string& params, const std::string& cache,
    dble_vect coordinate;
    // begin loop over blocks
    wchunk block;
-   while (!term) {
+   while (!block.term()) {
  
       // start time of block analysis
       EggTimer blockTimer;
