@@ -28,7 +28,8 @@ wstream_chan::wstream_chan(const wparameters& par, int dbugLvl)
    tiling.init(pars.blockDuration, pars.qRange, pars.frequencyRange, 
 	       fSample, pars.maximumMismatch, 
 	       pars.highPassCutoff, pars.lowPassCutoff, 
-	       pars.whiteningDuration, pars.transientFactor, debugLevel);
+	       pars.whiteningDuration, pars.transientFactor, 
+	       pars.minAllowableIndependents, debugLevel);
 
    if (debugLevel >=2) {
       cout << "  whiteningDuration:   " << tiling.whiteningDuration() << endl;
