@@ -34,10 +34,10 @@ wtile::wtile(double timeRange, const dble_vect& qRange,
 	     const dble_vect& frequencyRange, double sampleFrequency, 
 	     double maximumMismatch, double highPassCutoff, 
 	     double lowPassCutoff, double whiteningDuration, 
-	     double transientFactor, int debug) {
+	     double transientFactor, int minAllowableIndependents, int debug) {
    init(timeRange, qRange, frequencyRange, sampleFrequency, maximumMismatch, 
 	highPassCutoff, lowPassCutoff, whiteningDuration, transientFactor,
-	debug);
+	minAllowableIndependents, debug);
 }
 
 //======================================  Initialize w-transform tiling 
@@ -46,7 +46,8 @@ wtile::init(double timeRange, const dble_vect& qRange,
 	    const dble_vect& frequencyRange, double sampleFrequency, 
 	    double maximumMismatch, double highPassCutoff, 
 	    double lowPassCutoff, double whiteningDuration, 
-	    double transientFactor, int debug) {
+	    double transientFactor, int minAllowableIndependents, 
+	    int debug) {
    
    // apply default arguments
    _debugLevel = debug;
@@ -92,7 +93,7 @@ wtile::init(double timeRange, const dble_vect& qRange,
    double minimumAllowableQ = minimumAllowableQPrime * qPrimeToQ;
 
    // reasonable number of statistically independent tiles in a frequency row
-   double minimumAllowableIndependents = 50;
+   double minimumAllowableIndependents = minAllowableIndependents;
 
    // maximum allowable mismatch parameter for reasonable performance
    double maximumAllowableMismatch = 0.5;
@@ -279,6 +280,8 @@ wtile::init(double timeRange, const dble_vect& qRange,
 
    // test for insufficient data
    if ((2 * _transientDuration) >= _duration) {
+      cout << "transientDuration: " << 2*_transientDuration
+	   << " data duration: " << _duration << endl;
       error("duration of filter transients equals or exceeds data duration");
    }
 
@@ -314,6 +317,7 @@ wtile::defaultWhiteningDuration(void) const {
    for (const_qplane_iter p=_planes.begin(); p != _planes.end(); p++) {
       dMax = max(dMax, p->defaultWhiteningDt() );
    }
+   dMax = pow(2.0, int(log2(dMax) + 0.5));
    return dMax;
 }
 
