@@ -261,11 +261,11 @@ PulsarMon::PulsarMon(int argc, const char *argv[])
 	FILE* tmp;
         if (mOutput.error_log) {
 	    tmp = freopen(mOutput.error_file_name.c_str(), "w", stderr);
-	    if (tmp < 0) perror("Unable to divert stderr");
+	    if (tmp == NULL) perror("Unable to divert stderr");
 	}
         if (mOutput.write_log) {
 	    tmp = freopen(mOutput.log_file_name.c_str(), "w", stdout);	
-	    if (tmp < 0) perror("Unable to divert stdout");
+	    if (tmp == NULL) perror("Unable to divert stdout");
 	}
 
         //---------- Set up array that will hold data for DMTViewer history 
