@@ -6,7 +6,7 @@
 //
 //   Added DQ flags in March 2009 - Keith Riles (kriles@umich.edu)
 //
-//   $Id: SenseMonitor.cc 7637 2016-06-10 14:57:45Z john.zweizig@LIGO.ORG $
+//   $Id: SenseMonitor.cc 7831 2017-01-28 21:57:54Z john.zweizig@LIGO.ORG $
 //
 ///////////////////////////////////////////////////////////////////////////
 
@@ -20,6 +20,7 @@
 
 //----- Include this first
 #include "SenseMonitor.hh"
+#include "FIRdesign.hh"
 
 //----- Include standard headers
 #include <stdlib.h>
@@ -46,11 +47,8 @@
 #include "TrigRslt.hh"
 #include "ReadTrend.hh"
 
-//----- Windows
-#include "Hamming.hh"
-#include "Hanning.hh"
-#include "Blackman.hh"
-#include "FlatTop.hh"
+//----- Windows (window_factory function)
+#include "window_api.hh"
 
 //----- Include monitor-specific headers
 #include "Integrand.hh"
@@ -59,7 +57,7 @@
 
 //-->  The next three lines are needed if you are going to generate triggers.
 //     The descriptive title in PIDTITLE should the monitor function.
-#define PIDCVSHDR "$Header: https://redoubt.ligo-wa.caltech.edu/svn/gds/trunk/Monitors/SenseMonitor/SenseMonitor.cc 7637 2016-06-10 14:57:45Z john.zweizig@LIGO.ORG $"
+#define PIDCVSHDR "$Header: https://redoubt.ligo-wa.caltech.edu/svn/gds/trunk/Monitors/SenseMonitor/SenseMonitor.cc 7831 2017-01-28 21:57:54Z john.zweizig@LIGO.ORG $"
 #define PIDTITLE  "Inspiral range monitor"
 #include "ProcIdent.hh"
 
@@ -115,6 +113,8 @@ const char *USAGE_INFO =
 "                SV_IFO_UP.  This condition must be defined in the file \n"
 "                specified by -OSCfile.\n"
 "                \n"
+"-overlap <frac> Specify the overlap fraction for the data sub-strides [0.0]\n"
+"                \n"
 "-procname <name>  Set the online process (service) name\n"
 "                \n" 
 "-prefix <name>  Set the monitor prefix (SNSM) (currently used for dmtviewer\n"
@@ -126,6 +126,8 @@ const char *USAGE_INFO =
 "                to the default files <IFO>_SenseMonitor_Log.txt and \n"
 "                <IFO>_SenseMonitor_Errors.txt.\n"
 "                \n"
+"-seg_length #   Length in seconds of each (overlapping) DFT segment\n"
+"                \n"
 "-stride #       Specify length in seconds of data to use for each range \n"
 "                estimate.  Default 60.\n"
 "                \n"
@@ -163,7 +165,7 @@ const char* const kHtmlLIGOLink = "http://www.ligo.caltech.edu";
 //======================================  SenseMonitor constructor.
 SenseMonitor::SenseMonitor(int argc, const char *argv[]) 
 : DatEnv(argc, argv), fatal_error(false), prev_endtime(0.0), 
-  running_average(0.0), running_count(0.0), MaxStride(99999), Debug(0), 
+  running_average(0.0), running_count(0.0), MaxStride(99999999), Debug(0), 
   missing_strides(0), NStride(0), NDQflag(0), time_since_update(0), 
   history_alpha(0), history_alphabeta(0), history_ampl(0), history_range(0)
 {
@@ -207,8 +209,11 @@ SenseMonitor::SenseMonitor(int argc, const char *argv[])
     Run_Par.l_freq = 20.0;
     Run_Par.h_freq = 1400.0;
     Run_Par.num_ints = 15;
+    Run_Par.overlap = 0.0;
+    Run_Par.seg_length = 0.0;
     Run_Par.monitor_prefix = "SNSM";
     Run_Par.write_segs = true;
+    Run_Par.window_name = "hanning";
     R_Dat.alpha = 0.0;
     R_Dat.beta = 0.0;
     R_Dat.ampl = 0.0;
@@ -266,9 +271,10 @@ SenseMonitor::SenseMonitor(int argc, const char *argv[])
         //         $DMTHTMLOUT.  Note that the 
 	//         plain-text log file is named in ProcessData() method.
 
-      if (Debug >= 2) { 
-	cout << "Inside finish block with mOutput.local =" << mOutput.local << endl;
-      }
+	if (Debug >= 2) { 
+	    cout << "Inside finish block with mOutput.local =" << mOutput.local
+		 << endl;
+	}
 
         if (!mOutput.local) {
 	    mOutput.html_dir = getenv("DMTHTMLOUT");
@@ -354,29 +360,15 @@ SenseMonitor::SenseMonitor(int argc, const char *argv[])
 	}
 
         //-------- Set window type and intialize PSD object.
-        if (Run_Par.window_name == "hamming") {
-            Hamming ham;
-            psd = new PSD(&ham, Run_Par.num_ints);
-        } else if (Run_Par.window_name == "hanning") {
-            Hanning han;
-            psd = new PSD(&han, Run_Par.num_ints);
-        } else if (Run_Par.window_name == "flattop") {
-            FlatTop flat;
-            psd = new PSD(&flat, Run_Par.num_ints);
-        } else if (Run_Par.window_name == "blackman") {
-            Blackman black;
-            psd = new PSD(&black, Run_Par.num_ints);
-        } else if (Run_Par.window_name == "square") {
-            psd = new PSD("square", Run_Par.num_ints);
-        } else {
-            Run_Par.window_name = "hanning";
-            Hanning han;
-            psd = new PSD(&han, Run_Par.num_ints);
-        }
+	unique_ptr<window_api> win(window_factory(Run_Par.window_name, 32768));
+	psd = new PSD(win.get(), Run_Par.num_ints);
+	psd->set_overlap(Run_Par.overlap);
 
         //---------- Set the time stride.
         getDacc().setStride(Interval(Run_Par.T));
+	getDacc().setIgnoreMissingChannel(true);
 	setStrideAlignment(60, 0.0);
+	
 
 	if (Debug >= 1) { 
 	  cout << "Time stride is set..." << endl;
@@ -392,15 +384,14 @@ SenseMonitor::SenseMonitor(int argc, const char *argv[])
         //           is requested) because FDEasyCalibrate adds new channels to
         //           the Dacc. 
         //           KLUDGE: Hard-wire requested frequencies to [0,4096]Hz.
-        mCalibrate = new FDEasyCalibrate(
-                            &getDacc(),
-                            Run_Par.xml_file_name.c_str(),
-                            Run_Par.genCalParam,
-                            0.0,
-                            Run_Par.num_ints/Run_Par.T,
-			    // Dubious code: What is supposed to be inted?
-                            int(4096.0-0.0)*Run_Par.T/Run_Par.num_ints + 1 
-                     );
+	double Fny = 4096;
+        mCalibrate = new FDEasyCalibrate(&getDacc(),
+					 Run_Par.xml_file_name.c_str(),
+					 Run_Par.genCalParam,
+					 0.0,
+					 1.0 / Run_Par.seg_length,
+					 int(Fny * Run_Par.seg_length) + 1 
+					 );
 
         //----- Check that calibration file applies to channel we are analysing.
         if ( Run_Par.mChannel != mCalibrate->getChannel() ) {
@@ -586,13 +577,23 @@ SenseMonitor::ProcessData(void) {
 	    mOutput.cumlog_file_name += ".log";
         }
 
-        //---------- Get AS_Q data to TSeries.
+        //---------- Get DARM data to TSeries.
         TSeries raw_asq = *getDacc().refData(Run_Par.mChannel);
 	if (!mDecimate.isDataValid(raw_asq)) {
 	    cerr << "SensMonitor: decimation filter reset after gap" << endl;
 	    mDecimate.reset();
+	    mHighPass.reset();
 	}
 	ts_asq = mDecimate(raw_asq);
+	if (Run_Par.l_freq > 0) {
+           if (!NStride) {
+	      double rate = 1.0/double(ts_asq.getTStep());
+              mHighPass = dFirW(0, rate, "Kaiser", "HighPass", 
+				Run_Par.l_freq/2, 0, 100.0, 
+				Run_Par.l_freq/5.0);
+	   }
+	   ts_asq = mHighPass(ts_asq);
+	}
 
         //--------- Read waveform file that contains the integrand
         FSpectrum waveform;
@@ -638,7 +639,10 @@ SenseMonitor::ProcessData(void) {
 	    ReadTrend::tseries_vect rt_data(4);
 	    string rt_prefix = Run_Par.IFO.substr(0,1) + "-"
 		             + Run_Par.MonitorName;
-	    ReadTrend rt(getenv("DMTRENDOUT"), rt_prefix.c_str());
+	    ReadTrend rt;
+	    // rt.setDebug();
+            rt.setType(ReadTrend::kMinute);
+	    rt.setMonitor(Run_Par.MonitorName.c_str());
 	    Interval dT = Run_Par.T * tserieslength;
 	    rt.getSeries(rt_name, rt_type, history_start, dT, rt_data);
 	    rt_data[0].getData(tserieslength, calvalues);
@@ -1603,7 +1607,9 @@ SenseMonitor::Configure(int argc, const char *argv[])
  	    } else if (argi == "-stride") {
 	        Run_Par.T = strtod(argv[++i], 0);
 	    } else if (argi == "-n") {
-	        Run_Par.num_ints = (int)strtod(argv[++i], 0);
+	        Run_Par.num_ints = strtol(argv[++i], 0, 0);
+	    } else if (argi == "-seg_length") {
+	        Run_Par.seg_length = strtod(argv[++i], 0);
 	    } else if (argi == "-fmin") {
 	        Run_Par.l_freq = strtod(argv[++i], 0);
 	    } else if (argi == "-fmax") {
@@ -1616,9 +1622,14 @@ SenseMonitor::Configure(int argc, const char *argv[])
                 Run_Par.osc_cond = Run_Par.IFO + ":" + argv[++i];
  	    } else if (argi == "-OSCfile") { 
                 Run_Par.osc_file_name = argv[++i];
- 	    } else if (argi == "-procname") { 
+ 	    }
+	    else if (argi == "-overlap") { 
+                Run_Par.overlap = strtod(argv[++i], 0);
+ 	    }
+	    else if (argi == "-procname") { 
                 Run_Par.MonitorName = argv[++i];
- 	    } else if (argi == "-prefix") { 
+ 	    }
+	    else if (argi == "-prefix") { 
                 Run_Par.monitor_prefix = argv[++i];
  	    } else if (argi == "-channel") { 
                 Run_Par.mChannel = argv[++i];
@@ -1630,13 +1641,11 @@ SenseMonitor::Configure(int argc, const char *argv[])
                 mOutput.screen_output = true;
      	        mOutput.write_log = false;
  	        mOutput.error_log = false;
-	    } else if(argi == "-trend") {
+	    }	    
+	    else if(argi == "-trend") {
 	        mOutput.trend = true;
   	    } else if(argi == "-window") {
                 Run_Par.window_name = argv[++i];
-  	        for(unsigned int j=0; j < (Run_Par.window_name).length(); j++) {
-                    Run_Par.window_name[j] = tolower(Run_Par.window_name[j]);
-	        }
   	    } else if(argi == "-writesegs") {
 		if (strtol(argv[++i], 0, 0) == 0) Run_Par.write_segs = false;
 		else                              Run_Par.write_segs = true;
@@ -1667,13 +1676,36 @@ SenseMonitor::Configure(int argc, const char *argv[])
 void
 SenseMonitor::VerifyParameters(Parameter& Run_Par, bool& fatal_error)
 {
-    if ( ((int)(Run_Par.T) % Run_Par.num_ints) != 0 ) {
-	cout << "SenseMonitor ERROR: The number of averages 'n' must divide the length 'stride'.\n"; 
-	cout << "                    Exiting.\n";
-	cout << USAGE_INFO << endl;
-	fatal_error = true;
-	finish();
-    } 
+    //----------------------------------  Calculate seg-length, n
+    if (Run_Par.seg_length == 0.0 && Run_Par.num_ints == 0) {
+	Run_Par.seg_length = 4.0;
+    }
+    if (Run_Par.seg_length == 0.0) {
+	double nEff =  1.0 + (Run_Par.num_ints - 1) * (1 - Run_Par.overlap);
+	Run_Par.seg_length = Run_Par.T / nEff;
+	if (fmod(Run_Par.seg_length, 1.0) != 0.0) {
+	    cout << "SenseMonitor ERROR: Segment length (" << Run_Par.seg_length
+		 << ") is not an integer number of seconds." << endl; 
+	    cout << "                    Exiting.\n";
+	    cout << USAGE_INFO << endl;
+	    fatal_error = true;
+	    finish();
+	    return;
+	}
+    }
+    if (Run_Par.num_ints == 0) {
+	double nEff = 1.0 + (Run_Par.T/Run_Par.seg_length - 1.0)
+	            / (1.0 - Run_Par.overlap);
+	if (fmod(nEff,1.0) != 0 ) {
+	    cout << "SenseMonitor ERROR: The inferred number of averages ("
+		 << nEff << ") is not an integer." << endl; 
+	    cout << "                    Exiting.\n";
+	    cout << USAGE_INFO << endl;
+	    fatal_error = true;
+	    finish();
+	}
+	Run_Par.num_ints = nEff;
+    }
     if ( Run_Par.l_freq >= Run_Par.h_freq ) {
         cout << "SenseMonitor ERROR: Low frequency must be less than high ";
 	cout << "frequency.  Exiting.\n";
@@ -1681,119 +1713,44 @@ SenseMonitor::VerifyParameters(Parameter& Run_Par, bool& fatal_error)
         fatal_error = true;
         finish();
     }
-/*
-    if (((int)(86400.0 / Run_Par.T) != (86400.0 / Run_Par.T)) && mOutput.trend) {
-	cout << "SenseMonitor ERROR: 'stride' must divide 86400 (number of seconds in 1 day).\n";
-	cout << "                    Exiting.\n";
-	cout << USAGE_INFO << endl;
-	fatal_error = true;
-	finish();
-    }
-*/
+
     if (Run_Par.window_name == "square") {
-	cout << "SenseMonitor WARNING: Square window (ie, no windowing) selected for\n"; 
-	cout << "                      power-spectrum estimation.  This is a VERY BAD\n";
-	cout << "                      IDEA; you should select anything else.\n";
+	cout << "SenseMonitor: WARNING Square window (i.e. no windowing) "
+	     << "selected for" << endl; 
+	cout << "              power-spectrum estimation. This is a VERY BAD"
+	     << endl;
+	cout << "              IDEA; you should select anything else." << endl;
     }
     if (!fatal_error) {
         //if ( !mOutput.local && !((Run_Par.cumlog_file_name).empty()) ) {
-        if ( !mOutput.local && !((mOutput.cumlog_file_name).empty()) ) {
-	    cout << "SenseMonitor WARNING: -local option has not been selected; specification\n";
-            cout << "                      of log-file name will be ignored.\n";
+        if (!mOutput.local && !mOutput.cumlog_file_name.empty()) {
+	    cout << "SenseMonitor WARNING: -local option has not been "
+		 << "selected; specification" << endl;
+            cout << "                      of log-file name will be ignored."
+		 << endl;
         }
-//----- :KLUDGE: Put in corresponding check that xml calibration file can be read.
-/*
-        //---------- Get name of calibration file.
-	if (Run_Par.statcal) {
-	    if ( (Run_Par.cal_file_name).empty() ) {
-  	        cout << "SenseMonitor WARNING: No calibration file specified; will look for default\n";
-                cout << "                      calibration file.\n";
-                //---------- Look for calibration file in directory specified
-                //           in $SENSEMONITOR_CALIBRATION instead of in local directory.
-                const char* cal_dir = getenv("SENSEMONITOR_CALIBRATION");
-                if (cal_dir) {
-                    Run_Par.cal_file_name = string(cal_dir) + "/";
-                } else { 
-	            cout << "SenseMonitor WARNING: Environment variable $SENSEMONITOR_CALIBRATION not set;\n"; 
-                    cout << "                      looking in local directory for default calibration file.\n";
-                }
-                Run_Par.cal_file_name += "SenseMonitor_Calibration_";
-                Run_Par.cal_file_name += Run_Par.IFO;
-                Run_Par.cal_file_name += ".txt";
-            }
-            //---------- Verify that calibration file can be opened.
-            ifstream input;
-            input.open((Run_Par.cal_file_name).c_str());
-            if (input.fail()) {
-                cerr << "SenseMonitor ERROR: Cannot open calibration file ";
-                cerr << Run_Par.cal_file_name  << ".  Exiting.\n";
-                fatal_error = true;
-                finish();
-            } else {
-	        cout << "SenseMonitor MESSAGE: Found calibration file ";
-	        cout << Run_Par.cal_file_name << endl;
-	    }
-            input.close();
-	} else {
-            //---------- Verify that open-loop-gain and sensing-function files can be opened.
-            ifstream input;
-            input.open((Run_Par.olg_file_name).c_str());
-            if (input.fail()) {
-                cerr << "SenseMonitor ERROR: Cannot open open-loop-gain file ";
-                cerr << Run_Par.olg_file_name  << ".  Exiting.\n";
-                fatal_error = true;
-                finish();
-            } else {
-	        cout << "SenseMonitor MESSAGE: Found open-loop-gain file ";
-	        cout << Run_Par.olg_file_name << endl;
-	    }
-            input.close();
-            input.open((Run_Par.sf_file_name).c_str());
-            if (input.fail()) {
-                cerr << "SenseMonitor ERROR: Cannot open sensing-function file ";
-                cerr << Run_Par.sf_file_name  << ".  Exiting.\n";
-                fatal_error = true;
-                finish();
-            } else {
-	        cout << "SenseMonitor MESSAGE: Found sensing-function file ";
-	        cout << Run_Par.olg_file_name << endl;
-	    }
-            input.close();
-	}
-*/
+
         //---------- Get name of OSC configuration files.
         if ( (Run_Par.osc_file_name).empty() ) {
-  	    cout << "SenseMonitor WARNING: No OSC configuration file specified; will look for\n";
-            cout << "                      default OSC configuration file.\n";
-            //---------- Look for OSC config file in directory specified
-            //           in $SENSEMONITOR_OSCCONF instead of in local directory.
+  	    cout << "SenseMonitor WARNING: No OSC configuration file "
+		 << "specified; will look for" << endl;
+            cout << "                      default OSC configuration file."
+		 << endl;
+            //---------- Look for OSC config file in directory specified in
+            //           $SENSEMONITOR_OSCCONF instead of in local directory.
             const char* osc_dir = getenv("SENSEMONITOR_OSCCONF");
             if (osc_dir) {
                 Run_Par.osc_file_name = string(osc_dir) + "/";
             } else { 
-	        cout << "SenseMonitor WARNING: Environment variable $SENSEMONITOR_OSCCONF not set;\n"; 
-                cout << "                      looking in local directory for default OSC file.\n";
+	        cout << "SenseMonitor WARNING: Environment variable "
+		     << "$SENSEMONITOR_OSCCONF not set;" << endl; 
+                cout << "                      looking in local directory "
+		     << "for default OSC file." << endl;
             }
             //Run_Par.osc_file_name += "LockLoss_";
             //Run_Par.osc_file_name += Run_Par.IFO;
             Run_Par.osc_file_name += "SenseMonitor_LockLoss.conf";
         }
-//----- :KLUDGE: Put in corresponding check that xml calibration file can be read.
-/*
-        //---------- Verify that calibration file can be opened.
-        ifstream input;  //----- previous declaration inside if () statement therefore gone.
-        input.open((Run_Par.osc_file_name).c_str());
-        if (input.fail()) {
-            cerr << "SenseMonitor ERROR: Cannot open OSC configuration file ";
-            cerr << Run_Par.osc_file_name  << ".  Exiting.\n";
-            fatal_error = true;
-            finish();
-        } else {
-	    cout << "SenseMonitor MESSAGE: Found OSC configuration file ";
-	    cout << Run_Par.osc_file_name << endl;
-	}
-        input.close();
-*/
     }
 }
 
