@@ -7,7 +7,7 @@
       
 //-->  The next three lines are needed if you are going to generate triggers.
 //     The text in PIDTITLE should describe the monitor function.
-#define PIDCVSHDR "$Header: https://redoubt.ligo-wa.caltech.edu/svn/gds/trunk/Monitors/SixtyHertzMon/SixtyHertzMon.cc 6294 2010-08-13 03:18:16Z john.zweizig@LIGO.ORG $"
+#define PIDCVSHDR "$Header: https://redoubt.ligo-wa.caltech.edu/svn/gds/trunk/Monitors/SixtyHertzMon/SixtyHertzMon.cc 7421 2015-07-19 05:30:31Z john.zweizig@LIGO.ORG $"
 #define PIDTITLE  "Sixty Hertz line monitor"
 // #include "ProcIdent.hh"
 
@@ -15,11 +15,11 @@
 #include <iostream>
 #include <fstream>
 #include <string>
-#include <stdlib.h>
+#include <cstdlib>
 #include "Hanning.hh"
 #include "fft.hh"
-#include <math.h>
-#include <fstream>
+#include <cmath>
+#include <sys/stat.h>
 
 using namespace std;
 
@@ -45,7 +45,7 @@ DatTemplate::DatTemplate(int argc, const char *argv[])
     for(int i=0;i<10;i++) tspd[i] = 0.0;
     current_month= "NA";
     string version = "debug";
-    char* html_dir = "./";
+    const char* html_dir = "./";
     htmldir        = html_dir;
     if( (html_dir = getenv("DMTHTMLOUT")) ) {
       if( strlen(html_dir) ){
@@ -121,7 +121,7 @@ DatTemplate::DatTemplate(int argc, const char *argv[])
     cout<<"Signal Channel:" << SignalChannel << endl;
 
     //----------------------------------  Make sure there's a valid channel
-    if (SignalChannel[0]== 'H');   
+    if (SignalChannel[0]== 'H')
       VoltageChannel      = "H0:PEM-LVEA2_V1";
     if (SignalChannel[0]== 'L')
       VoltageChannel      = "L0:PEM-LVEA_V1";
@@ -189,12 +189,12 @@ DatTemplate::DatTemplate(int argc, const char *argv[])
        }
     }     
 
-
     //----------------make necessary directories
-    string command;
-    command = "mkdir ";
-    command = command+htmldir+"history/";
-    system(command.c_str());
+    string history_dir = htmldir + "history/";
+    if (mkdir(history_dir.c_str(), 0777)) {
+       perror("SixtyHertzMon: Unable to make history directory");
+    }
+
     //----------------setup lock status indicator
     cout << " call mosc.setstride with mstep:"<<mstep<<endl; 
     mOSC.ignoreAllExcept(SigSub);
@@ -236,10 +236,10 @@ DatTemplate::ProcessData(void) {
       if (db >= 1) cout<< "newfile:"<<1<<endl;
       //make a new folder for a new month if neccessary
       if (newfolder()) {
-	string command;
-	command = "mkdir ";
-	command = command+htmldir+"history/"+HistFolder;
-	system(command.c_str());
+	string folder_dir = htmldir + "history/" + HistFolder;
+	if (mkdir(folder_dir.c_str(), 0777)) {
+	  perror("SixtyHertzMon: Unable to make history folder directory");
+	}
       }
 
       for(int hfindex=0;hfindex<nhf;hfindex++) {
