@@ -535,7 +535,7 @@ void StrainbandsMon::ProcessData() {
 			<< " - " << bands[i]->upperFreq << ": " << bandVal << endl;
 	}
 	
-	delete strainDensity;
+	delete[] strainDensity;
 	
 	//update the trend to include the most recent data
 	trend.Update();
