@@ -10,7 +10,7 @@
 
 //  The next three lines are needed if to generate triggers.
 //  The descriptive title in PIDTITLE should the monitor function.
-// #define PIDCVSHDR "$Header: https://redoubt.ligo-wa.caltech.edu/svn/gds/trunk/Monitors/WaveMon/WaveMon.cc 7156 2014-08-27 21:45:11Z john.zweizig@LIGO.ORG $"
+// #define PIDCVSHDR "$Header: https://redoubt.ligo-wa.caltech.edu/svn/gds/trunk/Monitors/WaveMon/WaveMon.cc 7987 2018-01-11 08:18:07Z john.zweizig@LIGO.ORG $"
 // #define PIDTITLE  "Data monitor environment template"
 // #include "ProcIdent.hh"
 
@@ -930,7 +930,7 @@ wavearray<float> WaveMon::getRate(wavecluster& ws)
 
   for(i=0; i<t.size(); i++){
      n = size_t(t.start()+t.data[i]) - t0;
-     if(n<0 || n>= buf.size()) 
+     if(n>= buf.size()) 
        cout<<"WaveMon::getRate() error. "<<t.data[i]<<"  "<<t0<<endl;
      else buf.data[n] += 1.;
   }
