@@ -2,7 +2,7 @@
 
 //-->  The next three lines are needed if you are going to generate triggers.
 //     The text in PIDTITLE should describe the monitor function.
-#define PIDCVSHDR "$Header: https://redoubt.ligo-wa.caltech.edu/svn/gds/trunk/Monitors/blrms/BandMonitor.cc 7131 2014-07-18 00:01:15Z john.zweizig@LIGO.ORG $"
+#define PIDCVSHDR "$Header: https://redoubt.ligo-wa.caltech.edu/svn/gds/trunk/Monitors/blrms/BandMonitor.cc 7889 2017-05-19 21:48:36Z john.zweizig@LIGO.ORG $"
 #define PIDTITLE  "Data monitor trigger template"
 #include "ProcIdent.hh"
 #include "BandMonitor.hh"
@@ -17,8 +17,7 @@
 
 #include "Time.hh"
 #include "DVecType.hh"
-#include "scandir.hh"
-#include "frame_name.hh"
+#include "ReadTrend.hh"
 #include "Trend.hh"
 #include "IIRfilter_structures.hh"
 #include "IIRfilter.hh"
@@ -227,61 +226,6 @@ BandMonitor::Attention(void) {
 
 //======================================  Monitor tseries functions
 //
-//======================================  Add a list of frames to a dacc
-static void
-add_frames(const Time& t0, const Interval dT, const std::string& dir, 
-	   DaccAPI& dacc) 
-{
-   scandir sd(dir);
-   Time::ulong_t tMin = t0.getS();
-   Time::ulong_t tMax = (t0+dT).getS();
-   while (sd.next_entry()) {
-      if (!sd.is_frame()) continue;
-      Time::ulong_t fMin = sd.gps();
-      if (fMin >= tMax) continue;
-      if (fMin + sd.duration() <= tMin) continue;
-      dacc.addPath(sd.file_path());
-   }
-}
-
-//======================================  Get data from trend frames
-static void 
-fill_from_trend(TSeries& ts, const Trend& tr, const string& chname) {
-   Dacc in;
-   Time start = ts.getStartTime();
-   Interval dT = ts.getInterval();
-   Time tend = start + dT;
-   const char* dmtout=getenv("DMTRENDOUT");
-   if (dmtout) {
-      frame_name frname;
-      frname.set_directory(dmtout);
-      string start_dir=frname.dir_name(start);
-      cout << "add frames from directory: " << start_dir << endl;
-      add_frames(start, dT, start_dir, in);
-      string end_dir = frname.dir_name(tend);
-      if (end_dir != start_dir) add_frames(start, dT, end_dir, in);
-   } else {
-      add_frames(start, dT, ".", in);
-   }
-
-   in.addChannel(chname);
-   in.seek(start);
-   int rc = 0;
-   while (!rc) {
-      if (in.synch() || in.getCurrentTime() >= tend) break;
-      Interval segDt = tend - in.getCurrentTime();
-      rc = in.fillData(segDt);
-      if (rc == -3) break;
-      if (!in.refData(chname)) continue;
-      const TSeries& trend_ts(*(in.refData(chname)));
-      if (!trend_ts.refDVect()) continue;
-      const DVector& trend_dv(*trend_ts.refDVect());
-      size_t fbin = ts.getBin(trend_ts.getStartTime());
-      size_t lbin = ts.getBin(trend_ts.getEndTime());
-      ts.refDVect()->replace(fbin, lbin-fbin, trend_dv);
-      if (rc == -4) rc = 0;
-   }
-}
 
 //======================================  Extract a sub-series
 static void 
@@ -422,29 +366,47 @@ void BandMonitor::ProcessData(void) {
 	       if (Debug()) cout << "trendname = " << trendname << endl;
 	       trend_channel_list.push_back(trendname);
 	       pblrmsTrend->addChannel(trendname.c_str());
-
-	       //----------------------------  Fetch data from the trend frames
-	       string meanChan = trendname + ".mean";
-	       fill_from_trend(monitor48h_tseries[monitor_count],
-			       *pblrmsTrend, meanChan);
-	       sqrt_dvect(dynamic_cast<DVectF&>
-	 		  (*monitor48h_tseries[monitor_count].refDVect()));
-	       fill_from_series(monitor_tseries[monitor_count], 
-				monitor48h_tseries[monitor_count]);
 	    }
 	    // end of code to name trend channels
 	
 	    ++monitor_count;
 	 }
-      }
 
-      // make index for trends
-      if ( make_trends && make_trend_index ) {
-	 pblrmsTrend->writeIndex();
       }
-      // now we are all ready to start writing time series of monitor data.
-   }
+      
+      //--------------------------------  Initialize monitor from trend values
+      if ( make_trends ) {
+	 ReadTrend rt;
+	 if (Debug()) rt.setDebug();
+	 rt.setMonitor(trend_name.c_str());
+	 ReadTrend::string_vect  rt_chan = trend_channel_list;
+	 ReadTrend::type_vect    rt_type(monitor_count, ReadTrend::kMean);
+	 ReadTrend::tseries_vect rt_data(monitor_count);
+	 rt.getSeries(rt_chan, rt_type, start48h, stop-start48h, rt_data);
 
+	 //-----------------------------  Copy rms to monitor vectors
+	 for (int i=0; i<monitor_count; i++) {
+	    monitor48h_tseries[i] = rt_data[i];
+	    if (Debug()) {
+	       Time t0 = monitor48h_tseries[i].getStartTime();
+	       cout << "read trend: " << rt_chan[i] << " data from " << t0.getS()
+		    << " to " << monitor48h_tseries[i].getEndTime().getS()
+		    << endl;
+	       if (!i) {
+		  Interval dT  = monitor48h_tseries[i].getTStep()*16.0;
+		  monitor48h_tseries[i].extract(t0, dT).Dump(cout);
+	       }
+	    }
+	    sqrt_dvect(dynamic_cast<DVectF&>(*monitor48h_tseries[i].refDVect()));
+	    fill_from_series(monitor_tseries[i], monitor48h_tseries[i]);
+	 }
+      
+	 //--------------------------  make index for trends
+	 if ( make_trend_index ) {
+	    pblrmsTrend->writeIndex();
+	 }
+      }
+   }  // end of first-sample initialization.
 
    //------------ THIS CODE RUN ONCE EVERY SECOND  ---------------
 
