@@ -6,12 +6,12 @@
  * January 2010.
  */
 
-// $Id: callineMon.cc 6385 2010-12-10 23:00:42Z john.zweizig@LIGO.ORG $
+// $Id: callineMon.cc 7899 2017-06-16 13:44:56Z ed.maros@LIGO.ORG $
 
 #include "callineMon.hh"
 
 
-#define PIDCVSHDR "$Header: https://redoubt.ligo-wa.caltech.edu/svn/gds/trunk/Monitors/callineMon/callineMon.cc 6385 2010-12-10 23:00:42Z john.zweizig@LIGO.ORG $"
+#define PIDCVSHDR "$Header: https://redoubt.ligo-wa.caltech.edu/svn/gds/trunk/Monitors/callineMon/callineMon.cc 7899 2017-06-16 13:44:56Z ed.maros@LIGO.ORG $"
 #define PIDTITLE  "Generate gamma factors for calibration lines"
 #include "ProcIdent.hh"
 
@@ -262,8 +262,8 @@ void callineMon::ProcessData()
             powers.push_back(compute_spectrum(GAMMA_RE, GAMMA_IM, t0));
         }
 
-        delete GAMMA_IM;
-        delete GAMMA_RE;
+        delete[] GAMMA_IM;
+        delete[] GAMMA_RE;
 
         /* For trends */
         LOG(4) << "Make trends\n";
@@ -303,7 +303,7 @@ void callineMon::ProcessData()
                 for (int m = 0; m < n; m++)
                     avg[m] = mAlpha * current[m] + (1-mAlpha) * old_avg[m];
                 mPowAvg[i]->setData(n, avg);
-                delete avg;
+                delete[] avg;
             }
         }
 
@@ -317,9 +317,9 @@ void callineMon::ProcessData()
 
     /* Leave a clean memory */
     LOG(5) << "Clean memory\n";
-    delete hann;
-    delete l;
-    delete dc;
+    delete[] hann;
+    delete[] l;
+    delete[] dc;
 
     for (size_t i = 0; i < gammas.size(); i++)
         delete gammas[i];
@@ -384,7 +384,7 @@ FSpectrum* callineMon::compute_spectrum(float* GAMMA_RE, float* GAMMA_IM,
     fftw_destroy_plan(p);
     fftw_free(in);
     fftw_free(out);
-    delete POWER;
+    delete[] POWER;
 
     return spectrum;
 }
