@@ -18,7 +18,7 @@ EXECDAT(DQ_Module)
 
 DQ_Module::DQ_Module(int argc, const char* argv[])
  : MultiStream(argc, argv), stride(4.0), flag_step(0.0625),
-   parity_bit(true), invert(false), config_version("Not Specified"), 
+   parity_bit(0), invert(false), config_version("Not Specified"), 
    config_crc32(0), frame_path("$HOME/frames/X-DQ_MODULE-%05r", "X-DQ_MODULE"),
    compression("uncompressed"), output_start(0), current(0), frames_out(0)
 {
@@ -35,6 +35,7 @@ DQ_Module::DQ_Module(int argc, const char* argv[])
    }
    getDacc().setStride(stride);
    setStrideAlignment(stride, 0.0);
+   init_output_channels();
    book_channels();
    fr_writer.setCompress(FrVectRef::get_compression_mode(compression));
 }
@@ -57,7 +58,9 @@ DQ_Module::put_config(ostream& out) const {
    out << "config-version: " << config_version << endl;
    out << "config-crc32:   " << config_crc32 << endl;
    out << "stride:         " << stride << endl;
-   out << "parity-bit      " << boolstr(parity_bit) << endl;
+   out << "parity-bit      ";
+   if (parity_bit < 0) out << "off" << endl;
+   else                out << parity_bit << endl;
    out << "invert          " << boolstr(invert) << endl;
    out << "flag_step:      " << flag_step << endl;
    out << "Frame_name:     " << frame_path.file_path(Time(0)) << endl;
@@ -162,10 +165,23 @@ DQ_Module::config(const std::string& cfg_file) {
    rdr.parse(conf_str.data(), conf_str.data() + conf_str.size(), doc);
    bool syntax = false;
 
-   parse_json(doc, "config_version", stride);
+   parse_json(doc, "config-version", config_version);
    parse_json(doc, "stride", stride);
    parse_json(doc, "flag_step", flag_step);
-   parse_json(doc, "parity-bit", parity_bit);
+   if (doc.isMember("parity-bit")) {
+      if (doc["parity-bit"].isBool()) {
+	 if (!doc["parity-bit"].asBool()) parity_bit = -1;
+      } else if (doc["parity-bit"].isNumeric()) {
+	 parity_bit = doc["parity-bit"].asInt();
+      } else {
+	 cerr << "Invalid parity-bit specification" << endl;
+	 syntax = true;
+      }
+      if (parity_bit >= 32) {
+	 cerr << "invalid parity bit number" << endl;
+	 syntax = true;
+      }
+   }
    parse_json(doc, "invert", invert);
    string write_path;
    if (parse_json(doc, "write_path", write_path)) frame_path.split(write_path);
@@ -257,7 +273,7 @@ DQ_Module::config(const std::string& cfg_file) {
 	    syntax = true;
 	    continue;
 	 }
-	 
+
 	 //----------------------------  Construct the channel
 	 DQ_bit* dq_obj = plug_init();
 	 dq_obj->dq_class(plugin);
@@ -286,6 +302,14 @@ DQ_Module::config(const std::string& cfg_file) {
 	       }
 	    }
 	 }
+
+	 //-----------------------------  Check the invert bit
+	 bool inv_flag = false;
+	 if (parse_json(flag_def, "invert", inv_flag)) {
+	    dq_obj->invert(inv_flag);
+	 }
+	 
+	 //-----------------------------  Add this flag to the list
 	 flag_vect.push_back(dq_obj);
       }
 
@@ -349,9 +373,10 @@ DQ_Module::book_channels(void) {
    }
 }
 
-//======================================  
+//======================================  calculate the flag bit
 void
 DQ_Module::set_flag(DQ_bit* dq_def, const Time& t0, Interval dT) {
+   //-----------------------------------  Get the input channel list
    DQ_bit::tser_vect data;
    const DQ_bit::chanlist_type& chanlist = dq_def->channel_list();
    size_t nChan = chanlist.size();
@@ -362,7 +387,7 @@ DQ_Module::set_flag(DQ_bit* dq_def, const Time& t0, Interval dT) {
 	 data.push_back(tsi->extract(t0, dT));
       } 
       else if (flag_map.find(chanlist[i]) != flag_map.end()) {
-	 data.push_back(flag_map[chanlist[i]].extract(t0,dT));
+	 data.push_back(flag_map[chanlist[i]].ref_series().extract(t0,dT));
       }
       else {
 	 ostringstream msg;
@@ -372,21 +397,26 @@ DQ_Module::set_flag(DQ_bit* dq_def, const Time& t0, Interval dT) {
       }
    }
 
+   //-----------------------------------  Calculate the bit value
    bool bit = dq_def->bit_value(data);
-   if (bit) {
+   if (dq_def->invert()) bit = !bit;
+
+   //-----------------------------------  And in the flag content
+   if (!bit) {
       flag_map_iter out_chan = flag_map.find(dq_def->bit_channel());
-      TSeries& tsout = out_chan->second;
+      TSeries& tsout = out_chan->second.ref_series();
       size_t inx = tsout.getBin(t0);
       DVectU* dv = dynamic_cast<DVectU*>(tsout.refDVect());
       if (!dv) {
 	 cerr << "Unable to find data vector for " << dq_def->bit_channel()
 	      << endl;
       } else {
-	 (*dv)[inx] |= 1 << dq_def->bit_number();
+	 (*dv)[inx] &= ~(1 << dq_def->bit_number());
       }
    }
 }
 
+//======================================  Initialize defined flag instances.
 void
 DQ_Module::init_all(void) {
    size_t nFlags = flag_vect.size();
@@ -395,6 +425,23 @@ DQ_Module::init_all(void) {
    }
 }
 
+//======================================  Define output channels.
+void
+DQ_Module::init_output_channels(void) {
+   size_t nFlags = flag_vect.size();
+   for (size_t iflag=0; iflag < nFlags; ++iflag) {
+      string chan = flag_vect[iflag]->bit_channel();
+      flag_map_iter itr = flag_map.find(chan);
+      if (itr == flag_map.end()) {
+	 dq_bitmask temp;
+	 flag_map.insert(flag_map_type::value_type(chan, temp));
+	 itr = flag_map.find(chan);
+	 if (itr == flag_map.end()) throw runtime_error("unableto add channel");
+      }
+      itr->second.enable(flag_vect[iflag]->bit_number());
+   }
+}
+
 //======================================  Process a stride.
 void 
 DQ_Module::ProcessData(void) {
@@ -404,27 +451,19 @@ DQ_Module::ProcessData(void) {
       init_all();
       current = getDacc().getFillTime();
    }
-   Interval dT = getDacc().getFillStride();
    
-   //-----------------------------------  Initialize template/
+   //-----------------------------------  Get time structure for a bit channel
+   Interval dT = getDacc().getFillStride();
    Interval fstep(flag_step);
    int nstep = int(double(dT) / fstep);
-   TSeries temp(current, fstep, 1, &data);
-   temp.extend(current + dT);
 
    //-----------------------------------  Initialize output bit masks.
-   size_t nFlags = flag_vect.size();
-   for (size_t iflag=0; iflag < nFlags; ++iflag) {
-      string chan = flag_vect[iflag]->bit_channel();
-      flag_map_iter itr = flag_map.find(chan);
-      if (itr == flag_map.end()) {
-	 flag_map.insert(flag_map_type::value_type(chan, temp));
-      } else {
-	 itr->second = temp;
-      }
+   for (flag_map_iter i=flag_map.begin(); i != flag_map.end(); i++) {
+      i->second.preset(current, fstep, nstep);
    }
    
    //-----------------------------------  Initialize step over times
+   size_t nFlags = flag_vect.size();
    for (int istep=0; istep < nstep; istep++) {
       Time t0 = current + fstep * double(istep);
       for (size_t iflag=0; iflag<nFlags; iflag++) {	 
@@ -432,20 +471,20 @@ DQ_Module::ProcessData(void) {
       }
    }
 
-   //-----------------------------------  Set the parity bit and inver data
-   if (parity_bit || invert) {
-      const uint32_t parity_bit = (1 << 31);
+   //-----------------------------------  Set the parity bit and invert data
+   if (parity_bit >= 0 || invert) {
+      const uint32_t parity_mask = (parity_bit < 0) ? 0 : (1 << parity_bit);
       for (flag_map_iter out_chan=flag_map.begin(); 
 	   out_chan != flag_map.end();
 	   out_chan++) { 
-         TSeries& tsout = out_chan->second;
+         TSeries& tsout = out_chan->second.ref_series();
          DVectU* dv = dynamic_cast<DVectU*>(tsout.refDVect());
 	 size_t N=tsout.getNSample();
 	 for (size_t i=0; i<N; i++) {
 	    uint32_t dvi = (*dv)[i];
-	    if (parity_bit) {
-	       dvi &= ~parity_bit;
-	       if (!odd_parity(dvi)) dvi |= parity_bit;
+	    if (parity_mask) {
+	       dvi &= ~parity_mask;
+	       if (!odd_parity(dvi)) dvi |= parity_mask;
             }
 	    if (invert) dvi = ~dvi;
 	    (*dv)[i] = dvi;
@@ -475,7 +514,25 @@ DQ_Module::write_frame(const Time& t0, Interval dT) {
 	    continue;
          }
       }
-      fr_writer.copyHistory(*(getDacc(inx)->getFrame()));
+      if (inx < 0 || inx > getNStream()) {
+	 static bool first_er1=true;
+	 if (first_er1) {
+	    cerr << "DQ_Module::write_frame: " << frametype
+		 << " is not a valid stream identifier." << endl;
+	    first_er1 = false;
+	 }
+      }
+      else if (!getDacc(inx) || !getDacc(inx)->getFrame()) {
+	 static bool first_er2=true;
+	 if (first_er2) {
+	    cerr << "DQ_Module::write_frame: No history records available "
+		 << "for stream " << frametype << endl;
+	    first_er2 = false;
+	 }
+      }
+      else {
+	 fr_writer.copyHistory(*(getDacc(inx)->getFrame()));
+      }
    }
 
    //-----------------------------------  Add a history record
@@ -499,7 +556,7 @@ DQ_Module::write_frame(const Time& t0, Interval dT) {
 
    //-----------------------------------  Write DQ flag series.
    for (const_flag_map_iter i=flag_map.begin(); i != flag_map.end(); i++) {
-      fr_writer.addProcSeries(i->first, i->second);
+      fr_writer.addProcSeries(i->first, i->second.ref_series());
    }
 
    //-----------------------------------  Open a writer to a frame file
@@ -542,3 +599,21 @@ DQ_Module::write_frame(const Time& t0, Interval dT) {
    fr_writer.close();
    fr_writer.erase();
 }
+
+//======================================  DQ channel constructor
+DQ_Module::dq_bitmask::dq_bitmask(void) 
+  : _enable_mask(0)
+{
+}
+
+//======================================  DQ channel destructor
+DQ_Module::dq_bitmask::~dq_bitmask(void) {
+}
+
+//======================================  Set an output channel for one stride
+void
+DQ_Module::dq_bitmask::preset(const Time& t0, Interval dT, size_t N) {
+   DVectU data(N);
+   for (size_t i=0; i<N; i++) data[i] = _enable_mask;
+   _series.setData(t0, dT, data.clone());
+}
