@@ -11,7 +11,7 @@
 #include "DVector.hh"
 #include "ParseLine.hh"
 
-#define PIDCVSHDR "$Header: https://redoubt.ligo-wa.caltech.edu/svn/gds/trunk/Monitors/eqMon/eqMon.cc 6557 2011-12-27 05:12:17Z john.zweizig@LIGO.ORG $"
+#define PIDCVSHDR "$Header: https://redoubt.ligo-wa.caltech.edu/svn/gds/trunk/Monitors/eqMon/eqMon.cc 7411 2015-07-17 20:33:04Z ed.maros@LIGO.ORG $"
 #define PIDTITLE "Earthquake Monitor"
 #include "ProcIdent.hh"
 
@@ -83,11 +83,11 @@ eqMon::eqMon(int argc, const char *argv[]) :
   /////////////  Set some variables
   mDataName = mDict.getString("DataPrefix");
   mEventName = mDict.getString("EventPrefix");
-  if (mDataName[0] |= '/' && mDataName[0] != '.') {
+  if (mDataName[0] != '/' && mDataName[0] != '.') {
     const char* datadir = getenv("DMTOUTPUT");
     if (datadir) mDataName = string(datadir) + "/" + mDataName;
   }
-  if (mEventName[0] |= '/' && mEventName[0] != '.') {
+  if (mEventName[0] != '/' && mEventName[0] != '.') {
     const char* htmldir = getenv("DMTHTMLOUT");
     if (htmldir) mEventName = string(htmldir) + "/" + mEventName;
   }
