@@ -1,5 +1,5 @@
 /* -*- mode: c++; c-basic-offset: 3 -*- */
-#define PIDCVSHDR "$Header: https://redoubt.ligo-wa.caltech.edu/svn/gds/trunk/Monitors/kleineWelle/kleineWelleM.cc 7469 2015-09-16 16:26:55Z john.zweizig@LIGO.ORG $"
+#define PIDCVSHDR "$Header: https://redoubt.ligo-wa.caltech.edu/svn/gds/trunk/Monitors/kleineWelle/kleineWelleM.cc 7497 2015-10-18 20:58:45Z john.zweizig@LIGO.ORG $"
 #define PIDTITLE  "kleineWelle"
 #include "ProcIdent.hh"
 #include "mywv2lib.hh"
@@ -478,7 +478,7 @@ void kleineWelle::ProcessData(void)
       if(t0 == lasttime) {
 	 //----------------------------  Open the output trigger file.
          trg_path.make_dir(trg_path.dir_name(t0));
-	 string trgfile = trg_path.file_path(t0);
+	 string trgfile = trg_path.temp_path(t0);
 	 ofstream outfile(trgfile.c_str());
 	 if (!outfile) {
 	    cerr << "cannot write to file: " << trgfile << endl;
