@@ -101,6 +101,7 @@ namespace framexmit {
    
       // options
       if (mcast_addr != 0) {
+	 char adr_tmp[32];
       
          // check multicast address
          if (!IN_MULTICAST (ntohl (inet_addr (mcast_addr)))) {
@@ -128,12 +129,12 @@ namespace framexmit {
          if (logison) {
             char buf[256];
             sprintf (buf, "Join multicast %s at %s", mcast_addr,
-                    inet_ntoa(i_addr));
+		     inet_ntop(AF_INET, &i_addr, adr_tmp, sizeof(adr_tmp)));
             addLog (buf);
          }
       #ifdef DEBUG
          cout << "join multicast " << mcast_addr << " at " 
-	      << inet_ntoa (i_addr) << endl;
+	      << inet_ntop(AF_INET, &i_addr, adr_tmp, sizeof(adr_tmp)) << endl;
       #endif
       }
       else {
