@@ -10,6 +10,7 @@
 #include "lcl_array.hh"
 #include <iostream>
 #include <cstring>
+#include <cctype>
 #include <cmath>
 
 using namespace std;
@@ -78,9 +79,9 @@ dRemez(int N, double Hz, int nBand, const double* Bands,
 //======================================  Window and filter type translation
 #define N_WMODE 7
 #define N_FMODE 4
-const char* wmode[N_WMODE] = {"Rectangle", "Triangle", "Hamming", "GHamming", 
-			      "Hanning", "Kaiser", "Cheby"};
-const char* fmode[N_FMODE] = {"LowPass", "HighPass", "BandPass", "BandStop"};
+const char* wmode[N_WMODE] = {"rectangle", "triangle", "hamming", "ghamming", 
+			      "hanning", "kaiser", "cheby"};
+const char* fmode[N_FMODE] = {"lowpass", "highpass", "bandpass", "bandstop"};
 
 //======================================  Windowed sinc design method
 FIRFilter
@@ -94,13 +95,13 @@ dFirW(int N, double Hz, const char* window, const char* type, double Flow,
     //----------------------------------  Get the window mode
     int wm=-1;
     for (int i=0 ; i<N_WMODE ; i++) {
-        if (!strcmp(wmode[i], window)) {
+        if (!strcasecmp(wmode[i], window)) {
 	    wm = i+1;
 	    break;
 	}
     }
     if (wm < 0) {
-	if (!strcmp("Hann", window)) {
+	if (!strcasecmp("hann", window)) {
 	    wm = 5; // "Hann" == "Hanning"
 	} else{
 	    throw std::invalid_argument("dFirW: Invalid window type.");
@@ -110,7 +111,7 @@ dFirW(int N, double Hz, const char* window, const char* type, double Flow,
     //----------------------------------  Get the filter mode
     int fm=-1;
     for (int i=0 ; i<N_FMODE ; i++) {
-        if (!strcmp(fmode[i], type)) {
+        if (!strcasecmp(fmode[i], type)) {
 	    fm = i+1;
 	    break;
 	}
@@ -124,6 +125,7 @@ dFirW(int N, double Hz, const char* window, const char* type, double Flow,
     if (rc > 0) {  // if (rc==1) Nf was recalculated.
         delete[] h;
 	h = new double[Nf];
+	cerr << "Number of coefficients reset to " << Nf << endl;
 	rc = FirW(Nf, wm, fm, Flow/Hz, Fhigh/Hz, 2*dF/Hz, Ripple, h);
     }
     if (rc) throw std::runtime_error("dFirW: Unable to construct filter");
@@ -197,6 +199,9 @@ SincVect(double f, long N, double t0, double dT) {
 FIRFilter 
 dFirW(int N, double Hz, const window_api& win, const std::string& type, 
       double fLow, double fHigh) {
+    string lctype = type;
+    for (size_t i=0; i<type.size(); i++) lctype[i] = tolower(lctype[i]);
+    
     if (N  <= 0) throw runtime_error("dFirW: invalid filter length."); 
     if (Hz <= 0) throw runtime_error("dFirW: invalid sample rate."); 
 
@@ -210,19 +215,19 @@ dFirW(int N, double Hz, const window_api& win, const std::string& type,
     DVectD dv;
 
     //------------------------------  Lowpass: sinc(wLow)
-    if (type == "LowPass") {
+    if (lctype == "lowpass") {
 	dv = SincVect(fLow, N, t0, dT);
     }
 
     //------------------------------  Highpass: delta(t)-sinc(wHigh)
-    else if (type == "HighPass") {
+    else if (lctype == "highpass") {
 	dv = SincVect(fLow, N, t0, dT);
 	dv *= -1;
 	dv[N2] += 1.0;
     }
 
     //------------------------------  BandPass: sinc(wHigh)-sinc(wLow)
-    else if (type == "BandPass") {
+    else if (lctype == "bandpass") {
 	if (fHigh < 0 || fHigh > fNy) 
 	    throw runtime_error("dFirW: Invalid high frequency (fHigh)");
 	dv  = SincVect(fHigh, N, t0, dT);
@@ -230,7 +235,7 @@ dFirW(int N, double Hz, const window_api& win, const std::string& type,
     }
 
     //------------------------------  BandStop: delta(t)+sinc(wLow)-sinc(wHigh)
-    else if (type == "BandStop") {
+    else if (lctype == "bandstop") {
 	if (fHigh < 0 || fHigh > fNy) 
 	    throw runtime_error("dFirW: Invalid high frequency (fHigh)");
 	dv  = SincVect(fLow, N, t0, dT);
