@@ -79,7 +79,14 @@ FirW(int& Nf, int itype, int jtype, double f1, double f2, double df,
     case 6:
         //------------------------------  Calculate Kaiser filter length if
         //                                not supplied.
-        if (!Nf) Nf = int((ripple-7.95)/(14.36*df)) + 1;
+        if (Nf <= 0) {
+	    if (ripple <= 0 || df <= 0) {
+		cerr << "FirW: Can't calculate Kaiser filter order, "
+		     << "ripple or df <= 0." << endl;
+		return -1;
+	    }
+	    Nf = int((ripple-7.95)/(14.36*df)) + 1;
+	}
         break;
 
     case 7:
