@@ -4,7 +4,7 @@
 
 //======================================  Constructor
 YPipe::YPipe(void) 
-  : mStartTime(0), mCurrentTime(0)
+  : mStartTime(0)
 {}
 
 //======================================  Destructor
