@@ -1,8 +1,8 @@
-#include <string.h>
-#include <strings.h>
-#include <stdio.h>
+#include <cstring>
+#include <cstdio>
 #include <string>
 #include <cstdlib>
+#include <cctype>
 #include <iostream>
 #include "FilterParse.hh"
 #include "zp2zp.hh"
@@ -10,9 +10,9 @@
 
    using namespace std;
 
-//______________________________________________________________________________
-   void FilterParse::splitLine ( const string& str_in, 
-                     StrList& strlist, char delim) 
+//======================================  Utility functions
+   void
+   FilterParse::splitLine(const string& str_in, StrList& strlist, char delim) 
    {
       if ( str_in.size() ) {
       
@@ -59,7 +59,8 @@
    }
 
 //______________________________________________________________________________
-   bool FilterParse::str2cmplx ( const string& str, dComplex& value ) 
+   bool
+   FilterParse::str2cmplx ( const string& str, dComplex& value ) 
    {
       if ( str.empty() ) {
          return false;
@@ -107,7 +108,7 @@
                   resign = -1;
                }
                else { // sign error
-                  cerr << "Sign error in a Complex Nubmer. " << str << endl;
+                  cerr << "Sign error in a Complex Number. " << str << endl;
                   value.setMArg( 0.0, 0.0 );
                   return false;
                }
@@ -132,7 +133,7 @@
                   imsign = -1;
                }
                else { // sign error
-                  cerr << "Sign error in a Complex Nubmer. " << str << endl;
+                  cerr << "Sign error in a Complex Number. " << str << endl;
                   value.setMArg( 0.0, 0.0 ); 
                   return false;
                }
@@ -142,7 +143,8 @@
                   isimag = true;
                }
                else {
-                  cerr << "Imaginary symbol error in a Complex Nubmer. " << str << endl;
+                  cerr << "Imaginary symbol error in a Complex Number. "
+		       << str << endl;
                   value.setMArg( 0.0, 0.0 );
                   return false;
                }
@@ -156,7 +158,8 @@
             if ( imline[imline.size() - 1] == 'i' ) {
                if ( !isimag ) isimag = true;
                else { // imag symbol error
-                  cerr << "Imaginary symbol error in a Complex Nubmer. " << str << endl;
+                  cerr << "Imaginary symbol error in a Complex Number. "
+		       << str << endl;
                   value.setMArg( 0.0, 0.0 );
                   return false;
                }
@@ -167,7 +170,8 @@
          if (imline.empty()) imline = "1"; // could i alone!
       
          if ( !isimag ) {
-            cerr << "Imaginary symbol error in a Complex Nubmer. " << str << endl;
+            cerr << "Imaginary symbol error in a Complex Number. "
+		 << str << endl;
             value.setMArg( 0.0, 0.0 );
             return false;
          }
@@ -304,9 +308,12 @@
       splitLine( arg, arglist );
    
       int size = arglist.size();
-   
-      // gain
-      if ( strcasecmp ( name.c_str(), "gain" ) == 0 ) {
+      
+      string tname = name;
+      for (size_t i=0; i<name.size(); i++) tname[i] = tolower(name[i]);
+      
+      //--------------------------------  gain
+      if (tname == "gain") {
       
          double g;
          string format = "scalar";
@@ -334,8 +341,8 @@
          }
       
       }
-      // pole
-      else if ( strcasecmp ( name.c_str(), "pole" ) == 0 ) {
+      //--------------------------------  pole
+      else if (tname == "pole") {
       
          double f;
          double gain = 1;
@@ -389,8 +396,8 @@
          }
       
       }
-      // zero
-      else if ( strcasecmp ( name.c_str(), "zero" ) == 0 ) {
+      //--------------------------------  zero
+      else if (tname == "zero") {
       
          double f;
          double gain = 1;
@@ -444,8 +451,8 @@
          }
       
       }
-      // pole2
-      else if ( strcasecmp ( name.c_str(), "pole2" ) == 0 ) {
+      //--------------------------------  pole2
+      else if (tname == "pole2") {
       
          double f;
          double Q;
@@ -501,8 +508,8 @@
          }
       
       }
-      // zero2
-      else if ( strcasecmp ( name.c_str(), "zero2" ) == 0 ) {
+      //--------------------------------  zero2
+      else if (tname == "zero2") {
       
          double f;
          double Q;
@@ -558,8 +565,8 @@
          }
       
       }
-      // zpk
-      else if ( strcasecmp ( name.c_str(), "zpk" ) == 0 ) {
+      //--------------------------------  zpk
+      else if (tname == "zpk") {
       
          int size = arglist.size();
       
@@ -639,8 +646,8 @@
             return false;
       
       }
-      // rpoly 
-      else if ( strcasecmp ( name.c_str(), "rpoly" ) == 0 ) {
+      //--------------------------------  rpoly 
+      else if (tname == "rpoly") {
       
          if ( size != 3 ) {
             cerr << "Too few/many arguments." << endl;
@@ -693,8 +700,8 @@
             return false;
       
       }
-      // biquad
-      else if ( strcasecmp ( name.c_str(), "biquad" ) == 0 ) {
+      //--------------------------------  biquad
+      else if (tname == "biquad") {
       
          if ( size != 5 ) {
             cerr << "Too few/many arguments." << endl;
@@ -711,8 +718,8 @@
             return false;
          }
       }
-      // sos
-      else if ( strcasecmp ( name.c_str(), "sos" ) == 0 ) {
+      //--------------------------------  sos
+      else if (tname == "sos") {
       
          int size = arglist.size();
          string format = "s";
@@ -770,8 +777,8 @@
             return false;
       
       }
-      // zroots
-      else if ( strcasecmp ( name.c_str(), "zroots" ) == 0 ) {
+      //--------------------------------  zroots
+      else if (tname == "zroots") {
       
          int size = arglist.size();
       
@@ -837,8 +844,8 @@
             return false;
       
       }
-      // direct
-      else if ( strcasecmp ( name.c_str(), "direct" ) == 0 ) {
+      //--------------------------------  direct
+      else if (tname == "direct") {
       
          if ( size != 2 ) {
             cerr << "Too few/many arguments." << endl;
@@ -884,8 +891,8 @@
             return false;
       
       }
-      // elliptic
-      else if ( strcasecmp ( name.c_str(), "ellip" ) == 0 ) {
+      //--------------------------------  elliptic
+      else if (tname == "ellip") {
       
          Filter_Type type; 
          int order;
@@ -914,7 +921,8 @@
                   }
                   if ( ( type == kBandPass || type == kBandStop ) &&
                      size != 6 ) {
-                     cerr << "BandPass and BandStop filters require two cutoff frequencies." << endl;
+                     cerr << "BandPass and BandStop filters require two "
+			  << "cutoff frequencies." << endl;
                      return false;
                   }
                   break;
@@ -930,8 +938,8 @@
             return false;
          }
       }
-      // chebyshev type-1
-      else if ( strcasecmp ( name.c_str(), "cheby1" ) == 0 ) {
+      //--------------------------------  chebyshev type-1
+      else if (tname == "cheby1") {
       
          Filter_Type type;
          int order;
@@ -959,7 +967,8 @@
                   }
                   if ( ( type == kBandPass || type == kBandStop ) &&
                      size != 5 ) {
-                     cerr << "BandPass and BandStop filters require two cutoff frequencies." << endl;
+                     cerr << "BandPass and BandStop filters require two "
+			  << "cutoff frequencies." << endl;
                      return false;
                   }
                   break;
@@ -975,8 +984,8 @@
             return false;
          }
       }
-      // chebyshev type-2
-      else if ( strcasecmp ( name.c_str(), "cheby2" ) == 0 ) {
+      //--------------------------------  chebyshev type-2
+      else if (tname == "cheby2") {
       
          Filter_Type type;
          int order;
@@ -1004,7 +1013,8 @@
                   }
                   if ( ( type == kBandPass || type == kBandStop ) &&
                      size != 5 ) {
-                     cerr << "BandPass and BandStop filters require two cutoff frequencies." << endl;
+                     cerr << "BandPass and BandStop filters require two "
+			  << "cutoff frequencies." << endl;
                      return false;
                   }
                   break;
@@ -1020,8 +1030,8 @@
             return false;
          }
       }
-      // butterworth filter
-      else if ( strcasecmp ( name.c_str(), "butter" ) == 0 ) {
+      //--------------------------------  butterworth filter
+      else if (tname == "butter") {
       
          Filter_Type type;
          int order;
@@ -1048,7 +1058,8 @@
                   }
                   if ( ( type == kBandPass || type == kBandStop ) &&
                      size != 4 ) {
-                     cerr << "BandPass and BandStop filters require two cutoff frequencies." << endl;
+                     cerr << "BandPass and BandStop filters require two "
+			  << "cutoff frequencies." << endl;
                      return false;
                   }
                   break;
@@ -1064,8 +1075,8 @@
             return false;
          }
       }
-      // notch
-      else if ( strcasecmp ( name.c_str(), "notch" ) == 0 ) {
+      //--------------------------------  notch
+      else if (tname == "notch") {
       
          double f0;
          double Q;
@@ -1095,8 +1106,8 @@
          }
       
       }
-      // resgain
-      else if ( strcasecmp ( name.c_str(), "resgain" ) == 0 ) {
+      //--------------------------------  resgain
+      else if (tname == "resgain") {
       
          double f0;
          double Q;
@@ -1126,8 +1137,8 @@
          }
       
       }
-      // comb
-      else if ( strcasecmp ( name.c_str(), "comb" ) == 0 ) {
+      //--------------------------------  comb
+      else if (tname == "comb") {
       
          int N = 0;
          double amp = 0.0;
@@ -1162,8 +1173,8 @@
          }
       
       }
-      // remez
-      else if ( strcasecmp ( name.c_str(), "remez" ) == 0 ) {
+      //--------------------------------  remez
+      else if (tname == "remez") {
       
          int N;
          int nBand;
@@ -1229,7 +1240,7 @@
       
       }
       //--------------------------------  firls()
-      else if ( strcasecmp ( name.c_str(), "firls" ) == 0 ) {
+      else if (tname == "firls") {
       
          int N;
          int nBand;
@@ -1295,8 +1306,8 @@
             return false;
       
       }
-      //firw
-      else if ( strcasecmp ( name.c_str(), "firw" ) == 0 ) {
+      //--------------------------------  firw
+      else if (tname == "firw") {
       
          int N;
          Filter_Type type;
@@ -1355,8 +1366,8 @@
       
       }
 
-      //fircoef
-      else if ( strcasecmp ( name.c_str(), "fircoef" ) == 0 ) {
+      //--------------------------------  fircoef
+      else if (tname == "fircoef") {
 	 string mode;
 	 bool ftype = false;
          vector<double> coefs;
@@ -1393,8 +1404,8 @@
       
       }
 
-      // difference
-      else if ( strcasecmp ( name.c_str(), "difference" ) == 0 ) {
+      //--------------------------------  difference
+      else if (tname == "difference") {
       
          if ( !size ) {
             if ( !difference() ) {
@@ -1408,8 +1419,8 @@
       
       }
 
-      // limiter
-      else if ( strcasecmp ( name.c_str(), "limiter" ) == 0 ) {
+      //--------------------------------  limiter
+      else if (tname == "limiter") {
       
          double l1;
          double l2 = 0.0;
@@ -1443,8 +1454,8 @@
          }
       
       }
-      // decimateBy2
-      else if ( strcasecmp ( name.c_str(), "decimateBy2" ) == 0 ) {
+      //--------------------------------  decimateBy2
+      else if (tname == "decimateBy2") {
       
          int N;
          int filtid = 1;
@@ -1472,8 +1483,8 @@
          }
       
       }
-      // multirate
-      else if ( strcasecmp ( name.c_str(), "multirate" ) == 0 ) {
+      //--------------------------------  multirate
+      else if (tname == "multirate") {
       
          double m1, m2 = 1E-3;
          double atten = 80;
@@ -1506,8 +1517,8 @@
          }
       
       }
-      // mixer
-      else if ( strcasecmp ( name.c_str(), "mixer" ) == 0 ) {
+      //--------------------------------  mixer
+      else if (tname == "mixer") {
       
          double fmix;
          double phase = 0.0;
@@ -1535,8 +1546,8 @@
          }
       
       }
-      // linefileter
-      else if ( strcasecmp ( name.c_str(), "linefilter" ) == 0 ) {
+      //--------------------------------  linefilter
+      else if (tname == "linefilter") {
       
          double f;
          double T = 0.0;
@@ -1576,8 +1587,8 @@
          }
       
       }
-      // frontend
-      else if ( strcasecmp ( name.c_str(), "frontend" ) == 0 ) {
+      //--------------------------------  frontend
+      else if (tname == "frontend") {
       
          int section = -1;
       
@@ -1603,8 +1614,8 @@
          }
       
       }
-      // closeloop
-      else if ( strcasecmp ( name.c_str(), "closeloop" ) == 0 ) {
+      //--------------------------------  closeloop
+      else if (tname == "closeloop") {
       
          double g;
       
@@ -1626,8 +1637,8 @@
          }
       
       }
-      // setgain
-      else if ( strcasecmp ( name.c_str(), "setgain" ) == 0 ) {
+      //--------------------------------  setgain
+      else if (tname == "setgain") {
          if ( size != 2 ) {
             cerr << "Too few/many arguments." << endl;
             return false;
@@ -1643,8 +1654,5 @@
          return false;
       }
    
-   
       return true;
-   
    }
-
