@@ -1,6 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 4; -*- */
 #include <time.h>
 #include <iostream>
+#include <sstream>
 #include <algorithm>
 #include "DVector.hh"
 #include "IIRSos.hh"
@@ -102,13 +103,20 @@ IIRFilter::init(unsigned int npoles, const dComplex* pole,
 IIRFilter& 
 IIRFilter::operator*=( const IIRFilter& f )
 {
+    if (!f._in_use) {
+	return *this;
+    }
     if ( !_in_use ) {
 	_in_use = true;
 	_filter_gain = 1;
-	_have_s_representation = true;
+	_sample_rate = f._sample_rate;
+	_have_s_representation = f._have_s_representation;
     }
-    if (!f._in_use) {
-	return *this;
+    if (_sample_rate != f._sample_rate) {
+	ostringstream msg;
+	msg << "IIRFilter: Can not combine filters with unequal sample rates ("
+	    << _sample_rate << ", " << f._sample_rate << ")." << endl;
+	throw runtime_error(msg.str());
     }
     if (_have_s_representation && f._have_s_representation) {
 	copy (f._pole_pair.begin(), 
@@ -238,7 +246,7 @@ IIRFilter::~IIRFilter(void)
 TSeries 
 IIRFilter::apply(const TSeries& data_in)
 {
-    if(_in_use && !data_in.isEmpty()) {
+    if (_in_use && !data_in.isEmpty()) {
 
 	// Check data
 	dataCheck(data_in);
