@@ -576,7 +576,7 @@ int
 IIRSos::apply(double* pdata, int ndata) {
    if (!_section_loaded) throw runtime_error("IIRSOS::apply: Not initialized");
 
-   register double hzm1(_hzminusone), hzm2(_hzminustwo);
+   double hzm1(_hzminusone), hzm2(_hzminustwo);
    switch (_evmode) {
    case sos_df2:
       //------------------------------  apply single second order section
@@ -619,7 +619,7 @@ int
 IIRSos::apply(float* pdata, int ndata) {
    if (!_section_loaded) throw runtime_error("IIRSOS::apply: Not initialized");
 
-   register double hzm1(_hzminusone), hzm2(_hzminustwo);
+   double hzm1(_hzminusone), hzm2(_hzminustwo);
 
    switch (_evmode) {
    case sos_df2:
