@@ -99,7 +99,7 @@ unsigned int LineFilter::maxLine(int L)
 
 bool LineFilter::isDataValid(const TSeries& ts) const 
 {
-  if(!(&ts)) return false;
+  // if(!(&ts)) return false;
   try {
     dataCheck(ts);
   } 
