@@ -26,6 +26,11 @@ LinearSum::apply(const TSeries& x, const TSeries& y) {
   return tempA;
 }
 
+LinearSum*
+LinearSum::clone(void) const {
+  return new LinearSum(*this);
+}
+
 //======================================  Apply the filter to the input series
 void 
 LinearSum::dataCheck(const TSeries& x, const TSeries& y) const {
