@@ -1,5 +1,5 @@
 #include "Bartlett.hh"
-#include <math.h>
+#include <cmath>
 #include "constant.hh"
 
 //--------------------------------------  Constructor.
