@@ -1,5 +1,5 @@
 #include "Blackman.hh"
-#include <math.h>
+#include <cmath>
 
 //--------------------------------------  Constructor.
 Blackman::Blackman(int N, double Beta) : mBeta(Beta) {
