@@ -5,7 +5,7 @@
 //////////////////////////////////////////////////////////////////////////
 #if !defined (__GNUG__) || defined (_NEED_EVENTALGORITHM_TEMPL)
 #include "PConfig.h"
-#include <stdio.h>
+#include <cstdio>
 #include <queue>
 #include <vector>
 #include <functional>
