@@ -12,20 +12,12 @@
 // #include "framecpp/Dimension.hh"
 #include "framecpp/FrVect.hh"
 
-#if LDAS_VERSION_NUMBER < 200000
-#include "general/gpstime.hh"
-using General::GPSTime;
-#else
 #include "framecpp/GPSTime.hh"
 using FrameCPP::GPSTime;
-#endif
 
-#if LDAS_VERSION_NUMBER < 109360
-#include "framecpp/OFrameStream.hh"
-#else
 #include "framecpp/Common/IOStream.hh"
 using FrameCPP::Common::FrameBuffer;
-#endif
+
 #include <fstream>
 #include <cstring>
 #include <cstdio>
@@ -54,11 +46,7 @@ FrWrite::FrWrite(int argc, const char *argv[])
   : DMTBase(argc, argv), mFrOut(1), mFrDone(0), mFrTotal(0), mFileOut(0),
     mRepeat(1), mSequence(0), mMode(m_CopyAll), mResize(0), mTOC(false), 
     mWriter(0),
-#if LDAS_VERSION_NUMBER < 109360
-    mStream(0),
-#else
     mFrameBuf(0),
-#endif
     mOSC(0), mBackFrame(0), mTrigFrame(1), mBackWrite(0), mBackValid(0)
 {
     const char* synText[] = {
@@ -214,17 +202,7 @@ FrWrite::openWriter(const Time& gps) {
 
     //--------------------------------  Open the output file
     mCurFile = line;
-#if LDAS_VERSION_NUMBER < 109360
-    mStream = new ofstream(line, ios::out);
-    if (mStream->good()) {
-        cout << "FrWrite: Opened " << mCurFile << " for frame output, TOC=" 
-	     << mTOC << endl;
-    } else {
-        cerr << "FrWrite: Can't open " << mCurFile << " for output." << endl;
-	return true;
-    }
-#else
-    auto_ptr< FrameBuffer<filebuf> > fb(new FrameBuffer<filebuf>(ios::out));
+    unique_ptr< FrameBuffer<filebuf> > fb(new FrameBuffer<filebuf>(ios::out));
     if (fb->open(line, ios::out)) {
         cout << "FrWrite: Opened " << mCurFile << " for frame output, TOC=" 
 	     << mTOC << endl;
@@ -233,15 +211,10 @@ FrWrite::openWriter(const Time& gps) {
 	return true;
     }
     mFrameBuf = fb.release();
-#endif
 
     //--------------------------------  Create a frame writer.
     try {
-#if LDAS_VERSION_NUMBER < 109360
-        mWriter = new FrameCPP::OFrameStream(*mStream);
-#else
         mWriter = new FrameCPP::OFrameStream(mFrameBuf);
-#endif
     } catch (std::exception& e) {
         mWriter = 0;
 	cerr << "FrWrite: Unable to open writer: " << e.what() << endl;
@@ -465,29 +438,17 @@ FrWrite::closeWriter(void)
 	    if (mTOC) cout << " and writing TOC.";
 	    cout << endl;
 	}
-#if LDAS_VERSION_NUMBER < 109360
-        mWriter->close();
-        delete mWriter;
-#else
         mWriter->Close();
         delete mWriter;
 	mFrameBuf = 0;
-#endif
 	mFileOut++;
 	mWriter = 0;
     }
 
-#if LDAS_VERSION_NUMBER < 109360
-    if (mStream) {
-        delete mStream;
-	mStream = 0;
-    }
-#else
     if (mFrameBuf) {
         delete mFrameBuf;
 	mFrameBuf = 0;
     }
-#endif
 }
 
 //======================================  Print final Results
@@ -553,39 +514,8 @@ ChanDesc::Copy(fradcdata_pointer in, frameh_pointer out,
     if (!dT) {
         FrRawData::firstAdc_iterator  iadc = cadc->append(in);
     } else {
-#if LDAS_VERSION_NUMBER < 109000
-        frvect_pointer vect(in->RefData().front());
-        Dimension dim = vect->GetDim(0);
-	size_t inx = size_t((double(Off) - dim.GetStartX())/dim.GetDx() + 0.5);
-	size_t len = size_t(double(dT)/dim.GetDx() + 0.5);
-	if (len+inx > dim.GetNx()) len = dim.GetNx() - inx;
-	dim.SetNx(len);
-	short  type  = vect->GetType();
-	size_t tSize = FrVect::GetTypeSize(type);
-	frvect_pointer newV(new FrVect(vect->GetName(),
-				       vect->GetType(),
-				       1,
-				       &dim,
-				       FrameCPP::BYTE_ORDER_HOST,
-				       vect->GetData(true)+inx*tSize,
-				       vect->GetUnitY()));
-	auto_ptr<FrAdcData> newA(new FrAdcData( in->GetName(), 
-						in->GetChannelGroup(),
-						in->GetChannelNumber(), 
-						in->GetNBits(),
-						in->GetSampleRate(),
-						in->GetBias(),
-						in->GetSlope(),
-						in->GetUnits(),
-						in->GetFShift(),
-						in->GetTimeOffset(),
-						in->GetDataValid(),
-						in->GetPhase())
-				 );
-	newA->RefData().append(newV, false, true);
-        cadc->append(newA.release(), false, true);
-#elif !defined(FCPP_SHARED_PTRS)
-	auto_ptr<FrAdcData> newA = in->SubFrAdcData(Off, dT);
+#if !defined(FCPP_SHARED_PTRS)
+	unique_ptr<FrAdcData> newA = in->SubFrAdcData(Off, dT);
         cadc->append(newA.release(), false, true);
 #else
 	fradcdata_pointer newA(in->Subset(Off, dT));
