@@ -56,7 +56,8 @@ public:
     enum sock_status {
 	kOK,
 	kRetry,
-	kReconnect
+	kReconnect,
+	kUnrecoverable
     };
 
     /**  Maximum time to maintain the client side of a connection if 
@@ -128,6 +129,15 @@ public:
       */
     sock_status read_header(link_header& hdr);
 
+    /**  Read in a data block as defined by the header structure. Indicate 
+      *  an error if the data read fails or data is the wrong length.
+      *  \brief Read data block.
+      *  \param hdr Reference to the output header structure.
+      *  \param buf data buffer of length at least hdr.length
+      *  \return Error code or zero.
+      */
+    sock_status read_data(const link_header& hdr, void* buf);
+
     /**  Test whether this process is a TCP data receiver, \e i.e. whether 
       *  the program mode is \c kReceive or \c kPull.
       *  \brief test whether this is a receiver.
@@ -169,10 +179,20 @@ private:
     uint32_t    mFrameDt;
 
     //----------------------------------  Status info.
-    SigFlag     mTerm;       /// Termination signal flag
-    sockaddr_in mServerAddr; /// Server address (bind or connect)
-    int         mServer;     /// Server port 
+    SigFlag     mTerm;       ///< Termination signal flag
+    sockaddr_in mServerAddr; ///< Server address (bind or connect)
+    int         mServer;     ///< Server port 
     int         mSocket;
+    /**  Bound state flag.
+      *    * server: On a server, the bound state indicates that the server 
+      *      socket has been bound to the server address and that a listen()
+      *      request has been issued. This frlag is set by the connect_sock() 
+      *      method and is cleared bu close_server().
+      *    * client: On a server, this flag indicates that the data socket has 
+      *      been bound to a network port. This flag is set by connect_sock() 
+      *      and cleared by close_sock().
+      *  \brief bound state flag.
+      */
     bool        mBound;
     bool        mConnected;
     uint32_t    mBlockID;
@@ -225,7 +245,7 @@ logstamp(std::ostream& out) {
     return out << TimeString(Now(), "%Y.%02m.%02d-%02H:%02N:%02S ");
 }
 
-//======================================  COntrol constants
+//======================================  Control constants
 static const int max_verbline = 100;
 
 //======================================  Main program
@@ -375,7 +395,7 @@ FrameLink::FrameLink(int argc, const char* argv[])
 
     //-----------------------------------  Optionally switch to a log file
     if (logfile) {
-	int flags = O_WRONLY | O_CREAT;
+	int flags = O_WRONLY | O_CREAT | O_APPEND;
 	int fd = open(logfile, flags, 0664);
 	close(1); // stdout
 	if (dup(fd) != 1) {
@@ -389,7 +409,7 @@ FrameLink::FrameLink(int argc, const char* argv[])
     }
 
     //----------------------------------  Identify myself (after log is open)
-    logstamp(cout) << "Starting framelink: $Id: framelink.cc 7471 2015-09-16 20:00:56Z john.zweizig@LIGO.ORG $" << endl;
+    logstamp(cout) << "Starting framelink: $Id: framelink.cc 7922 2017-08-03 00:14:52Z john.zweizig@LIGO.ORG $" << endl;
     logstamp(cout) << "arguments are:";
     for (int i=1; i<argc; i++) cout << " " << argv[i];
     cout << endl;
@@ -415,7 +435,7 @@ FrameLink::connect_sock(void) {
     int rc = 0;
 
     //----------------------------------  Open a socket
-    if (mSocket < 0) {
+    if (mSocket < 0 && (client() || !mBound)) {
 	mSocket = socket(PF_INET, SOCK_STREAM, 0);
 	if (mSocket < 0) {
 	    throw SysError("Socket request failed");
@@ -447,6 +467,7 @@ FrameLink::connect_sock(void) {
 	    rc = connectWithTimeout(mSocket, (sockaddr*)&mServerAddr, 
 				    sizeof(mServerAddr), Timeout);
 	    if (rc == 0) {
+		keepAliveTCP(mSocket, 60, 60, 2);
 		mConnected = true;
 		mLastRecv = Now();
 		if (v_check(true)) {
@@ -460,9 +481,6 @@ FrameLink::connect_sock(void) {
 		logstamp(cout) << "connect failed: " << strerror(errno) << endl;
 		switch(sverrno) {
 		case ETIMEDOUT:
-		    logstamp(cout) << "framelink: waiting for server " 
-				   << mPeerName << endl;
-		    break;
 		case ECONNREFUSED:
 		case ENOTCONN:
 		case ENETUNREACH:
@@ -472,8 +490,7 @@ FrameLink::connect_sock(void) {
 #ifdef ECONNABORTED
 		case ECONNABORTED:
 #endif
-		    close(mSocket);
-		    mSocket = -1;
+		    close_sock();
 		    sleep(30);
 		    break;
 		case EINTR:
@@ -494,6 +511,8 @@ FrameLink::connect_sock(void) {
 			   << mPeerName << endl;
 	    mServer = mSocket;
 	    mSocket = -1;
+
+	    //--------------------------  Make the server port reusable
 	    int reuse = 1;
 	    rc = setsockopt(mServer, SOL_SOCKET, SO_REUSEADDR, 
 			    &reuse, sizeof(int));
@@ -501,25 +520,48 @@ FrameLink::connect_sock(void) {
 		throw SysError("Unable to set reuse address");
 	    }
 
+#ifdef SO_REUSEPORT
+	    rc = setsockopt(mServer, SOL_SOCKET, SO_REUSEPORT, 
+			    &reuse, sizeof(int));
+	    if (rc != 0) {
+		throw SysError("Unable to set reuse port");
+	    }
+#endif
+
+	    //--------------------------  Bind the socket to the server port
 	    rc = ::bind(mServer, (sockaddr*)&mServerAddr, sizeof(mServerAddr));
-	    if (rc < 0) throw SysError("Server port bind failed");
-
-	    logstamp(cout) << "Listening to server socket" << endl;
-	    if (listen(mServer, 1)) {
-		throw SysError("Listen failed");
+	    if (rc < 0) {
+		switch (errno) {
+		case EADDRINUSE:
+		    mSocket = mServer;
+		    sleep(30.0);
+		    break;
+		default:
+		    throw SysError("Server port bind failed");
+		}
+	    } else {
+		logstamp(cout) << "Listening to server socket" << endl;
+		if (listen(mServer, 1)) {
+		    throw SysError("Listen failed");
+		}
+		mBound = true;
 	    }
-	    mBound = true;
 	}
 
 	//------------------------------  Accept a connection
-	if (!mConnected) {
+	if (mBound && !mConnected) {
 	    logstamp(cout) << "Waiting for client connection" << endl;
 	    mSocket = accept(mServer, 0, 0);
 	    if (mSocket < 0) {
 		perror("framelink: Accept error");
 	    } else {
-		logstamp(cout) << "Client connected" << endl;
 		mConnected = true;
+		logstamp(cout) << "Client connected" << endl;
+		if (keepAliveTCP(mSocket, 60, 60, 2)) {
+		    logstamp(cout) << "Keep-alive set" << endl;
+		} else {
+		    logstamp(cerr) << "Keep-alive setup failed" << endl;
+		}
 		mLastRecv = Now();
 	    }
 	    mBlockID = 0;
@@ -577,7 +619,19 @@ FrameLink::connect_shm(void) {
 void
 FrameLink::close_server(void) {
     if (mServer >= 0) {
-	close(mServer);
+	logstamp(cout) << "Close server socket." << endl;
+	int rc = shutdown(mServer, SHUT_RDWR);
+	if (rc < 0) {
+	    int sverr = errno;
+	    logstamp(cerr) << "Warning: Failed to shut down server socket: "
+			   << strerror(sverr) << endl;
+	}
+	rc = close(mServer);
+	if (rc < 0) {
+	    int sverr = errno;
+	    logstamp(cerr) << "Warning: Failed to close server socket: "
+			   << strerror(sverr) << endl;
+	}
 	mServer = -1;
 	mBound = false;
     }
@@ -599,13 +653,25 @@ FrameLink::close_shm(void) {
 //======================================  Close socket connection
 void
 FrameLink::close_sock(void) {
-    shutdown(mSocket, SHUT_RDWR);
-    close(mSocket);
+    if (mSocket < 0) return;
+    if (mConnected) {
+        if (shutdown(mSocket, SHUT_RDWR) < 0) {
+	    int sverr = errno;
+	    cerr << "Warning: Failed to shut down socket: " << strerror(sverr)
+	         << endl;
+        }
+        mConnected = false;
+    }
+    if (close(mSocket) < 0) {
+	int sverr = errno;
+	cerr << "Warning: Failed to close socket: " << strerror(sverr)
+	     << endl;
+    }
     mSocket = -1;
     if (client()) {
 	mBound = false;
     }
-    mConnected = false;
+    logstamp(cout) << "Data socket closed" << endl;
 }
 
 //=======================================  flush the specified length data
@@ -670,30 +736,18 @@ FrameLink::process(void) {
 	    }
 
 	    //--------------------------  Read frame into shared memory
-	    int rLen = read(buf, h.length, true);
-	    if (rLen <= 0) {
+	    sock_status datOK = read_data(h, buf);
+	    if (datOK != kOK) {
 		int save_errno = errno;
 		mOutPart->return_buffer();
-		errno = save_errno;
-		if (v_check(false)) {
-		    mVerbStream << " error receiving frame" << endl;
-		    mVerbStream.flush();
+		if (datOK != kRetry) {
+		    close_shm();
+		    close_sock();
 		}
-		throw SysError("Error receiving frame");
-	    }
-
-	    //--------------------------  Make a crc check
-	    if (uint32_t(rLen) != h.length) {
-		mOutPart->return_buffer();
-		if (v_check(false)) {
-		    mVerbStream << " Length error, read " << rLen 
-				<< "/" << h.length << endl;
-		    mVerbStream.flush();
+		if (datOK == kUnrecoverable) {
+		    errno = save_errno;
+		    throw SysError("Error receiving frame");
 		}
-		logstamp(cerr) << "Length error (" << rLen << "/" << h.length 
-			       << ") in frame at gps: " << h.gps_secs << endl;
-		close_shm();
-		close_sock();
 		continue;
 	    }
 
@@ -965,6 +1019,9 @@ FrameLink::read_header(link_header& h) {
 	case ECONNRESET:
 	    logstamp(cout) << "Connection closed by sender." << endl;
 	    return kReconnect;
+	case ETIMEDOUT:
+	    logstamp(cerr) << "Keep-alive detected a broken connection" << endl;
+	    return kReconnect;
 	default:
 	    throw SysError("Error reading header");
 	}
@@ -1040,6 +1097,52 @@ FrameLink::read_header(link_header& h) {
     return kOK;
 }
 
+//=======================================  Open verbose stream if requested
+FrameLink::sock_status
+FrameLink::read_data(const link_header& hdr, void* buf) {
+    sock_status rc = kOK;
+    
+    //----------------------------------  Try to read the data.
+    int rLen = read(buf, hdr.length, true);
+    int save_errno = errno;
+
+    //----------------------------------  See if an error was detected
+    if (rLen <= 0) {
+	if (v_check(false)) {
+	    mVerbStream << " error receiving frame" << endl;
+	    mVerbStream.flush();
+	}
+	switch (errno) {
+	case ENOTCONN:
+	case ECONNRESET:
+	    logstamp(cerr) << "Connection closed by sender." << endl;
+	    rc = kReconnect;
+	    break;
+	case ETIMEDOUT:
+	    logstamp(cerr) << "Keep-alive detected a broken connection" << endl;
+	    rc = kReconnect;
+	    break;
+	default:
+	    rc = kUnrecoverable;
+	}
+    }
+    
+    //----------------------------------  Check the length
+    else if (uint32_t(rLen) != hdr.length) {
+	if (v_check(false)) {
+	    mVerbStream << " Length error, read " << rLen 
+			<< "/" << hdr.length << endl;
+	    mVerbStream.flush();
+	}
+	logstamp(cerr) << "Length error (" << rLen << "/" << hdr.length 
+		       << ") in frame at gps: " << hdr.gps_secs << endl;
+	rc = kReconnect;
+    }
+    
+    errno = save_errno;
+    return rc;
+}
+
 //=======================================  Open verbose stream if requested
 bool
 FrameLink::v_check(bool reopen) {
