@@ -151,6 +151,8 @@ seg_calc::seg_calc(int argc, const char* argv[])
 	    }
 	} else if (argi == "-f") {
 	    fmt = argv[++i];
+	} else if (argi == "-ifo") {
+	    pfx = argv[++i];
 	} else if (argi == "-i") {
 	    mCmdFile = argv[++i];
 	} else if (argi.substr(0,2) == "-s") {
@@ -238,7 +240,7 @@ seg_calc::exec_cmd(const ParseLine& pl) {
 
     //------------------------------  Define a segment list
     if (cmdi == "define") {
-	string eval_cmd, name, ifo("xx");
+	string eval_cmd, name, ifo;
 	bool replace=false, logit=false, quiet=false;
 	int i0=1;
 	if (*(pl[i0]) != '-' ) name = pl[i0++];
@@ -516,7 +518,7 @@ seg_calc::write_segfile(const string& file, const segID& select,
 #ifdef HAVE_HDF5
 	wrt = new seg_iohdf5();
 #else
-	cerr << "*** Error: HDF5 not instsalled. File: " << file 
+	cerr << "*** Error: HDF5 not installed. File: " << file 
 	     << " not written." << endl;
 	return;
 #endif // defined(HAVE_HDF5)
@@ -616,10 +618,20 @@ SegEval::eval_funct(const std::string& sym, int N) {
 void 
 SegEval::push_symbol(const std::string& sym) {
     segID symID(sym);
-    if (mDictionary.find(symID) == mDictionary.end()) {
-        throw runtime_error(string("Undefined segment: ") + symID.full_name());
+    for (dict_type::const_iterator i=mDictionary.begin();
+	                           i != mDictionary.end();
+	                           i++) {
+	if (i->first.test(symID)) {
+	    mStack.push(new seg_token(i->second));
+	    return;
+	}
     }
-    mStack.push(new seg_token(mDictionary[symID]));
+    throw runtime_error(string("Undefined segment: ") + symID.full_name());
+    //------------------------------------------old source;
+    //if (mDictionary.find(symID) == mDictionary.end()) {
+    //    throw runtime_error(string("Undefined segment: ") + symID.full_name());
+    //}
+    //mStack.push(new seg_token(mDictionary[symID]));
 }
 
 //======================================  
